/* ##MKB
;-----------------------------------------------------------------------
; ##Copyright:          ABB
;-----------------------------------------------------------------------
; ##System           :  Transmitter
; ##Systemkomponente :  2000T
;-----------------------------------------------------------------------
; $Archive:: /Handheld/275/2000T/Sourcen/Rev 02/2000TiR2.ddl  $
; $Revision:: 1                                               $
;-----------------------------------------------------------------------
; ##Modulelemente    :
;
; - DDL of hand held terminal 275
;
; ##SPECEND
;-----------------------------------------------------------------------
; ##MKE*/


/*  Redefinitionen fr die COMMON-TABLES-DDL
    Redefinitionen fr die UNIVERSAL-Command-DDL
    Redefinitionen fr die COMMON-PRACTICE-Command-DDL
    Redefinition des COMMON-PRACTICE-Kommandos #48 und der zugehrigen Variablen
    Redefinitionen fr die PRESSURE-UNIVERSAL-Interoperable-DDL
    Redefinitionen fr die PRESSURE-COMMON-Interoperable-DDL   */




/*   Redefinitionen fr die COMMON-TABLES-DDL */

IMPORT STANDARD _TABLES, DEVICE_REVISION 6, DD_REVISION 1
{
   EVERYTHING;

/* Begin CPK*/
   REDEFINITIONS
   {
       DELETE VARIABLE unique_device_type_code;
       DELETE VARIABLE rosemount_model_code;
       DELETE VARIABLE rosemount_analytical_model_code;
       DELETE VARIABLE kayray_model_code;
       DELETE VARIABLE micro_motion_model_code;
       DELETE VARIABLE analog_output_numbers_code;
       DELETE VARIABLE operating_mode_code;
       DELETE VARIABLE units_code;
       DELETE VARIABLE transfer_function_code;
       DELETE VARIABLE material_code;
       DELETE VARIABLE alarm_selection_code;
       DELETE VARIABLE write_protect_code;
       DELETE VARIABLE company_identification_code;
       DELETE VARIABLE burst_mode_control_code;
       DELETE VARIABLE physical_signaling_codes;
       DELETE VARIABLE flag_assignment;
   }
/*End CPK */
}


/*****      Redefinitionen fr die UNIVERSAL-Command-DDL  */

IMPORT STANDARD _UNIVERSAL, DEVICE_REVISION 5, DD_REVISION 1
{
    EVERYTHING;

    REDEFINITIONS
    {
        DELETE COMMAND read_pv;

        VARIABLE manufacturer_id
        {
            REDEFINE TYPE ENUMERATED
            {
                { 26,  "ABB" }
            }
        }


        VARIABLE physical_signaling_code
        {
            /* Der Wert 2 ist in HART-Revision 5.1 nicht vorgesehen */
            TYPE ENUMERATED
            {
                DELETE 2;
            }
            /* auch WRITE, da zum Schreiben Password notwendig ist */
            REDEFINE HANDLING READ & WRITE;
        }


        VARIABLE device_type
        {
            REDEFINE TYPE ENUMERATED
            {
                { 137, "263/265, 2000T" }
            }
        }


        VARIABLE device_flags
        {
            /* Der Wert 0x04 ist in HART-Revision 5.1 nicht vorgesehen */
            TYPE BIT_ENUMERATED
            {
                DELETE 0x04;
            }
        }




        COMMAND read_unique_identifier
        {
            REDEFINE RESPONSE_CODES
            {
                0, SUCCESS, [no_command_specific_errors];
                8, MISC_WARNING, [update_failure];
            }
        }

        COMMAND read_pv_current_and_percent_range
        {
            REDEFINE RESPONSE_CODES
            {
                0, SUCCESS, [no_command_specific_errors];
                8, MISC_WARNING, [update_failure];
            }
        }

        COMMAND read_dynamic_variables_and_pv_current
        {
            REDEFINE TRANSACTION
            {
                REQUEST
                {}
                REPLY
                {
                    response_code, device_status
                    PV.ANALOG_VALUE,
                    free_process_variable_units, free_process_variable,
                    temperature_units, temperature_pressure_value,
                    free_process_var_units, free_proc_var_stat_press,
                    process_temp_units, static_press_proc_temp
                }
            }
            REDEFINE RESPONSE_CODES
            {
                0, SUCCESS, [no_command_specific_errors];
                8, MISC_WARNING, [update_failure];
            }
        }


        COMMAND write_polling_address
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }


        COMMAND read_unique_identifier_with_tag
        {
            REDEFINE RESPONSE_CODES
            {
                0, SUCCESS, [no_command_specific_errors];
                5, MISC_ERROR, [too_few_data_bytes_recieved];
                8, MISC_WARNING, [update_failure];
            }
        }


        COMMAND read_message
        {
            REDEFINE RESPONSE_CODES
            {
                0, SUCCESS, [no_command_specific_errors];
                8, MISC_WARNING, [update_failure];
            }
        }


        COMMAND read_tag_descriptor_date
        {
            REDEFINE RESPONSE_CODES
            {
                0, SUCCESS, [no_command_specific_errors];
                8, MISC_WARNING, [update_failure];
            }
        }


        COMMAND read_pv_sensor_info
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }


        VARIABLE write_protect
        {
            REDEFINE LABEL "|001Local write lock"
                           "|049VorOrtSchreibsch.";
            TYPE ENUMERATED
            {
                DELETE 250;
                DELETE 251;
                DELETE 252;
                DELETE 253;
            }
            /* DYNAMIC zustzlich, weil per Tastendruck nderbar */
            REDEFINE CLASS DEVICE & DYNAMIC;
        }


        VARIABLE private_label_distributor
        {
            /* Zustzliche Firmencodes der Revision 6 von den COMMON-TABLES im
             *  Vergleich zur Revision 5 lschen */
            TYPE ENUMERATED
            {
                REDEFINE
                {
                    26,  "ABB"
                }
                DELETE 61;
                DELETE 62;
                DELETE 63;
                DELETE 64;
                DELETE 65;
                DELETE 66;
                DELETE 67;
                DELETE 68;
                DELETE 69;
                DELETE 70;
                DELETE 71;
                DELETE 72;
                DELETE 73;
                DELETE 74;
            }
        }


        COMMAND read_pv_output_info
        {
            REDEFINE TRANSACTION
            {
                REQUEST
                    {}

                REPLY
                    {
                        response_code, device_status,
                        PV.ALARM_CODE, PV.TRANSFER_FUNCTION,
                        pressure_units, TV.UPPER_RANGE_VALUE, TV.LOWER_RANGE_VALUE,
                        PV.DAMPING_VALUE, write_protect, private_label_distributor
                    }
            }

            REDEFINE RESPONSE_CODES
            {
                0, SUCCESS, [no_command_specific_errors];
                8, MISC_WARNING, [update_failure];
            }
        }


        COMMAND read_final_assembly_number
        {
            REDEFINE RESPONSE_CODES
            {
                0, SUCCESS, [no_command_specific_errors];
                8, MISC_WARNING, [update_failure];
            }
        }


        COMMAND write_message
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }


        COMMAND write_tag_descriptor_date
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }


        COMMAND write_final_assembly_number
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }
    }
}



/******************************************************************************
 * Redefinitionen fr die COMMON-PRACTICE-Command-DDL     */

IMPORT STANDARD _COMMON_PRACTICE, DEVICE_REVISION 7, DD_REVISION 2
{
    /* nur nachfolgende Variablen, Kommandos und Methoden werden importiert  */
    VARIABLE eeprom_select;
    VARIABLE response_preambles;
    VARIABLE burst_command_number;
    VARIABLE burst_mode_select;

    COMMAND write_pv_damping_value;                     /* Command 34 */
    COMMAND write_pv_range_values;                      /* Command 35 */
    COMMAND set_pv_upper_range_value;                   /* Command 36 */
    COMMAND set_pv_lower_range_value;                   /* Command 37 */
    COMMAND reset_configuration_change_flag;            /* Command 38 */
    COMMAND eeprom_control;                             /* Command 39 */
    COMMAND enter_exit_fixed_pv_current_mode;           /* Command 40 */
    COMMAND perform_transmitter_self_test;              /* Command 41 */
    COMMAND perform_master_reset;                       /* Command 42 */
    COMMAND set_pv_zero;                                /* Command 43 */
    COMMAND write_pv_units;                             /* Command 44 */
    COMMAND trim_pv_current_dac_zero;                   /* Command 45 */
    COMMAND trim_pv_current_dac_gain;                   /* Command 46 */
    COMMAND write_pv_transfer_function;                 /* Command 47 */
    COMMAND read_additional_transmitter_status;         /* Command 48 */
    COMMAND write_number_of_response_preambles;         /* Command 59 */
    COMMAND write_burst_command_number;                 /* Command 108 */
    COMMAND burst_mode_control;                         /* Command 109 */

    METHOD loop_test;
    METHOD leave_fixed_current_mode;
    METHOD return_to_normal;
    METHOD burn_eeprom;
    METHOD zero_trim;
    METHOD applied_rerange;

    REDEFINITIONS
    {
        VARIABLE burst_mode_select
        {
            TYPE ENUMERATED
            {
                DELETE 250;
                DELETE 251;
                DELETE 252;
                DELETE 253;
            }
        }


        COMMAND write_pv_damping_value
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
                ADD 17, MISC_ERROR, "|001Invalid float format"
                                    "|049ungltige Gleitkommazahl";
            }
        }

        COMMAND write_pv_range_values
        {
            REDEFINE TRANSACTION
            {
                 REQUEST
                 {
                     pressure_units, TV.UPPER_RANGE_VALUE, TV.LOWER_RANGE_VALUE
                 }

                 REPLY
                 {
                     response_code, device_status,
                     pressure_units, TV.UPPER_RANGE_VALUE, TV.LOWER_RANGE_VALUE
                 }
            }

            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
                REDEFINE 14, DATA_ENTRY_ERROR, [span_too_small];
                ADD 17, MISC_ERROR, "|001Invalid float format"
                                    "|049ungltige Gleitkommazahl";
            }
        }

        COMMAND set_pv_upper_range_value
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }

        COMMAND set_pv_lower_range_value
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }

        COMMAND reset_configuration_change_flag
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }

        COMMAND eeprom_control
        {
            RESPONSE_CODES
            {
                DELETE 6;
            }
        }

        COMMAND enter_exit_fixed_pv_current_mode
        {
            RESPONSE_CODES
            {
                DELETE 6;
                ADD 17, MISC_ERROR, "|001Invalid float format"
                                    "|049ungltige Gleitkommazahl";
            }
        }

        COMMAND perform_transmitter_self_test
        {
            RESPONSE_CODES
            {
                DELETE 6;
            }
        }

        COMMAND perform_master_reset
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
                ADD 7, MODE_ERROR, [in_write_protect_mode];
            }
        }

        COMMAND set_pv_zero
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }

        COMMAND write_pv_units
        {
            REDEFINE TRANSACTION
            {
                REQUEST
                {
                    free_process_variable_units
                }

                REPLY
                {
                    response_code, device_status, free_process_variable_units
                }
            }

            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }

        COMMAND trim_pv_current_dac_zero
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
                ADD 12, MISC_ERROR, "|001current out of range"
                                    "|049unzulssiger Stromwert";
                ADD 17, MISC_ERROR, "|001Invalid float format"
                                    "|049ungltige Gleitkommazahl";
            }
        }

        COMMAND trim_pv_current_dac_gain
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
                ADD 12, MISC_ERROR, "|001current out of range"
                                    "|049unzulssiger Stromwert";
                ADD 17, MISC_ERROR, "|001Invalid float format"
                                    "|049ungltige Gleitkommazahl";
            }
        }

        COMMAND write_pv_transfer_function
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }


        COMMAND write_number_of_response_preambles
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }

        COMMAND write_burst_command_number
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }

        COMMAND burst_mode_control
        {
            RESPONSE_CODES
            {
                DELETE 6;
                DELETE 16;
            }
        }


        COMMAND read_additional_transmitter_status
        {
             REDEFINE TRANSACTION
             {
                 REQUEST
                     {
                     }
                 REPLY
                     {
                         response_code, device_status,
                         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                         diagnosis, diagnosis1, 0, 0,
                         diagnosisExtension, diagnosisExtension1,
                         diagnosisExtension2, diagnosisExtension3,
                         0, 0
                     }
                 RESPONSE_CODES
                     {
                         0, SUCCESS, [no_command_specific_errors];
                     }
             }
        }


        REDEFINE METHOD zero_trim
        {
            LABEL [zero_trim];
            HELP [zero_trim_help];
            DEFINITION
            {
                char status[STATUS_SIZE];
                int retry;
                char disp_string1[60];
                char disp_string2[60];
                int slen1;
                int slen2;
                slen1=60;
                slen2=60;
                /* alle nachfolgenden Response-Codes und gesetzten Device-Status-Bits */
                /* sollen nicht zum Abbruch der Methode fhren.                       */
                IGNORE_ALL_RESPONSE_CODES();
                IGNORE_ALL_DEVICE_STATUS();
                XMTR_IGNORE_ALL_RESPONSE_CODES();
                XMTR_IGNORE_ALL_DEVICE_STATUS();
                /* Warnung ausgeben */
                get_dictionary_string(remove_loop_from_auto,disp_string1,slen1);
                ACKNOWLEDGE(disp_string1);
                /* bei Abbruch der Methode, die Methode 'return_to_normal' ausfhren */
                add_abort_method(return_to_normal);
                /* Warnung ausgeben, das die Sensorkalibrierung beeinflut wird. */
                get_dictionary_string(this_will_affect_snsr_cal,disp_string1,slen1);
                ACKNOWLEDGE(disp_string1);
                /* tue ... */
                do
                {
                    /* Text ausgeben, da Druck 0 an Sensor gelegt werden soll */
                    get_dictionary_string(apply_0_input_to_snsr,disp_string1,slen1);
                    ACKNOWLEDGE(disp_string1);

                    /* Text ausgeben, da Druck einschwingen soll */
                    get_dictionary_string(snsr_input_stabilizing,disp_string1,slen1);
                    DELAY(3,disp_string1);

                    /* Trim-Kommando ausfhren */
                    send(43,status);

                    /* wenn Response-Code nicht 0 ist ... */
                    if (status[STATUS_RESPONSE_CODE])
                    {
                        /* Response-Code ausgeben */
                        display_response_status(43,status[STATUS_RESPONSE_CODE]);

                        /* wenn Messumformer in Schreibschutzmode ist, Fehlertext */
                        /* ausgeben und Methode abbrechen                        */
                        if ((status[STATUS_RESPONSE_CODE] != 9) &&
                            (status[STATUS_RESPONSE_CODE] != 10))
                        {
                            get_dictionary_string(abort_last_error,disp_string1,slen1);
                            DELAY(2,disp_string1);
                            process_abort();
                        }

                        /* wenn angelegter Druck zu klein oder zu gross ist, Abfrage ob */
                        /* erneut versucht werden soll.                                */
                        get_dictionary_string(zero_the_input_and_try_again,disp_string1,slen1);
                        get_dictionary_string(yes_no,disp_string2,slen2);
                        retry=SELECT_FROM_LIST(disp_string1,disp_string2);
                    }
                    else
                    {
                        /* wenn Methode beendet wird, Daten ins EEPROM brennen und in */
                        /* Normalmode zurckkehren                                    */
                        remove_abort_method(return_to_normal);  /* zuerst burn_eeprom */
                        add_abort_method(burn_eeprom);          /* und dann           */
                        add_abort_method(return_to_normal);     /* return_to_normal   */
                        /* Erfolgsmeldung ausgeben */
                        get_dictionary_string(snsr_zero_succeeded,disp_string1,slen1);
                        DELAY(3,disp_string1);
                        process_abort();
                    }
                } while (!retry);
                process_abort();
            }
        }


       /* Methode applied_rerange redefinieren * (Werte beaufschlagen)  */

        REDEFINE METHOD applied_rerange
        {
            LABEL [apply_values];
            HELP [applied_values_help];
            DEFINITION
            {
                int rc;
                long varid[3];
                char status[STATUS_SIZE];
                char disp_string1[60];
                char disp_string2[60];
                int slen1;
                int slen2;

                slen1 = 60;
                slen2 = 60;

                /* bei multivariablen Gert keine Bereichsnderung zulassen und nur Meldung ausgeben */
                rc = ivar_value(pbMultivariableFunction);
                if (rc > 0)
                {
                    DELAY(3,"|001No function at multivar. devices|049Keine Funktion bei multivar. Gerten");
                }

                /* sonst, nderung zulassen */
                else
                {
                    IGNORE_ALL_RESPONSE_CODES();
                    IGNORE_ALL_DEVICE_STATUS();
                    XMTR_IGNORE_ALL_RESPONSE_CODES();
                    XMTR_IGNORE_ALL_DEVICE_STATUS();
                    get_dictionary_string(remove_loop_from_auto,disp_string1,slen1);
                    ACKNOWLEDGE(disp_string1);
                    add_abort_method(return_to_normal);
                    varid[0] = VARID(TV.DIGITAL_VALUE);
                    varid[1] = VARID(TV.DIGITAL_UNITS);
                    while ( 1 )
                    {
                        get_dictionary_string(set_the,disp_string1,slen1);
                        get_dictionary_string(choice_4_20_exit,disp_string2,slen2);
                        switch(SELECT_FROM_LIST(disp_string1,disp_string2))
                        {
                        case 0:
                            get_dictionary_string(apply_new_4ma_input,disp_string1,slen1);
                            ACKNOWLEDGE(disp_string1);
                            do
                            {
                                send_command(3);
                                get_dictionary_string(current_applied_process_val,disp_string1,slen1);
                                get_dictionary_string(set_4ma_read_new_leave,disp_string2,slen2);
                                rc = select_from_list(disp_string1,varid,disp_string2);
                            } while(rc==1);
                            if( rc == 0 )
                            {
                                send(37,status);
                                if ( status[STATUS_RESPONSE_CODE] )
                                {
                                    display_response_status(37,status[STATUS_RESPONSE_CODE]);
                                }

                                assign_int(eeprom_select,0);
                                get_dictionary_string(making_changes_permanent,disp_string1,slen1);
                                DELAY(3,disp_string1);
                                send(39,status);
                                if ( status[STATUS_RESPONSE_CODE] )
                                {
                                    display_response_status(39,status[STATUS_RESPONSE_CODE]);
                                    get_dictionary_string(previous_err_seen_brn_eeprom,disp_string1,slen1);
                                    ACKNOWLEDGE(disp_string1);
                                }

                                send_command(15);
                            }
                            break;
                        case 1:
                            get_dictionary_string(apply_new_20ma_input,disp_string1,slen1);
                            ACKNOWLEDGE(disp_string1);
                            do
                            {
                                send_command(3);
                                get_dictionary_string(current_applied_process_val,disp_string1,slen1);
                                get_dictionary_string(set_20ma_read_new_leave,disp_string2,slen2);
                                rc = select_from_list(disp_string1,varid,disp_string2);
                            } while(rc == 1);
                            if( rc == 0 )
                            {
                                send(36,status);
                                if ( status[STATUS_RESPONSE_CODE] )
                                {
                                    display_response_status(36,status[STATUS_RESPONSE_CODE]);
                                }
                                assign_int(eeprom_select,0);
                                get_dictionary_string(making_changes_permanent,disp_string1,slen1);
                                DELAY(3,disp_string1);
                                send(39,status);
                                if ( status[STATUS_RESPONSE_CODE] )
                                {
                                    display_response_status(39,status[STATUS_RESPONSE_CODE]);
                                    get_dictionary_string(previous_err_seen_brn_eeprom,disp_string1,slen1);
                                    ACKNOWLEDGE(disp_string1);
                                }
                                send_command(15);
                            }
                            break;
                        case 2:
                            process_abort();
                        default:
                            process_abort();
                        }
                    }
                }
            }
        }
    }
}



/******************************************************************************
   Definition der Variablen zum Kommando #48             */


VARIABLE diagnosis
{
    HELP [field_device_status_14_help];
    LABEL [xmtr_specific_status_14];
    HANDLING READ;
    CLASS DEVICE & DIAGNOSTIC;
    TYPE BIT_ENUMERATED
    {
        { 0x01,     "|001Hardware failure of the electronic"
                    "|049Elektronikfehler Hardware", HARDWARE & UNCORRECTABLE }
        { 0x10,     "|001Memory error"
                    "|049Memory Fehler", HARDWARE & UNCORRECTABLE }
        { 0x20,     "|001Failure in measurement"
                    "|049Fehler A/D Wandler", HARDWARE & UNCORRECTABLE }
    }
}

VARIABLE diagnosis1
{
    HELP [field_device_status_15_help];
    LABEL [xmtr_specific_status_15];
    HANDLING READ;
    CLASS DEVICE & DIAGNOSTIC;
    TYPE BIT_ENUMERATED
    {
        { 0x04,     "|001Configuration not valid"
                    "|049Konfiguration ungltig", DATA }
    }
}


VARIABLE diagnosisExtension
{
    HELP [field_device_status_18_help];
    LABEL [xmtr_specific_status_18];
    HANDLING READ;
    CLASS DEVICE & DIAGNOSTIC;
    TYPE BIT_ENUMERATED
    {
        { 0x01,     "|001Comm Error Electr-EEPROM"
                    "|049Kommunikationsfehler Elektr-EEPROM", HARDWARE & UNCORRECTABLE}
        { 0x02,     "|001Comm Error Sensor-EEPROM"
                    "|049Kommunikationsfehler Sensor-EEPROM", HARDWARE & UNCORRECTABLE }
        { 0x04,     "|001max Write-Cycles Electr-EEPROM"
                    "|049max Schreibzyklen Elektr-EEPROM", HARDWARE & UNCORRECTABLE }
        { 0x08,     "|001max Write-Cycles Sensor-EEPROM"
                    "|049max Schreibzyklen Sensor-EEPROM", HARDWARE & UNCORRECTABLE }
        { 0x10,     "|001Electronic Data Error"
                    "|049Elektronik-Daten Fehler", HARDWARE & UNCORRECTABLE }
        { 0x20,     "|001Sensor Data Error"
                    "|049Sensor-Daten Fehler", HARDWARE & UNCORRECTABLE }
        { 0x40,     "|001User Data Error"
                    "|049Benutzer-Daten Fehler", HARDWARE & UNCORRECTABLE }
        { 0x80,     "|001Factory Reset Data Error"
                    "|049Werkseinstelldaten Fehler", HARDWARE & UNCORRECTABLE }
    }
}


VARIABLE diagnosisExtension1
{
    HELP [field_device_status_19_help];
    LABEL [xmtr_specific_status_19];
    HANDLING READ;
    CLASS DEVICE & DIAGNOSTIC;
    TYPE BIT_ENUMERATED
    {
        { 0x02,   "|001Saving EEPROM Data"
                  "|049Speichern der Daten ins EEPROM", MISC & SELF_CORRECTING }
        { 0x04,   "|001Factory Reset Data Error"
                  "|049Werkseinstelldaten Fehler", HARDWARE & UNCORRECTABLE }
        { 0x10,   "|001Device is busy"
                  "|049Gert ist beschftigt", MISC & SELF_CORRECTING }
        { 0x20,   "|001Wrong length of cycl data"
                  "|049Lnge des zykl. Datensatzes falsch", HARDWARE & UNCORRECTABLE }
        { 0x40,   "|001Cycl object not readable"
                  "|049Objekt zykl. Datensatz unlesbar", HARDWARE & UNCORRECTABLE }
        { 0x80,   "|001Cycl object not writable"
                  "|049Objekt zykl. Datensatz nicht schreibbar", HARDWARE & UNCORRECTABLE }
    }
}


VARIABLE diagnosisExtension2
{
    HELP [field_device_status_20_help];
    LABEL [xmtr_specific_status_20];
    HANDLING READ;
    CLASS DEVICE & DIAGNOSTIC;
    TYPE BIT_ENUMERATED
    {
        { 0x01,    "|001ROM error"
                   "|049ROM Fehler", HARDWARE & UNCORRECTABLE }
        { 0x02,    "|001Error int RAM"
                   "|049Fehler int. RAM", HARDWARE & UNCORRECTABLE }
        { 0x04,    "|001Error ext RAM"
                   "|049Fehler ext RAM", HARDWARE & UNCORRECTABLE }
    }
}


VARIABLE diagnosisExtension3
{
    HELP [field_device_status_21_help];
    LABEL [xmtr_specific_status_21];
    HANDLING READ;
    CLASS DEVICE & DIAGNOSTIC;
    TYPE BIT_ENUMERATED
    {
        { 0x20,    "|001Current reached lower limit"
                   "|049untere Strombegrenzung", HARDWARE & UNCORRECTABLE }
        { 0x40,    "|001Current reached upper limit"
                   "|049obere Strombegrenzung", HARDWARE & UNCORRECTABLE }
    }
}




/******************************************************************************
 * Redefinitionen fr die PRESSURE-UNIVERSAL-Interoperable-DDL     */


IMPORT STANDARD _PRESSURE_UNIVERSAL_5, DEVICE_REVISION 1, DD_REVISION 1
{
    EVERYTHING;

    REDEFINITIONS
    {
        DELETE ARRAY transmitter_variables;
        DELETE VARIABLE pressure_range_units;
        DELETE UNIT pressure_range_units_relation;

        COLLECTION OF VARIABLE process_pressure
        {
            MEMBERS
            {
                REDEFINE SENSOR_UNITS, pressure_units, [sensor_unit], [sensor_minspan_unit_help];
                REDEFINE RANGE_UNITS, pressure_units, [range_units], [range_units_help];
            }
        }


        VARIABLE pressure_units
        {
            REDEFINE HELP "|001Field Device Variable Unit- unit in which digital value, "
                          "upper range value, lower range value are displayed. "
                          "Pressure- Measured process pressure in relation to a reference pressure."
                          "|049Feldgerte Variablendimension- Dimension mit der der digitale Wert, die "
                          "obere Mebereichsgrenze und die untere Mebereichsgrenze behaftet sind. "
                          "Druck- Gemessener Prozedruck in Relation zu einem Bezugsdruck.";
            REDEFINE TYPE ENUMERATED
            {
                {    1,   "|001inH2O"
                          "|049inH2O"},
                {    2,   "|001inHg"
                          "|049inHg"},
                {    3,   "|001ftH2O"
                          "|049ftH2O"},
                {    4,   "|001mmH2O"
                          "|049mmH2O"},
                {    5,   "|001mmHg"
                          "|049mmHg"},
                {    6,   "|001psi"
                          "|049psi"},
                {    7,   "|001bar"
                          "|049bar"},
                {    8,   "|001mbar"
                          "|049mbar"},
                {    9,   "|001g/cm2"
                          "|049g/cm2"},
                {   10,   "|001kg/cm2"
                          "|049kg/cm2"},
                {   11,   "|001Pa"
                          "|049Pa"},
                {   12,   "|001kPa"
                          "|049kPa"},
                {   13,   "|001torr"
                          "|049torr"},
                {   14,   "|001atm"
                          "|049atm"},
                {  237,   "|001MPa"
                          "|049MPa"},
                {  253,   "|001special"
                          "|049Spezial"}
            }
            REDEFINE HANDLING
                IF ( pbMultivariableFunction > 0 )
                {
                    READ ;
                }
                ELSE
                {
                    READ & WRITE;
                }
            REDEFINE PRE_EDIT_ACTIONS
            {
                store_old_press_unit
            }
            REDEFINE POST_EDIT_ACTIONS
            {
                calc_new_pressure_range_values
            }
        }

        VARIABLE pressure_percent_range
        {
           REDEFINE LABEL [percent_of_range];
           REDEFINE HELP "|001Percent of Range- Variable which represents the digital value with respect "
                          "to the range defined by the lower range value and upper range value. For "
                          "normal operating modes. This variable is always in percent. Pressure- "
                          "Measured process pressure in relation to a reference pressure."
                          "|049Prozent Mespanne- Variable, die den dig. Wert darstellt mit Bezug zur "
                          "Mespanne, die durch Meanfang und Meende bestimmt ist. Fr normale "
                          "Betriebsbedingungen. Die Einheit ist immer Prozent. Druck- Gemessener "
                          "Prozedruck in Relation zu einem Bezugsdruck.";
           /* Das Anzeige-Format wird auf 1 Nachkommastelle begrenzt   */
            REDEFINE TYPE FLOAT
            {
                DISPLAY_FORMAT ".1f";
            }
        }


        VARIABLE pressure_upper_range_limit
        {
            REDEFINE HELP "|001Upper Sensor Limit Value- Defines the maximum value able to be used for the "
                          "upper range value. Pressure- Measured proccess pressure in relation to a "
                          "reference pressure."
                          "|049Wert obere Mebereichsgrenze- bestimmt den max. nutzbaren Wert fr das "
                          "Meende. Druck- Gemessener Prozedruck in Relation zu einem Bezugsdruck.";
            /* auch WRITE, da zum Schreiben Password notwendig ist  */
            REDEFINE HANDLING READ & WRITE;
        }


        VARIABLE pressure_lower_range_limit
        {
            REDEFINE HELP "|001Lower Sensor Limit Value- Defines the lowest allowable value for the lower "
                          "range value. Pressure- Pressure of the process with respect to a reference "
                          "pressure."
                          "|049Wert untere Mebereichsgrenze- bestimmt den min. nutzbaren Wert fr den "
                          "Meanfang. Druck- Gemessener Prozedruck in Relation zu einem Bezugsdruck.";
            /* auch WRITE, da zum Schreiben Password notwendig ist  */
            REDEFINE HANDLING READ & WRITE;
        }


        VARIABLE pressure_minimum_span
        {
            REDEFINE HELP "|001Minimum Span Value- Defines the smallest allowable difference between the "
                          "Upper Range Value and the Lower Range Value. Pressure- Measured proccess "
                          "pressure in relation to a reference pressure."
                          "|049Wert min.Mespanne- bestimmt die kleinste zulssige Differenz zwischen "
                          "Meanfang und Meende. Druck- Gemessener Prozedruck in Relation zu einem "
                          "Bezugsdruck.";
            /* auch WRITE, da zum Schreiben Password notwendig ist  */
            REDEFINE HANDLING READ & WRITE;
        }


        VARIABLE pressure_output_transfer_function
        {
            REDEFINE LABEL [pressure_transfer_function];
            REDEFINE HELP [transfer_function_help];
            REDEFINE TYPE ENUMERATED
            {
                {   0,  "|001Linearization"
                        "|049Linear" },
                {   1,  "|001Square root"
                        "|049Radizierung" },
                {   2,  "|001Square root to the 3rd power"
                        "|049Xexp3/2" },
                {   3,  "|001Square root to the 5th power"
                        "|049Xexp5/2" },
                {   4,  "|001Linearization curve"
                        "|049Linearisierungskurve" },
                { 160,  "|001Linearization primary element"
                        "|049Linearisierung Primrgerte" },
                { 241,  "|001Spherical tank"                     /*getauscht  */
                        "|049Kugelbehlter"},                   /*wg. falscher */
                { 242,  "|001Cylindric lying tank"              /*Zuordnung */
                        "|049Zylindr liegender Behlter" }      /*in Gertesoftware */
            }
            REDEFINE HANDLING
                IF ( pbMultivariableFunction > 0 )
                {
                    READ ;
                }
                ELSE
                {
                    READ & WRITE;
                }
        }


       VARIABLE pressure_upper_range_value
       {
           REDEFINE HELP "|001Upper Range Value- Defines the endpoint for the analog value and the 100% "
                         "point of the percent range. The upper range value also defines the "
                         "operational endpoint from which the alarms for the analog output value as "
                         "well as the associated digital value are taken. Pressure- Measured proccess "
                         "pressure in relation to a reference pressure."
                         "|049Meende- bestimmt den Endpunkt fr das analoge Ausgangssignal und den 100% "
                         "Punkt des entsprechenden Prozentbereiches. Zustzlich bestimmt das Meende "
                         "einen Arbeits-Endpunkt von dem die Alarme fr den Analogausgang, als auch "
                         "fr den entsprechenden digitalen Wert erlangt werden. Druck- Gemessener "
                         "Prozedruck in Relation zu einem Bezugsdruck.";
           REDEFINE TYPE FLOAT
           {
               EDIT_FORMAT
               SELECT (pressure_units)
               {
                   CASE 1:
                       ".3g";
                   CASE 2:
                       ".f";
                   CASE 3:
                       ".f";
                   CASE 4:
                       ".3g";
                   CASE 5:
                       ".3g";
                   CASE 6:
                       ".1f";
                   CASE 7:
                       ".2f";
                   CASE 8:
                       ".3g";
                   CASE 9:
                       ".3g";
                   CASE 10:
                       ".2f";
                   CASE 11:
                       ".3g";
                   CASE 12:
                       ".2f";
                   CASE 13:
                       ".3g";
                   CASE 14:
                       ".2f";
               }
               DISPLAY_FORMAT
               SELECT (pressure_units)
               {
                   CASE 1:
                       ".3g";
                   CASE 2:
                       ".f";
                   CASE 3:
                       ".f";
                   CASE 4:
                       ".3g";
                   CASE 5:
                       ".3g";
                   CASE 6:
                       ".1f";
                   CASE 7:
                       ".2f";
                   CASE 8:
                       ".3g";
                   CASE 9:
                       ".3g";
                   CASE 10:
                       ".2f";
                   CASE 11:
                       ".3g";
                   CASE 12:
                       ".2f";
                   CASE 13:
                       ".3g";
                   CASE 14:
                       ".2f";
               }
           }
           REDEFINE HANDLING
               IF ( pbMultivariableFunction > 0 )
               {
                   READ ;
               }
               ELSE
               {
                   READ & WRITE;
               }
       }


       VARIABLE pressure_lower_range_value
       {
           REDEFINE HELP "|001Lower Range Value- Defines the operational endpoint or the analog output "
                         "signal and 0% of the percent range. In addition, the lower range value "
                         "defines an operational endpoint from which the alarm values for the analog "
                         "output as well as the associated digital value are derived. Pressure- "
                         "Pressure of the process with respect to a reference pressure."
                         "|049Meanfang- bestimmt den Anfangspunkt fr das analoge Ausgangssignal und den "
                         "0% Punkt des entsprechenden Prozentbereiches. Zustzlich bestimmt der "
                         "Meanfang einen Arbeits-Endpunkt von dem die Alarme fr den Analogausgang, "
                         "als auch fr den entsprechenden digitalen Wert erlangt werden. Druck- "
                         "Gemessener Prozedruck in Relation zu einem Bezugsdruck.";
           REDEFINE TYPE FLOAT
           {
               EDIT_FORMAT
               SELECT (pressure_units)
               {
                   CASE 1:
                       ".3g";
                   CASE 2:
                       ".f";
                   CASE 3:
                       ".f";
                   CASE 4:
                       ".3g";
                   CASE 5:
                       ".3g";
                   CASE 6:
                       ".1f";
                   CASE 7:
                       ".2f";
                   CASE 8:
                       ".3g";
                   CASE 9:
                       ".3g";
                   CASE 10:
                       ".2f";
                   CASE 11:
                       ".3g";
                   CASE 12:
                       ".2f";
                   CASE 13:
                       ".3g";
                   CASE 14:
                       ".2f";
               }
               DISPLAY_FORMAT
               SELECT (pressure_units)
               {
                   CASE 1:
                       ".3g";
                   CASE 2:
                       ".f";
                   CASE 3:
                       ".f";
                   CASE 4:
                       ".3g";
                   CASE 5:
                       ".3g";
                   CASE 6:
                       ".1f";
                   CASE 7:
                       ".2f";
                   CASE 8:
                       ".3g";
                   CASE 9:
                       ".3g";
                   CASE 10:
                       ".2f";
                   CASE 11:
                       ".3g";
                   CASE 12:
                       ".2f";
                   CASE 13:
                       ".3g";
                   CASE 14:
                       ".2f";
               }
           }
           REDEFINE HANDLING
               IF ( pbMultivariableFunction > 0 )
               {
                   READ ;
               }
               ELSE
               {
                   READ & WRITE;
               }
       }


       VARIABLE pressure_damping_value
       {
           REDEFINE HELP "|001Damping Value- Damping time which affects both the digital and analog "
                         "output values. The variable is always in seconds. Pressure- Pressure of the "
                         "process with respect to a reference pressure."
                         "|049Dmpfungswert- Dmpfungszeit, die auf den digitalen Ausgangswert als auch "
                         "auf den entsprechenden analogen Ausgang wirkt. Die Angabe erfolgt immer in "
                         "Sekunden. Druck- Gemessener Prozedruck in Relation zu einem Bezugsdruck.";
           REDEFINE CLASS CORRECTION;
          /* Das Anzeige- und Editier-Format wird auf 1 Nachkommastelle erweitert  */
           REDEFINE TYPE FLOAT
           {
               DISPLAY_FORMAT ".1f";
               EDIT_FORMAT "4.1f";
               MIN_VALUE 0.0;
               MAX_VALUE 60.0;
           }
       }


       VARIABLE flange_type
       {
           REDEFINE HELP "|001Flange Type- Part next to the sensor which physically connects the process "
                         "to the sensor. Pressure- Pressure of the process measured with respect to a "
                         "reference pressure."
                         "|049Flanschtyp- Teil beim Sensor, der den Prozestoff zum Sensor fhrt. Druck- "
                         "Gemessener Prozedruck in Relation zu einem Bezugsdruck";
           REDEFINE TYPE ENUMERATED
           {
               {   1,   "|001Flange and 1/4 NPT"
                        "|049Flansch und 1/4 NPT" },
               {   2,   "|001DIN 19213 and 1/4 NPT"
                        "|049DIN 19213 u. 1/4 NPT" },
               {   3,   "|001DIN16288: B-G 1/2A"
                        "|049DIN16288: B-G 1/2A" },
               {   4,   "|001DIN16288: D-G 1/2A"
                        "|049DIN16288: D-G 1/2A" },
               {   5,   "|001NPT1/2 '' male thread"
                        "|049NPT 1/2 '' Auengew." },
               {   6,   "|001NPT1/2 '' fem. thread"
                        "|049NPT 1/2 '' Innengew." },
               {   7,   "|001NPT 1/4 internal thread"
                        "|049NPT 1/4 Innengewinde"},
               {   8,   "|001Pin DIN 16288 Form"
                        "|049Zapfen DIN 16288 Form"},
               {   9,   "|001Alcatel flange DN25"
                        "|049Alcatel Flansch DN25"},
               {  10,   "|001Pressure sensor with flange"
                        "|049Druck-Mewerk m.Flansch"},
               { 251,   [none] },
               { 253,   [special] }
           }
       }


       VARIABLE o_ring_material
       {
           REDEFINE HELP "|001O Ring Material- Material of the seal between the module and flange."
                         "|049O Ring Material- Werkstoff der Dichtung zwischen dem Mewerk und dem "
                         "Flansch.";
           REDEFINE TYPE ENUMERATED
           {
               {   0,   [carbon_steel], [carbon_steel_help] },
               {   1,   "|001Stainless Steel 304"
                        "|049Nichtr. Stahl 304"},
               {   2,   "|001Stainless Steel 316"
                        "|049Nichtr. Stahl 316"},
               {   3,   [hastelloy_c], [hastelloy_c_help] },
               {   4,   [monel], [monel_help] },
               {   5,   [tantalum], [tantalum_help] },
               {   6,   "|001Titanium"
                        "|049Titan"},
               {   7,   "|001Platinum-Iridium"
                        "|049Platin-Iridium"},
               {   8,   "|001Alloy 20"
                        "|049Alloy 20"},
               {   9,   "|001Cobalt Chromium Nickel"
                        "|049Kobalt-Chrom-Nickel"},
               {  10,   [ptfe], [ptfe_teflon_help] },
               {  11,   [vito], [viton_help] },
               {  12,   [buna_n], [buna_n_help] },
               {  13,   "|001Ethyl-Prop"
                        "|049Ethyl-Prop"},
               {  14,   "|001Urethane"
                        "|049Urethan"},
               {  15,   "|001Gold Monel Alloy"
                        "|049Gold Monel Alloy"},
               {  16,   "|001Tefzel"
                        "|049Tefzel"},
               {  17,   "|001Ryton"
                        "|049Ryton"},
               {  18,   [ceramic], [ceramic_help] },
               {  19,   [stainless_steel_316l], [stainless_steel_316l_help] },
               {  20,   "|001PVC"
                        "|049PVC"},
               {  21,   "|001Nitrile Rubber"
                        "|049Nitrile Gummi"},
               {  22,   [kalrez], [kalrez_help] },
               {  23,   "|001Inconel"
                        "|049Inconel"},
               {  24,   "|001Kynar"
                        "|049Kynar"},
               {  25,   "|001Aluminium"
                        "|049Aluminium"},
               {  26,   "|001Nickel"
                        "|049Nickel"},
               {  27,   "|001FEP"
                        "|049FEP"},
               {  28,   "|001Stainless Steel 316 Ti"
                        "|049Nichtr. Stahl 316 Ti"},
               {  30,   "|001Hastelloy C276"
                        "|049Hastelloy C276"},
               {  31,   "|001Klinger C4401"
                        "|049Klinger C4401"},
               {  32,   "|001Thermotork"
                        "|049Thermotork"},
               {  33,   "|001Grafoil"
                        "|049Grafoil"},
               {  34,   "|001PTFE coated 316l SST"
                        "|049316l SST PTFE beschichtet"},
               {  35,   "|001Gold plated Hastelloy C276"
                        "|049Hastelloy C276 goldbeschichtet"},
               {  36,   "|001PTFE Glass"
                        "|049PTFE Glass"},
               {  37,   "|001PTFE Graphite"
                        "|049PTFE Graphite"},
               { 129,   "|0011.4571/1.4404"
                        "|0491.4571/1.4404"},
               { 130,   "|001Hastelloy C/1.4571"
                        "|049Hastelloy C/1.4571"},
               { 132,   "|0011.4435/1.4571"
                        "|0491.4435/1.4571"},
               { 133,   "|001Per Fluor Kautschuk"
                        "|049Per Fluor Kautschuk"},
               { 134,   "|00114435"
                        "|04914435"},
               { 135,   "|001AU/1.4404"
                        "|049AU/1.4404"},
               { 136,   "|001Gold plated Monel"
                        "|049Monel goldbeschichtet"},
               { 137,   "|001PVDF"
                        "|049PVDF"},
               { 138,   "|001EPDM"
                        "|049EPDM"},
               { 144,   "|001Steel"
                        "|049Baustahl"},
               { 145,   "|001Stainless Steel, ferritic"
                        "|049nicht rostender Stahl, ferritisch"},
               { 146,   "|001Stainless Steel, austenitic"
                        "|049nicht rostender Stahl, austenitisch"},
               { 147,   "|001Copper based Alloys"
                        "|049Kupferlegierungen"},
               { 148,   "|001Brass"
                        "|049Messing"},
               { 234,   "|001PTFE Hastelloy"
                        "|049PTFE Hastelloy"},
               { 235,   "|001Stainless Steel CF 8M"
                        "|049Stainless Steel CF 8M"},
               { 236,   "|001Hastelloy SST"
                        "|049Hastelloy SST"},
               { 237,   "|001Gold plated SST"
                        "|049SST goldbeschichtet"},
               { 239,   "|001Monel 400"
                        "|049Monel 400"},
               { 250,   "|001Not used"
                        "|049Nicht benutzt"},
               { 251,   [none] },
               { 252,   "|001Unknown"
                        "|049Unbekannt"},
               { 253,   [special] }
           }
       }


       VARIABLE meter_installation
       {
           REDEFINE HELP "|001Display Unit - Defines which information is shown on the display."
                         "|049Anzeigewert- Definiert welche Information auf der Anzeige zu sehen ist";
           REDEFINE LABEL "|001Display Unit"
                          "|049Anzeigewert";
           REDEFINE TYPE ENUMERATED
           {
               {   1,   "|001Pressure"
                        "|049Druck"},
               {   2,   "|001Percent"
                        "|049Prozentwert"},
               {   3,   "|001Current"
                        "|049Strom"},
               {   4,   "|001Mass flow/Normalized vol flow"
                        "|049Massen-Durchflu/NormVolDurchfl"},
               {   5,   "|001Volume flow"
                        "|049Volumen-Durchflu"}
           }
       }


       VARIABLE remote_seal_type
       {
           REDEFINE HELP "|001Remote Seal Type- Type of remote seal connected to the device. This is only "
                         "true when only 1 remote seal is installed."
                         "|049Druckmittler Typ- Art des am Feldgert angeschlossenen Druckfhlers. Diese "
                         "Angabe ist eindeutig wenn nicht mehr als ein Druckfhler angeschlossen ist.";
           REDEFINE TYPE ENUMERATED
           {
               {   1,   "|001Flush diaphragm DN 25"
                        "|049Flachmembran DN 25" },
               {   2,   "|001Fl. diaphr. ANSI 1''"
                        "|049Flachmembr. ANSI 1''" },
               {   3,   "|001Fl. diaphragm DN 50"
                        "|049Flachmembran DN 50" },
               {   4,   "|001Fl. diaphr. ANSI 2''"
                        "|049Flachmembr. ANSI 2''" },
               {   5,   "|001Fl. diaphragm DN 80"
                        "|049Flachmembran DN 80" },
               {   6,   "|001Fl. diaphr. ANSI 3''"
                        "|049Flachmembr. ANSI 3''" },
               {   7,   "|001Ext. diaphragm DN 50"
                        "|049Tubus DN 50" },
               {   8,   "|001Ext.diaphr. ANSI 2''"
                        "|049Tubus ANSI 2''" },
               {   9,   "|001Ext. diaphragm DN 80"
                        "|049Tubus DN 80" },
               {  10,   "|001Ext.diaphr. ANSI 3''"
                        "|049Tubus ANSI 3''" },
               {  11,   "|001Tube RS DN25/ANSI1''"
                        "|049Rohr-DF DN25/ANSI1''" },
               {  12,   "|001Tube RS DN40/1.5''"
                        "|049Rohr-DF DN40/1,5''" },
               {  13,   "|001Tube RS DN50/2'' "
                        "|049Rohr-DF DN50/2''" },
               {  14,   "|001Tube RS DN80/3'' "
                        "|049Rohr-DF DN80/3''" },
               {  15,   "|001RS w. cap screw DN50"
                        "|049DF Nutberwurfm DN50" },
               {  16,   "|001RS clamp connect.2''"
                        "|049DF Clamp-Anschl. 2''" },
               {  17,   "|001Miniature RS G 1 A"
                        "|049Klein-DF G 1 A" },
               {  18,   "|001Miniature RS G 1/2 A"
                        "|049Klein-DF G 1/2 A" },
               { 251,   [none] },
               { 253,   [special] }
           }
       }


       VARIABLE module_fill_fluid
       {
           REDEFINE HELP "|001Sensor Fill Fluid- Fluid in the module."
                         "|049Sensorfll- flssigkeit- Flssigkeit im Modul";
           REDEFINE TYPE ENUMERATED
           {
               {   1,   [silicone_oil] },
               {   2,   "|001Fluor carbon"
                        "|049Fluorkohlenstoff" },
               {   3,   "|001Destilled water"
                        "|049Destilliertes Wasser" },
               {   4,   "|001High temperature oil"
                        "|049Hochtemperaturl" },
               {   5,   "|001Vegetable Oil"
                        "|049Pflanzenl"},
               {   6,   "|001Mineral oil"
                        "|049Minerall"},
               {   7,   "|001White oil"
                        "|049Weissl"},
               {   8,   "|001Fill fluid FDA certified"
                        "|049Fllflssigkeit FDA zugelassen"},
               {   9,   "|001Fill fluid ABB"
                        "|049Fllflssigkeit ABB"},
               { 251,  [none] },
               { 253,  [special] }
           }
          /* auch WRITE, da zum Schreiben Password notwendig ist */
           REDEFINE HANDLING READ & WRITE;
       }


        REDEFINE  VARIABLE number_of_remote_seals
        {
            CLASS DEVICE;
            LABEL [number_of_remote_seals];
            HELP "|001Number of Remote Seals- Number of remote seals on the device."
                 "|049Anzahl Druckmittler- Menge der Druckmittler die am Gert montiert sind.";
            /* Definitionen fr den SMART-Messumformer */
            TYPE UNSIGNED_INTEGER
            {
                DISPLAY_FORMAT "5u";
            }
            HANDLING READ & WRITE;
        }

        /* Auflistung aller mit der Druckdimension behafteter Variablen */
        REDEFINE UNIT pressure_units_relation
        {
            pressure_units:
                pressure_upper_range_value,
                pressure_lower_range_value
        }

        /* Auflistung aller mit der Sensorgrenzendruckdimension behafteter Variablen */
        REDEFINE UNIT pressure_sensor_units_relation
        {
            pressure_sensor_units:
                pressure_upper_range_limit,
                pressure_lower_range_limit,
                pressure_minimum_span,
                static_pressure_hi_lim,
                static_pressure_lo_lim
        }

        /* Methode send_warning redefinieren
         * (Warnung bei Dimensionsnderungen auf dem HHT ausgeben) */
        REDEFINE METHOD send_warning
        {
            HELP "|001Send Warning- Sends a unit code warning to the user."
                 "|049Warnung- Gibt eine Dimensionscodewarnung an den Benutzer aus.";
            LABEL "|001Send Warning"
                  "|049WARNUNG";
            DEFINITION
            {
                /* Werte im Messumformer speichern */
                save_values();
                /* Warnung ausgeben */
                ACKNOWLEDGE("|001Variables with this unit maintain their old value until a new unit has been "
                            "sent to the device."
                            "|049Variablen mit dieser Dimension behalten ihren alten Wert bis die neue "
                            "Dimension zum Gert gesendet wurde.");
            }
        }
    }
}


/******************************************************************************
 *       Redefinitionen fr die PRESSURE-COMMON-Interoperable-DDL  */

IMPORT STANDARD _PRESSURE_COMMON_5, DEVICE_REVISION 1, DD_REVISION 1
{
  /* nur nachfolgende Variablen, Kommandos und Methoden werden importiert.*/
   VARIABLE analog_output_value;
   VARIABLE analog_output_alarm_select;
   VARIABLE pressure_sensor_serial_number;
   VARIABLE module_type_code;
   VARIABLE sensor_a_lower_sensor_trim_point;
   VARIABLE sensor_a_upper_sensor_trim_point;
   VARIABLE flange_material;
   VARIABLE remote_seal_isolator_material;
   VARIABLE module_isolator_material;
   VARIABLE local_keys_mode_control_codes;
   VARIABLE drain_vent_material;

   COMMAND write_upper_sensor_trim;                /* Command 130 */
   COMMAND write_lower_sensor_trim;                /* Command 131 */


   REDEFINITIONS
   {
       VARIABLE  pressure_sensor_serial_number
       {
           REDEFINE HELP "|001Sensor Serial Number- Clearly defines the sensor from which the digital "
                         "value or the field device variable is primarily taken. Pressure Sensor- "
                         "Hardware that measures pressure with respect to a reference pressure."
                         "|049Sensor Seriennummer- bestimmt eindeutig den Sensor von dem der digitale "
                         "Wert oder die Variable des Feldgertes hauptschlich erlangt wird. "
                         "Drucksensor- Konstruktion die den Druck in Relation zu einem Bezugsdruck "
                         "mit.";
          /* auch WRITE, da zum Schreiben Password notwendig ist */
           REDEFINE HANDLING READ & WRITE;
       }


       VARIABLE sensor_a_lower_sensor_trim_point
       {
           REDEFINE HELP "|001Lower Sensor Trim Point- Applied process pressure at which the last low "
                         "sensor trim was performed. Pressure Sensor- Measured proccess pressure in "
                         "relation to a reference pressure."
                         "|049Unterer Sensorabgleichpunkt- Angelegter Prozedruck bei dem der letzte "
                         "unterer Sensorabgleich vorgenommen wurde. Drucksensor- Konstruktion die den "
                         "Druck in Relation zu einem Bezugsdruck mit.";
           REDEFINE LABEL "|001Lower sensor trim point"
                          "|049Untere Sensor Einstellung";
       }


       VARIABLE sensor_a_upper_sensor_trim_point
       {
           REDEFINE HELP "|001Upper Sensor Trim Point- Applied process pressure at which the last upper "
                         "sensor trim was performed. Pressure Sensor- Measured proccess pressure in "
                         "relation to a reference pressure."
                         "|049Oberer Sensorabgleichpunkt- Angelegter Prozedruck bei dem der letzte obere "
                         "Sensorabgleich vorgenommen wurde. Drucksensor- Konstruktion die den Druck "
                         "in Relation zu einem Bezugsdruck mit.";
           REDEFINE LABEL "|001Upper sensor trim point"
                          "|049Oberer Sensor Einstellwert";
       }


       VARIABLE analog_output_value
       {
           REDEFINE HELP "|001Analog Output Value- Value that corresponds with the digital variable under "
                         "normal operating modes. Analog Output- Measureable physical output which "
                         "can change user intervention."
                         "|049Wert Analogausgang- Wert der direkt der digitalen Variable folgt, unter "
                         "normalen Betriebsbedinungen. Analogausgang- mebarer physischer Ausgang der "
                         "seinen Wert zeitweise ohne Zutun des Bedieners ndert.";
           REDEFINE LABEL  "|001PV AO"
                                            "|049PV AA";
          /* Das Editier-Format wird auf 6 Stellen erweitert  */
           REDEFINE TYPE FLOAT
           {
               DISPLAY_FORMAT ".3f";
               EDIT_FORMAT "6.3f";
           }
       }


        VARIABLE analog_output_alarm_select
        {
            REDEFINE HELP "|001Analog Output Alarm Type- Defines how the analog output responds when the "
                          "field device detects that the analog output does not correspond with the "
                          "field device variable. NOTE- The digital value can be undefined. Analog "
                          "Output- Measureable physical output which can change without user "
                          "intervention."
                          "|049Analogausgang Alarmwert- bestimmt das Verhalten des Analogausgangs, wenn "
                          "das Feldgert feststellt, da der Analogausgang mglicherweise nicht mehr "
                          "in Uebereinstimmung  mit der Variablen des Feldgertes ist. ANMERKUNG- der "
                          "digitale Wert kann unbestimmt sein. Analogausgang- mebarer physischer "
                          "Ausgang der seinen Wert zeitweise ohne Zutun des Bedieners ndert.";

            REDEFINE LABEL "|001AO alarm typ"
                           "|049Analog Alarmart";
            REDEFINE TYPE ENUMERATED
            {
                {   0,  [high] },
                {   1,  [low] },
                { 239,  "|001Hold last value"
                        "|049Letzten Stromwert beibehalten"}
            }
            /* auch WRITE, da Schreiben mglich ist  */
            REDEFINE HANDLING READ & WRITE;
        }


       VARIABLE module_type_code
       {
           REDEFINE HELP "|001Measurement Type- Type of measurement this field device is intended to be "
                         "used for."
                         "|049Messwerksart- Art der Messung fr welche das Feldgert ausgelegt ist.";
           REDEFINE TYPE ENUMERATED
           {
               {  20,   "|001MVD Kap. 15712"
                        "|049MVD Kap. 15712"},
               {  22,   "|001MVD Piezo 15712"
                        "|049MVD Piezo 15712"},
               {  23,   "|001MVDA Piezo 15713"
                        "|049MVDA Piezo 15713"},
               {  25,   "|001Internal use"
                        "|049Interne Benutzung"},
               {  28,   "|001MVD Piezo 15712 100 bar"
                        "|049MVD Piezo 15712, 100 bar"},
               {  30,   "|001MVP Kap. 15753"
                        "|049MVP Kap. 15753"},
               {  31,   "|001MVPA Kap. 15754"
                        "|049MVPA Kap. 15754"},
               {  32,   "|001MVP Piezo 15753"
                        "|049MVP Piezo 15753"},
               {  33,   "|001MVPA Piezo 15754"
                        "|049MVPA Piezo 15754"},
               {  35,   "|001Levelprobe, CapSensor"
                        "|049Sonde, Kapazitiver-Sensor"},
               {  36,   "|001Levelprobe, PiezoSensor"
                        "|049Sonde, Piezo-Sensor"}
           }
          /* auch WRITE, da zum Schreiben Password notwendig ist  */
           REDEFINE HANDLING READ & WRITE;
       }


       VARIABLE flange_material
       {
           REDEFINE HELP "|001Flange Material- Material of flange type."
                         "|049Flanschmaterial- Material des Flanschtyps";
           REDEFINE TYPE ENUMERATED
           {
               {   0,   [carbon_steel], [carbon_steel_help] },
               {   1,   "|001Stainless Steel 304"
                        "|049Nichtr. Stahl 304"},
               {   2,   "|001Stainless Steel 316"
                        "|049Nichtr. Stahl 316"},
               {   3,   [hastelloy_c], [hastelloy_c_help] },
               {   4,   [monel], [monel_help] },
               {   5,   [tantalum], [tantalum_help] },
               {   6,   "|001Titanium"
                        "|049Titan"},
               {   7,   "|001Platinum-Iridium"
                        "|049Platin-Iridium"},
               {   8,   "|001Alloy 20"
                        "|049Alloy 20"},
               {   9,   "|001Cobalt Chromium Nickel"
                        "|049Kobalt-Chrom-Nickel"},
               {  10,   [ptfe], [ptfe_teflon_help] },
               {  11,   [vito], [viton_help] },
               {  12,   [buna_n], [buna_n_help] },
               {  13,   "|001Ethyl-Prop"
                        "|049Ethyl-Prop"},
               {  14,   "|001Urethane"
                        "|049Urethan"},
               {  15,   "|001Gold Monel Alloy"
                        "|049Gold Monel Alloy"},
               {  16,   "|001Tefzel"
                        "|049Tefzel"},
               {  17,   "|001Ryton"
                        "|049Ryton"},
               {  18,   [ceramic], [ceramic_help] },
               {  19,   [stainless_steel_316l], [stainless_steel_316l_help] },
               {  20,   "|001PVC"
                        "|049PVC"},
               {  21,   "|001Nitrile Rubber"
                        "|049Nitrile Gummi"},
               {  22,   [kalrez], [kalrez_help] },
               {  23,   "|001Inconel"
                        "|049Inconel"},
               {  24,   "|001Kynar"
                        "|049Kynar"},
               {  25,   "|001Aluminium"
                        "|049Aluminium"},
               {  26,   "|001Nickel"
                        "|049Nickel"},
               {  27,   "|001FEP"
                        "|049FEP"},
               {  28,   "|001Stainless Steel 316 Ti"
                        "|049Nichtr. Stahl 316 Ti"},
               {  30,   "|001Hastelloy C276"
                        "|049Hastelloy C276"},
               {  31,   "|001Klinger C4401"
                        "|049Klinger C4401"},
               {  32,   "|001Thermotork"
                        "|049Thermotork"},
               {  33,   "|001Grafoil"
                        "|049Grafoil"},
               {  34,   "|001PTFE coated 316l SST"
                        "|049316l SST PTFE beschichtet"},
               {  35,   "|001Gold plated Hastelloy C276"
                        "|049Hastelloy C276 goldbeschichtet"},
               {  36,   "|001PTFE Glass"
                        "|049PTFE Glass"},
               {  37,   "|001PTFE Graphite"
                        "|049PTFE Graphite"},
               { 129,   "|0011.4571/1.4404"
                        "|0491.4571/1.4404"},
               { 130,   "|001Hastelloy C/1.4571"
                        "|049Hastelloy C/1.4571"},
               { 132,   "|0011.4435/1.4571"
                        "|0491.4435/1.4571"},
               { 133,   "|001Per Fluor Kautschuk"
                        "|049Per Fluor Kautschuk"},
               { 134,   "|00114435"
                        "|04914435"},
               { 135,   "|001AU/1.4404"
                        "|049AU/1.4404"},
               { 136,   "|001Gold plated Monel"
                        "|049Monel goldbeschichtet"},
               { 137,   "|001PVDF"
                        "|049PVDF"},
               { 138,   "|001EPDM"
                        "|049EPDM"},
               { 144,   "|001Steel"
                        "|049Baustahl"},
               { 145,   "|001Stainless Steel, ferritic"
                        "|049nicht rostender Stahl, ferritisch"},
               { 146,   "|001Stainless Steel, austenitic"
                        "|049nicht rostender Stahl, austenitisch"},
               { 147,   "|001Copper based Alloys"
                        "|049Kupferlegierungen"},
               { 148,   "|001Brass"
                        "|049Messing"},
               { 234,   "|001PTFE Hastelloy"
                        "|049PTFE Hastelloy"},
               { 235,   "|001Stainless Steel CF 8M"
                        "|049Stainless Steel CF 8M"},
               { 236,   "|001Hastelloy SST"
                        "|049Hastelloy SST"},
               { 237,   "|001Gold plated SST"
                        "|049SST goldbeschichtet"},
               { 239,   "|001Monel 400"
                        "|049Monel 400"},
               { 250,   "|001Not used"
                        "|049Nicht benutzt"},
               { 251,   [none] },
               { 252,   "|001Unknown"
                        "|049Unbekannt"},
               { 253,   [special] }
           }
       }


       VARIABLE remote_seal_isolator_material
       {
           REDEFINE HELP "|001Remote Seal Isolator Material- Remote seal material of the parts which come "
                         "in contact with the process medium. This is only true so long only 1 remote "
                         "seal is installed."
                         "|049Druckmittlermaterial- Material des Teils vom Druckmittler welches Kontakt "
                         "mit dem Prozestoff hat. Das ist solange eindeutig wie nur 1 Druckmittler "
                         "installiert ist.";
           REDEFINE TYPE ENUMERATED
           {
               {   0,   [carbon_steel], [carbon_steel_help] },
               {   1,   "|001Stainless Steel 304"
                        "|049Nichtr. Stahl 304"},
               {   2,   "|001Stainless Steel 316"
                        "|049Nichtr. Stahl 316"},
               {   3,   [hastelloy_c], [hastelloy_c_help] },
               {   4,   [monel], [monel_help] },
               {   5,   [tantalum], [tantalum_help] },
               {   6,   "|001Titanium"
                        "|049Titan"},
               {   7,   "|001Platinum-Iridium"
                        "|049Platin-Iridium"},
               {   8,   "|001Alloy 20"
                        "|049Alloy 20"},
               {   9,   "|001Cobalt Chromium Nickel"
                        "|049Kobalt-Chrom-Nickel"},
               {  10,   [ptfe], [ptfe_teflon_help] },
               {  11,   [vito], [viton_help] },
               {  12,   [buna_n], [buna_n_help] },
               {  13,   "|001Ethyl-Prop"
                        "|049Ethyl-Prop"},
               {  14,   "|001Urethane"
                        "|049Urethan"},
               {  15,   "|001Gold Monel Alloy"
                        "|049Gold Monel Alloy"},
               {  16,   "|001Tefzel"
                        "|049Tefzel"},
               {  17,   "|001Ryton"
                        "|049Ryton"},
               {  18,   [ceramic], [ceramic_help] },
               {  19,   [stainless_steel_316l], [stainless_steel_316l_help] },
               {  20,   "|001PVC"
                        "|049PVC"},
               {  21,   "|001Nitrile Rubber"
                        "|049Nitrile Gummi"},
               {  22,   [kalrez], [kalrez_help] },
               {  23,   "|001Inconel"
                        "|049Inconel"},
               {  24,   "|001Kynar"
                        "|049Kynar"},
               {  25,   "|001Aluminium"
                        "|049Aluminium"},
               {  26,   "|001Nickel"
                        "|049Nickel"},
               {  27,   "|001FEP"
                        "|049FEP"},
               {  28,   "|001Stainless Steel 316 Ti"
                        "|049Nichtr. Stahl 316 Ti"},
               {  30,   "|001Hastelloy C276"
                        "|049Hastelloy C276"},
               {  31,   "|001Klinger C4401"
                        "|049Klinger C4401"},
               {  32,   "|001Thermotork"
                        "|049Thermotork"},
               {  33,   "|001Grafoil"
                        "|049Grafoil"},
               {  34,   "|001PTFE coated 316l SST"
                        "|049316l SST PTFE beschichtet"},
               {  35,   "|001Gold plated Hastelloy C276"
                        "|049Hastelloy C276 goldbeschichtet"},
               {  36,   "|001PTFE Glass"
                        "|049PTFE Glass"},
               {  37,   "|001PTFE Graphite"
                        "|049PTFE Graphite"},
               { 129,   "|0011.4571/1.4404"
                        "|0491.4571/1.4404"},
               { 130,   "|001Hastelloy C/1.4571"
                        "|049Hastelloy C/1.4571"},
               { 132,   "|0011.4435/1.4571"
                        "|0491.4435/1.4571"},
               { 133,   "|001Per Fluor Kautschuk"
                        "|049Per Fluor Kautschuk"},
               { 134,   "|00114435"
                        "|04914435"},
               { 135,   "|001AU/1.4404"
                        "|049AU/1.4404"},
               { 136,   "|001Gold plated Monel"
                        "|049Monel goldbeschichtet"},
               { 137,   "|001PVDF"
                        "|049PVDF"},
               { 138,   "|001EPDM"
                        "|049EPDM"},
               { 144,   "|001Steel"
                        "|049Baustahl"},
               { 145,   "|001Stainless Steel, ferritic"
                        "|049nicht rostender Stahl, ferritisch"},
               { 146,   "|001Stainless Steel, austenitic"
                        "|049nicht rostender Stahl, austenitisch"},
               { 147,   "|001Copper based Alloys"
                        "|049Kupferlegierungen"},
               { 148,   "|001Brass"
                        "|049Messing"},
               { 234,   "|001PTFE Hastelloy"
                        "|049PTFE Hastelloy"},
               { 235,   "|001Stainless Steel CF 8M"
                        "|049Stainless Steel CF 8M"},
               { 236,   "|001Hastelloy SST"
                        "|049Hastelloy SST"},
               { 237,   "|001Gold plated SST"
                        "|049SST goldbeschichtet"},
               { 239,   "|001Monel 400"
                        "|049Monel 400"},
               { 250,   "|001Not used"
                        "|049Nicht benutzt"},
               { 251,   [none] },
               { 252,   "|001Unknown"
                        "|049Unbekannt"},
               { 253,   [special] }
           }
       }


       VARIABLE module_isolator_material
       {
           REDEFINE HELP "|001Sensor Isolator Material- Material of a part of the sensor which comes in "
                         "contact with the process material."
                         "|049Membranmaterial- Material des Teils vom Sensor welches Kontakt mit dem "
                         "Prozestoff hat.";
           REDEFINE TYPE ENUMERATED
           {
               {   0,   [carbon_steel], [carbon_steel_help] },
               {   1,   "|001Stainless Steel 304"
                        "|049Nichtr. Stahl 304"},
               {   2,   "|001Stainless Steel 316"
                        "|049Nichtr. Stahl 316"},
               {   3,   [hastelloy_c], [hastelloy_c_help] },
               {   4,   [monel], [monel_help] },
               {   5,   [tantalum], [tantalum_help] },
               {   6,   "|001Titanium"
                        "|049Titan"},
               {   7,   "|001Platinum-Iridium"
                        "|049Platin-Iridium"},
               {   8,   "|001Alloy 20"
                        "|049Alloy 20"},
               {   9,   "|001Cobalt Chromium Nickel"
                        "|049Kobalt-Chrom-Nickel"},
               {  10,   [ptfe], [ptfe_teflon_help] },
               {  11,   [vito], [viton_help] },
               {  12,   [buna_n], [buna_n_help] },
               {  13,   "|001Ethyl-Prop"
                        "|049Ethyl-Prop"},
               {  14,   "|001Urethane"
                        "|049Urethan"},
               {  15,   "|001Gold Monel Alloy"
                        "|049Gold Monel Alloy"},
               {  16,   "|001Tefzel"
                        "|049Tefzel"},
               {  17,   "|001Ryton"
                        "|049Ryton"},
               {  18,   [ceramic], [ceramic_help] },
               {  19,   [stainless_steel_316l], [stainless_steel_316l_help] },
               {  20,   "|001PVC"
                        "|049PVC"},
               {  21,   "|001Nitrile Rubber"
                        "|049Nitrile Gummi"},
               {  22,   [kalrez], [kalrez_help] },
               {  23,   "|001Inconel"
                        "|049Inconel"},
               {  24,   "|001Kynar"
                        "|049Kynar"},
               {  25,   "|001Aluminium"
                        "|049Aluminium"},
               {  26,   "|001Nickel"
                        "|049Nickel"},
               {  27,   "|001FEP"
                        "|049FEP"},
               {  28,   "|001Stainless Steel 316 Ti"
                        "|049Nichtr. Stahl 316 Ti"},
               {  30,   "|001Hastelloy C276"
                        "|049Hastelloy C276"},
               {  31,   "|001Klinger C4401"
                        "|049Klinger C4401"},
               {  32,   "|001Thermotork"
                        "|049Thermotork"},
               {  33,   "|001Grafoil"
                        "|049Grafoil"},
               {  34,   "|001PTFE coated 316l SST"
                        "|049316l SST PTFE beschichtet"},
               {  35,   "|001Gold plated Hastelloy C276"
                        "|049Hastelloy C276 goldbeschichtet"},
               {  36,   "|001PTFE Glass"
                        "|049PTFE Glass"},
               {  37,   "|001PTFE Graphite"
                        "|049PTFE Graphite"},
               { 129,   "|0011.4571/1.4404"
                        "|0491.4571/1.4404"},
               { 130,   "|001Hastelloy C/1.4571"
                        "|049Hastelloy C/1.4571"},
               { 132,   "|0011.4435/1.4571"
                        "|0491.4435/1.4571"},
               { 133,   "|001Per Fluor Kautschuk"
                        "|049Per Fluor Kautschuk"},
               { 134,   "|00114435"
                        "|04914435"},
               { 135,   "|001AU/1.4404"
                        "|049AU/1.4404"},
               { 136,   "|001Gold plated Monel"
                        "|049Monel goldbeschichtet"},
               { 137,   "|001PVDF"
                        "|049PVDF"},
               { 138,   "|001EPDM"
                        "|049EPDM"},
               { 144,   "|001Steel"
                        "|049Baustahl"},
               { 145,   "|001Stainless Steel, ferritic"
                        "|049nicht rostender Stahl, ferritisch"},
               { 146,   "|001Stainless Steel, austenitic"
                        "|049nicht rostender Stahl, austenitisch"},
               { 147,   "|001Copper based Alloys"
                        "|049Kupferlegierungen"},
               { 148,   "|001Brass"
                        "|049Messing"},
               { 234,   "|001PTFE Hastelloy"
                        "|049PTFE Hastelloy"},
               { 235,   "|001Stainless Steel CF 8M"
                        "|049Stainless Steel CF 8M"},
               { 236,   "|001Hastelloy SST"
                        "|049Hastelloy SST"},
               { 237,   "|001Gold plated SST"
                        "|049SST goldbeschichtet"},
               { 239,   "|001Monel 400"
                        "|049Monel 400"},
               { 250,   "|001Not used"
                        "|049Nicht benutzt"},
               { 251,   [none] },
               { 252,   "|001Unknown"
                        "|049Unbekannt"},
               { 253,   [special] }
           }
          /* auch WRITE, da zum Schreiben Password notwendig ist  */
           REDEFINE HANDLING READ & WRITE;
       }


       VARIABLE drain_vent_material
       {
           REDEFINE HELP "|001Drain Vent Material- Material of a removable plug in the flange which can "
                         "be opened to remove unwanted process medium from the sensor area."
                         "|049Werkstoff Ventil- Werkstoff des Flanschschiebers, welcher aufgemacht werden "
                         "kann, um unerwnschte Prozestoffe von dem Sensor fernzuhalten.";
           REDEFINE TYPE ENUMERATED
           {
               {   0,   [carbon_steel], [carbon_steel_help] },
               {   1,   "|001Stainless Steel 304"
                        "|049Nichtr. Stahl 304"},
               {   2,   "|001Stainless Steel 316"
                        "|049Nichtr. Stahl 316"},
               {   3,   [hastelloy_c], [hastelloy_c_help] },
               {   4,   [monel], [monel_help] },
               {   5,   [tantalum], [tantalum_help] },
               {   6,   "|001Titanium"
                        "|049Titan"},
               {   7,   "|001Platinum-Iridium"
                        "|049Platin-Iridium"},
               {   8,   "|001Alloy 20"
                        "|049Alloy 20"},
               {   9,   "|001Cobalt Chromium Nickel"
                        "|049Kobalt-Chrom-Nickel"},
               {  10,   [ptfe], [ptfe_teflon_help] },
               {  11,   [vito], [viton_help] },
               {  12,   [buna_n], [buna_n_help] },
               {  13,   "|001Ethyl-Prop"
                        "|049Ethyl-Prop"},
               {  14,   "|001Urethane"
                        "|049Urethan"},
               {  15,   "|001Gold Monel Alloy"
                        "|049Gold Monel Alloy"},
               {  16,   "|001Tefzel"
                        "|049Tefzel"},
               {  17,   "|001Ryton"
                        "|049Ryton"},
               {  18,   [ceramic], [ceramic_help] },
               {  19,   [stainless_steel_316l], [stainless_steel_316l_help] },
               {  20,   "|001PVC"
                        "|049PVC"},
               {  21,   "|001Nitrile Rubber"
                        "|049Nitrile Gummi"},
               {  22,   [kalrez], [kalrez_help] },
               {  23,   "|001Inconel"
                        "|049Inconel"},
               {  24,   "|001Kynar"
                        "|049Kynar"},
               {  25,   "|001Aluminium"
                        "|049Aluminium"},
               {  26,   "|001Nickel"
                        "|049Nickel"},
               {  27,   "|001FEP"
                        "|049FEP"},
               {  28,   "|001Stainless Steel 316 Ti"
                        "|049Nichtr. Stahl 316 Ti"},
               {  30,   "|001Hastelloy C276"
                        "|049Hastelloy C276"},
               {  31,   "|001Klinger C4401"
                        "|049Klinger C4401"},
               {  32,   "|001Thermotork"
                        "|049Thermotork"},
               {  33,   "|001Grafoil"
                        "|049Grafoil"},
               {  34,   "|001PTFE coated 316l SST"
                        "|049316l SST PTFE beschichtet"},
               {  35,   "|001Gold plated Hastelloy C276"
                        "|049Hastelloy C276 goldbeschichtet"},
               {  36,   "|001PTFE Glass"
                        "|049PTFE Glass"},
               {  37,   "|001PTFE Graphite"
                        "|049PTFE Graphite"},
               { 129,   "|0011.4571/1.4404"
                        "|0491.4571/1.4404"},
               { 130,   "|001Hastelloy C/1.4571"
                        "|049Hastelloy C/1.4571"},
               { 132,   "|0011.4435/1.4571"
                        "|0491.4435/1.4571"},
               { 133,   "|001Per Fluor Kautschuk"
                        "|049Per Fluor Kautschuk"},
               { 134,   "|00114435"
                        "|04914435"},
               { 135,   "|001AU/1.4404"
                        "|049AU/1.4404"},
               { 136,   "|001Gold plated Monel"
                        "|049Monel goldbeschichtet"},
               { 137,   "|001PVDF"
                        "|049PVDF"},
               { 138,   "|001EPDM"
                        "|049EPDM"},
               { 144,   "|001Steel"
                        "|049Baustahl"},
               { 145,   "|001Stainless Steel, ferritic"
                        "|049nicht rostender Stahl, ferritisch"},
               { 146,   "|001Stainless Steel, austenitic"
                        "|049nicht rostender Stahl, austenitisch"},
               { 147,   "|001Copper based Alloys"
                        "|049Kupferlegierungen"},
               { 148,   "|001Brass"
                        "|049Messing"},
               { 234,   "|001PTFE Hastelloy"
                        "|049PTFE Hastelloy"},
               { 235,   "|001Stainless Steel CF 8M"
                        "|049Stainless Steel CF 8M"},
               { 236,   "|001Hastelloy SST"
                        "|049Hastelloy SST"},
               { 237,   "|001Gold plated SST"
                        "|049SST goldbeschichtet"},
               { 239,   "|001Monel 400"
                        "|049Monel 400"},
               { 250,   "|001Not used"
                        "|049Nicht benutzt"},
               { 251,   [none] },
               { 252,   "|001Unknown"
                        "|049Unbekannt"},
               { 253,   [special] }
           }
       }


       VARIABLE local_keys_mode_control_codes
       {
           REDEFINE LABEL "|001Loc keys ctrl mode|049Freig. lokale Bed.";
           REDEFINE HELP "|001Local Keys Control Mode- Controls the mode of the User Interface keys on "
                         "the Field Device."
                         "|049Gerteeinstellungs- steuerung- Vorgabe der Betriebsart fr die "
                         "Gertetasten.";
           REDEFINE TYPE ENUMERATED
           {
               {   0,   "|001Off"
                        "|049Aus"},
               {   1,   "|001On"
                        "|049Ein"}
           }
       }


        COMMAND write_upper_sensor_trim      /* Kommando 130 */
        {
            /* Die Dimension wird auf die einheitliche Druckdimension umgestellt  */
            REDEFINE TRANSACTION
            {
                REQUEST
                {
                    pressure_cal_units,sensor_a_upper_sensor_trim_point
                }
                REPLY
                {
                    response_code,
                    device_status,
                    pressure_cal_units,sensor_a_upper_sensor_trim_point
                }
            }
            RESPONSE_CODES
            {
                DELETE 11;
                ADD 17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                ADD 29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
            }
        }


        COMMAND write_lower_sensor_trim      /* Kommando 131 */
        {
            /* Die Dimension wird auf die einheitliche Druckdimension umgestellt  */
            REDEFINE TRANSACTION
            {
                REQUEST
                {
                    pressure_cal_units, sensor_a_lower_sensor_trim_point
                }
                REPLY
                {
                    response_code,
                    device_status,
                    pressure_cal_units, sensor_a_lower_sensor_trim_point
                }
            }
            RESPONSE_CODES
            {
                DELETE 11;
                ADD 17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                ADD 29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
            }
        }
    }
}
