/*****************************************************************************/
/*      Copyright (C)   ABB  All Rights Reserved                             */
/*      Product:                SIMATIC PDM                                  */
/*                                                                           */
/*      Device:         ABB 2600T-263/265                                    */
/*      Communication:  HART                                                 */
/*      File:           PDMTO2600-HART.ddl                                   */
/*      Dictionary:     SIHADC01.dct, PDMTO2600-HART.dct                     */
/*                                                                           */
/*  $Revision:   1.01         $                                              */
/*  $Date:   10 Juli 2003 15:15:15  $                                        */
/*****************************************************************************/
MANUFACTURER    26,
DEVICE_TYPE     137,
DEVICE_REVISION 2,
DD_REVISION     1

/******************************************************************************/
/*    Macros                                                                                                                              */
/******************************************************************************/
#define SENSOR_CAL_METHOD_TABEL         \
                {0x64,  [CAL_VOLUMETRIC]        },\
                {0x65,  [CAL_STATIC_WEIGH]      },\
                {0x66,  [CAL_DYNAMIC_WEIGH]     },\
                {0x67,  [FACT_TRIM_STD_CAL]     },\
                {0x68,  [USER_TRIM_STD_CAL]     },\
                {0x69,  [FACT_TRIM_SPEC_CAL]},\
                {0x6A,  [USER_TRIM_SPEC_CAL]},\
                {0xFF,  [OTHER_CAL]                     }

#define DEF_TRANS_SENSOR_TYPE                           \
                {0x12,  "MVD Piezo AAI"                         },\
                {0x14,  "MVD Kap. 15712"                        },\
                {0x16,  "MVD Piezo 15712"                       },\
                {0x17,  "MVDA Piezo 15713"                      },\
                {0x1C,  "MVD Piezo 15712 100 bar"       },\
                {0x1E,  "MVP Kap. 15753"                        },\
                {0x1F,  "MVPA Kap. 15754"                       },\
                {0x20,  "MVP Piezo 15753"                       },\
                {0x21,  "MVPA Piezo 15754"                      },\
                {0x23,  [sondekapazitiversensor]        },\
                {0x19,  [internaluse]                           }

#define STATUS_OUTPUT_NO_RCAS                           \
                { 0x20, [status_GOOD_00]                },      \
                { 0x21, [status_GOOD_01]                },      \
                { 0x22, [status_GOOD_02]                },      \
                { 0x23, [status_GOOD_03]                },      \
                { 0x24, [status_GOOD_04]                },      \
                { 0x25, [status_GOOD_05]                },      \
                { 0x26, [status_GOOD_06]                }       \
                { 0x28, [status_GOOD_08]                },      \
                { 0x29, [status_GOOD_09]                },      \
                { 0x10, [status_UNCERTAIN_00]   },      \
                { 0x11, [status_UNCERTAIN_01]   },      \
                { 0x12, [status_UNCERTAIN_02]   },      \
                { 0x13, [status_UNCERTAIN_03]   },      \
                { 0x14, [status_UNCERTAIN_04]   },      \
                { 0x15, [status_UNCERTAIN_05]   },      \
                { 0x16, [status_UNCERTAIN_06]   },      \
                { 0x17, [status_UNCERTAIN_07]   },      \
                { 0x00, [status_BAD_00]                 },      \
                { 0x01, [status_BAD_01]                 },      \
                { 0x02, [status_BAD_02]                 },      \
                { 0x03, [status_BAD_03]                 },      \
                { 0x04, [status_BAD_04]                 },      \
                { 0x05, [status_BAD_05]                 },      \
                { 0x06, [status_BAD_06]                 },      \
                { 0x07, [status_BAD_07]                 }

#define STATUS_OUTPUT_LIMIT                                                     \
                { 0x00, [status_limit_OK]                               },      \
                { 0x01, [status_limit_UNDERFLOW]                },      \
                { 0x02, [status_limit_OVERFLOW]                 },      \
                { 0x03, [status_limit_VALUE_CONSTANT]   }


#define DIFFERENTIAL_SENSOR module_type_code == 0x12 || module_type_code == 0x14 ||\
                                                        module_type_code == 0x16 ||  module_type_code == 0x1C\


#define STATIC_SENSOR module_type_code == 0x1E || module_type_code == 0x1F ||module_type_code == 0x17 ||\
                                          module_type_code == 0x20 || module_type_code == 0x21 || module_type_code == 0x23 || module_type_code == 0x23

#define ID_FC_ERROR                     3000


#define STATUS_INPUT_NO_RCAS                            \
                { 0x20, [status_GOOD_00]                },      \
                { 0x21, [status_GOOD_01]                },      \
                { 0x22, [status_GOOD_02]                },      \
                { 0x23, [status_GOOD_03]                },      \
                { 0x24, [status_GOOD_04]                },      \
                { 0x25, [status_GOOD_05]                },      \
                { 0x26, [status_GOOD_06]                },      \
                { 0x28, [status_GOOD_08]                },      \
                { 0x29, [status_GOOD_09]                },      \
                { 0x10, [status_UNCERTAIN_00]   },      \
                { 0x11, [status_UNCERTAIN_01]   },      \
                { 0x12, [status_UNCERTAIN_02]   },      \
                { 0x13, [status_UNCERTAIN_03]   },      \
                { 0x14, [status_UNCERTAIN_04]   },      \
                { 0x15, [status_UNCERTAIN_05]   },      \
                { 0x16, [status_UNCERTAIN_06]   },      \
                { 0x17, [status_UNCERTAIN_07]   },      \
                { 0x00, [status_BAD_00]                 },      \
                { 0x01, [status_BAD_01]                 },      \
                { 0x03, [status_BAD_03]                 },      \
                { 0x04, [status_BAD_04]                 },      \
                { 0x06, [status_BAD_06]                 },      \
                { 0x07, [status_BAD_07]                 }


#define STATUS_INPUT_LIMIT (quality)                                    \
        IF ((quality) == 0x20)                                                          \
        {                                                                                                       \
                { 0x00, [status_limit_OK]                               },              \
                { 0x03, [status_limit_VALUE_CONSTANT]   }               \
        }                                                                                                       \
        ELSE {                                                                                          \
                IF ((quality) == 0x30)                                                  \
                {                                                                                               \
                        { 0x00, [status_limit_OK]                               },      \
                        { 0x03, [status_limit_VALUE_CONSTANT]   }       \
                }                                                                                               \
                 ELSE {                                                                                 \
                        { 0x00, [status_limit_OK]                               },      \
                        { 0x01, [status_limit_UNDERFLOW]                },      \
                        { 0x02, [status_limit_OVERFLOW]                 },      \
                        { 0x03, [status_limit_VALUE_CONSTANT]   }       \
                }                                                                                               \
        }

#define BLOCK_MODE_MAN                          0x10

#define DIA_HW_ELECTR                                           0x01000000              /* 0x00000001 */
#define DIA_HW_MECH                                             0x02000000              /* 0x00000002 */
#define DIA_TEMP_MOTOR                                          0x04000000              /* 0x00000004 */
#define DIA_TEMP_ELECTR                                         0x08000000              /* 0x00000008 */
#define DIA_MEM_CHKSUM                                          0x10000000              /* 0x00000010 */
#define DIA_MEASUREMENT                                         0x20000000              /* 0x00000020 */
#define DIA_NOT_INIT                                            0x40000000              /* 0x00000040 */
#define DIA_INIT_ERR                                            0x80000000              /* 0x00000080 */
#define DIA_ZERO_ERR                                            0x00010000              /* 0x00000100 */
#define DIA_SUPPLY                                              0x00020000              /* 0x00000200 */
#define DIA_CONF_INVAL                                          0x00040000              /* 0x00000400 */
#define DIA_WARMSTART                                           0x00080000              /* 0x00000800 */
#define DIA_COLDSTART                                           0x00100000              /* 0x00001000 */
#define DIA_MAINTENANCE                                         0x00200000              /* 0x00002000 */
#define DIA_CHARACT                                             0x00400000              /* 0x00004000 */
#define DIA_IDENT_VIOL                                          0x00800000              /* 0x00008000 */
#define EXTENSION_AVAILABLE                                     0x00000080              /* 0x80000000 */


/******************************************************************************/
/*    Import HCF-DD                                                                                                                       */
/******************************************************************************/
#include "macros.ddl"
#include "bi_codes.h"

// @@st Import schlgt fehl!!! IMPORT ABB _2000T, DEVICE_REVISION 2, DD_REVISION 1
IMPORT "PDMTO2600imp.ddl"
{
        EVERYTHING;
        REDEFINITIONS
    {
                DELETE UNIT free_process_variable_units_relation;
                DELETE UNIT pressure_unit_relation;
                DELETE UNIT temperature_units_relation;
                DELETE UNIT stat_pressure_units_relation;
                DELETE UNIT process_temp_units_relation;
                /*  Kommando #164  */
                REDEFINE COMMAND read_outscale
                {
                        NUMBER 164;
                        OPERATION READ;
                        TRANSACTION 0
                        {
                                REQUEST
                                {
                                        2
                                }
                                REPLY
                                {
                                        response_code, device_status,
                                        2, aidp_outscale_units, aidp_outscale_100, aidp_outscale_0,
                                        aidp_outscale_decimal
                                }
                        }
                        TRANSACTION 1
                        {
                                REQUEST
                                {
                                        13
                                }
                                REPLY
                                {
                                        response_code, device_status,
                                        13, static_pressure_units, static_pressure_upper_range_value, static_pressure_lower_range_value,
                                        static_pressure_decimal
                                }
                        }
                        TRANSACTION 2
                        {
                                REQUEST
                                {
                                        14
                                }
                                REPLY
                                {
                                        response_code, device_status,
                                        14, 0, static_pressure_hi_lim, static_pressure_lo_lim,
                                        0
                                }
                        }

                        TRANSACTION 3
                        {
                                REQUEST
                                {
                                        7
                                }
                                REPLY
                                {
                                        response_code, device_status,
                                        7, ptrbScaleOutUnit, ptrbScaleOut100, ptrbScaleOut0,ptrbScaleOutDecimal

                                        0
                                }
                        }
                        TRANSACTION 4
                        {
                                REQUEST
                                {
                                        1
                                }
                                REPLY
                                {
                                        response_code, device_status,
                                        1, aiDPXdScaleUnitFF, aiDPXdScale100, aiDPXdScale0,
                                        aiDPXdScaleDecimalFF
                                }
                        }

                        TRANSACTION 5
                        {
                                REQUEST
                                {
                                        12
                                }
                                REPLY
                                {
                                        response_code, device_status,
                                        12, aiPOutScaleUnit, aiPOutScale100, aiPOutScale0,
                                        aiPOutScaleDecimal
                                }
                        }

                        RESPONSE_CODES
                        {
                                0,      SUCCESS,                        [no_command_specific_errors];
                                2,      DATA_ENTRY_ERROR,       [invalid_selection];
                                3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
                                4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                                7,      MODE_ERROR,                     [in_write_protect_mode];
                                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                                14,     DATA_ENTRY_WARNING,     [span_too_small];
                                16,     MODE_ERROR,                     [access_restricted];
                                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
                        }
                }

                /*  Kommando #165  */

                REDEFINE COMMAND write_outscale
                {
                        NUMBER 165;
                        OPERATION WRITE;
                        TRANSACTION 0
                        {
                                REQUEST
                                {
                                        2, aidp_outscale_units, aidp_outscale_100, aidp_outscale_0,
                                        aidp_outscale_decimal
                                }
                                REPLY
                                {
                                        response_code, device_status,
                                        2, aidp_outscale_units, aidp_outscale_100, aidp_outscale_0,
                                        aidp_outscale_decimal
                                }
                        }
                        TRANSACTION 1
                        {
                                REQUEST
                                {
                                        13, static_pressure_units, static_pressure_upper_range_value, static_pressure_lower_range_value,
                                        static_pressure_decimal
                                }
                                REPLY
                                {
                                        response_code, device_status,
                                        13, static_pressure_units, static_pressure_upper_range_value, static_pressure_lower_range_value,
                                        static_pressure_decimal
                                }
                        }
                        TRANSACTION 3
                        {
                                REQUEST
                                {
                                        7, ptrbScaleOutUnit, ptrbScaleOut100, ptrbScaleOut0,ptrbScaleOutDecimal
                                }
                                REPLY
                                {
                                        response_code, device_status,
                                        7, ptrbScaleOutUnit, ptrbScaleOut100, ptrbScaleOut0,ptrbScaleOutDecimal

                                        0
                                }
                        }
                        TRANSACTION 4
                        {
                                REQUEST
                                {
                                        14, 0, static_pressure_hi_lim, static_pressure_lo_lim,
                                        0
                                }
                                REPLY
                                {
                                        response_code, device_status,
                                        14, 0, static_pressure_hi_lim, static_pressure_lo_lim,
                                        0
                                }
                        }

                        TRANSACTION 4
                        {
                                REQUEST
                                {
                                        1, aiDPXdScaleUnitFF, aiDPXdScale100, aiDPXdScale0,
                                        aiDPXdScaleDecimalFF
                                }
                                REPLY
                                {
                                        response_code, device_status,
                                        1, aiDPXdScaleUnitFF, aiDPXdScale100, aiDPXdScale0,
                                        aiDPXdScaleDecimalFF
                                }
                        }

                        TRANSACTION 5
                        {
                                REQUEST
                                {
                                        12, aiPOutScaleUnit, aiPOutScale100, aiPOutScale0,
                                        aiPOutScaleDecimal
                                }
                                REPLY
                                {
                                        response_code, device_status,
                                        12, aiPOutScaleUnit, aiPOutScale100, aiPOutScale0,
                                        aiPOutScaleDecimal
                                }
                        }
                        RESPONSE_CODES
                        {
                                0,      SUCCESS,                        [no_command_specific_errors];
                                2,      DATA_ENTRY_ERROR,       [invalid_selection];
                                3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
                                4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                                7,      MODE_ERROR,                     [in_write_protect_mode];
                                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                                14,     DATA_ENTRY_WARNING,     [span_too_small];
                                16,     MODE_ERROR,                     [access_restricted];
                                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
                        }
                }

        COMMAND read_additional_transmitter_status
        {
             REDEFINE TRANSACTION
             {
                 REQUEST
                     {
                     }
                 REPLY
                     {
                         response_code, device_status,
                         xmtr_specific_status_0, xmtr_specific_status_1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                         diagnosis, diagnosis1, 0, 0,
                         diagnosisExtension, diagnosisExtension1,
                         diagnosisExtension2, diagnosisExtension3,
                         0, 0
                     }
                 RESPONSE_CODES
                     {
                         0, SUCCESS, [no_command_specific_errors];
                     }
             }
        }
                /*  Kommando #133  */

                REDEFINE COMMAND read_sensor_temp
                {
                        NUMBER 133;
                        OPERATION READ;
                        TRANSACTION
                        {
                                REQUEST
                                { }
                                REPLY
                                {
                                        response_code, device_status,
                                        ptrbModeBlkActual, ptrbPrimaryValue, /*ptrbPrimaryValueStatus*/
                                        ptrbPrimaryValueStatus_quality<0xFC>,
                                        ptrbPrimaryValueStatus_limit<0x03>,
                                        ptrbTrimmedValue,
                                        ptrbTrimmedValueStatus_quality<0xFC>,
                                        ptrbTrimmedValueStatus_limit<0x03>,
                                        ptrbSecondaryValue1Status_quality<0xFC>,
                                        ptrbSecondaryValue1Status_limit<0x03>,
                                        ptrbStaticPressureValueStatus_quality<0xFC>,
                                        ptrbStaticPressureValueStatus_limit<0x03>,
                                        ptrbTemperatureValueV21, ptrbTemperatureValueUnitV21,
                                        ptrbTemperatureValueStatus_quality<0xFC>,
                                        ptrbTemperatureValueStatus_limit<0x03>,
                                        ptrbSensorValue, 0,
                                }
                        }
                        RESPONSE_CODES
                        {
                                0, SUCCESS, [no_command_specific_errors];
                        }
                }
                VARIABLE device_status
                {
                        REDEFINE LABEL [device_status];
                }

                VARIABLE diagnosisExtension
                {
                        REDEFINE LABEL [diagnosisExt];
                }

                VARIABLE diagnosisExtension1
                {
                        REDEFINE LABEL [diagnosisExt1];
                }

                VARIABLE diagnosisExtension2
                {
                        REDEFINE LABEL [diagnosisExt2];
                }

                VARIABLE stat_press_sensor_lower_sensor_trim_point
                {
                        REDEFINE HELP [trans_cal_point_lo_help];
                        REDEFINE LABEL [trans_cal_point_lo];
                        DELETE VALIDITY;
                }

                VARIABLE stat_press_sensor_upper_sensor_trim_point
                {
                        REDEFINE HELP [trans_cal_point_hi_help];
                        REDEFINE LABEL [trans_cal_point_hi];
                        DELETE VALIDITY;
                }
                VARIABLE pressure_units
                {
                        REDEFINE TYPE ENUMERATED
                        {
                                DEFAULT_VALUE 8;
                                {    1,   "|001inH2O"
                                                  "|049inH2O"},
                                {    2,   "|001inHg"
                                                  "|049inHg"},
                                {    3,   "|001ftH2O"
                                                  "|049ftH2O"},
                                {    4,   "|001mmH2O"
                                                  "|049mmH2O"},
                                {    5,   "|001mmHg"
                                                  "|049mmHg"},
                                {    6,   "|001psi"
                                                  "|049psi"},
                                {    7,   "|001bar"
                                                  "|049bar"},
                                {    8,   "|001mbar"
                                                  "|049mbar"},
                                {    9,   "|001g/cm2"
                                                  "|049g/cm2"},
                                {   10,   "|001kg/cm2"
                                                  "|049kg/cm2"},
                                {   11,   "|001Pa"
                                                  "|049Pa"},
                                {   12,   "|001kPa"
                                                  "|049kPa"},
                                {   13,   "|001torr"
                                                  "|049torr"},
                                {   14,   "|001atm"
                                                  "|049atm"},
                                {  237,   "|001MPa"
                                                  "|049MPa"},
                                {  253,   "|001special"
                                                  "|049Spezial"}
                        }
                        ADD POST_EDIT_ACTIONS
                        {
                                method_assignment_unit
                        }
                        ADD POST_READ_ACTIONS
                        {
                                method_assignment_unit
                        }

                }

                VARIABLE ptrbStaticPressureMinSpan
                {
                        REDEFINE LABEL [trans_cal_min_span];
                        REDEFINE HELP [trans_cal_min_span];
                }

                VARIABLE static_pressure_upper_range_value
                {
                        REDEFINE LABEL [ptrbstaticpressurescalein100];
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE  local_static_pressure_upper_range_value;
                                // @@st riskant MIN_VALUE       (local_static_pressure_lower_range_value);
                                // @@st riskant MAX_VALUE       (local_static_pressure_upper_range_value);
                        }
                        REDEFINE VALIDITY IF (DIFFERENTIAL_SENSOR)
                        {
                                TRUE;
                        }
                        ELSE
                        {
                                FALSE;
                        }

                }

                VARIABLE static_pressure_lower_range_value
                {
                        REDEFINE LABEL [ptrbstaticpressurescalein0];
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE  local_static_pressure_lower_range_value;
                                // @@st riskant MIN_VALUE       (local_static_pressure_lower_range_value);
                                // @@st riskant MAX_VALUE       (local_static_pressure_upper_range_value);
                        }
                        REDEFINE VALIDITY IF (DIFFERENTIAL_SENSOR)
                        {
                                TRUE;
                        }
                        ELSE
                        {
                                FALSE;
                        }

                }

               VARIABLE ptrbTabActualNumber
                {
                        REDEFINE LABEL [ptrbTabActualNumber];
                        REDEFINE TYPE INTEGER
                        {      // @@st auskommentieren
                                DEFAULT_VALUE 1;
                                MIN_VALUE       0;
                                MAX_VALUE       20;
                        }
                }

                VARIABLE module_type_code
                {
                        REDEFINE LABEL [module_type_code];
                    REDEFINE HANDLING READ;
                        REDEFINE TYPE ENUMERATED
                        {
                                DEF_TRANS_SENSOR_TYPE
                        }
                }

                VARIABLE static_pressure_lo_lim
                {
                        REDEFINE LABEL [static_pressure_lo_lim];
                        REDEFINE TYPE   FLOAT
                        {
                                DELETE DISPLAY_FORMAT;
                                DEFAULT_VALUE   0.0;
                        }
                        REDEFINE  VALIDITY IF (/*module_type_code >= 30*/ DIFFERENTIAL_SENSOR )
                        {
                                TRUE;
                        }
                        ELSE
                        {
                                FALSE;
                        }
                        ADD POST_EDIT_ACTIONS
                        {
                                method_edit_local_static_pressure_lower_range_value
                        }
                        ADD POST_READ_ACTIONS
                        {
                                method_read_local_static_pressure_lower_range_value
                        }

                        REDEFINE  HANDLING READ & WRITE;
                }

                VARIABLE static_pressure_hi_lim
                {
                        REDEFINE LABEL [static_pressure_hi_lim];
                        REDEFINE TYPE   FLOAT
                        {
                                DELETE DISPLAY_FORMAT;
                                DEFAULT_VALUE   411000.0;
                        }
                        REDEFINE  VALIDITY IF (/*module_type_code >= 30*/ DIFFERENTIAL_SENSOR )
                        {
                                TRUE;
                        }
                        ELSE
                        {
                                FALSE;
                        }
                        ADD POST_EDIT_ACTIONS
                        {
                                method_edit_local_static_pressure_upper_range_value
                        }
                        ADD POST_READ_ACTIONS
                        {
                                method_read_local_static_pressure_upper_range_value
                        }
                        REDEFINE  HANDLING READ & WRITE;
                }

                VARIABLE pressure_lower_range_limit
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DELETE DISPLAY_FORMAT;
                                DEFAULT_VALUE   0.0;
                        }
                        ADD POST_EDIT_ACTIONS
                        {
                                method_assignment1
                        }
                        ADD POST_READ_ACTIONS
                        {
                                method_assignment1
                        }
                }

                VARIABLE pressure_upper_range_limit
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DELETE DISPLAY_FORMAT;
                                DEFAULT_VALUE   100.0;
                        }
                        ADD POST_EDIT_ACTIONS
                        {
                                method_assignment2
                        }
                        ADD POST_READ_ACTIONS
                        {
                                method_assignment2
                        }
                }

                VARIABLE static_pressure_units
                {
                        REDEFINE LABEL [static_pressure_units];
                        REDEFINE VALIDITY IF (DIFFERENTIAL_SENSOR)
                        {
                                TRUE;
                        }
                        ELSE
                        {
                                FALSE;
                        }

                        REDEFINE   TYPE ENUMERATED
                        {
                                DEFAULT_VALUE  7;
                                {    1,   "|001inH2O"
                                                  "|049inH2O"},
                                {    2,   "|001inHg"
                                                  "|049inHg"},
                                {    3,   "|001ftH2O"
                                                  "|049ftH2O"},
                                {    4,   "|001mmH2O"
                                                  "|049mmH2O"},
                                {    5,   "|001mmHg"
                                                  "|049mmHg"},
                                {    6,   "|001psi"
                                                  "|049psi"},
                                {    7,   "|001bar"
                                                  "|049bar"},
                                {    8,   "|001mbar"
                                                  "|049mbar"},
                                {    9,   "|001g/cm2"
                                                  "|049g/cm2"},
                                {   10,   "|001kg/cm2"
                                                  "|049kg/cm2"},
                                {   11,   "|001Pa"
                                                  "|049Pa"},
                                {   12,   "|001kPa"
                                                  "|049kPa"},
                                {   13,   "|001torr"
                                                  "|049torr"},
                                {   14,   "|001atm"
                                                  "|049atm"},
                                {  237,   "|001MPa"
                                                  "|049MPa"},
                                {  253,   "|001special"
                                                  "|049Spezial"}
                        }

                        ADD POST_EDIT_ACTIONS
                        {
                                method_static_pressure_units
                        }
                        ADD POST_READ_ACTIONS
                        {
                                method_static_pressure_units
                        }
                }

                VARIABLE remote_seal_fill_fluid
                {
                   LABEL [remote_seal_fill_fluid];
                   TYPE ENUMERATED
                   {
                           DEFAULT_VALUE 251;
                           {   1,   [silicone_oil] },
                           {   2,   "|001Fluor carbon"
                                                "|049Fluorkohlenstoff" },
                           {   3,   "|001Destilled water"
                                                "|049Destilliertes Wasser" },
                           {   4,   "|001High temperature oil"
                                                "|049Hochtemperaturl" },
                           {   5,   "|001Vegetable Oil"
                                                "|049Pflanzenl"},
                           {   6,   "|001Mineral oil"
                                                "|049Minerall"},
                           {   7,   "|001White oil"
                                                "|049Weissl"},
                           {   8,   "|001Fill fluid FDA certified"
                                                "|049Fllflssigkeit FDA zugelassen"},
                           {   9,   "|001Fill fluid ABB"
                                                "|049Fllflssigkeit ABB"},
                           { 251,   [none] },
                           { 253,   [special] }
                   }
                }

                VARIABLE remote_seal_type
                {
                   REDEFINE HELP "|001Remote Seal Type- Type of remote seal connected to the device. This is only "
                                                 "true when only 1 remote seal is installed."
                                                 "|049Druckmittler Typ- Art des am Feldgert angeschlossenen Druckfhlers. Diese "
                                                 "Angabe ist eindeutig wenn nicht mehr als ein Druckfhler angeschlossen ist.";
                   REDEFINE TYPE ENUMERATED
                   {
                           DEFAULT_VALUE 251;
                           {   1,   "|001Flush diaphragm DN 25"
                                                "|049Flachmembran DN 25" },
                           {   2,   "|001Fl. diaphr. ANSI 1''"
                                                "|049Flachmembr. ANSI 1''" },
                           {   3,   "|001Fl. diaphragm DN 50"
                                                "|049Flachmembran DN 50" },
                           {   4,   "|001Fl. diaphr. ANSI 2''"
                                                "|049Flachmembr. ANSI 2''" },
                           {   5,   "|001Fl. diaphragm DN 80"
                                                "|049Flachmembran DN 80" },
                           {   6,   "|001Fl. diaphr. ANSI 3''"
                                                "|049Flachmembr. ANSI 3''" },
                           {   7,   "|001Ext. diaphragm DN 50"
                                                "|049Tubus DN 50" },
                           {   8,   "|001Ext.diaphr. ANSI 2''"
                                                "|049Tubus ANSI 2''" },
                           {   9,   "|001Ext. diaphragm DN 80"
                                                "|049Tubus DN 80" },
                           {  10,   "|001Ext.diaphr. ANSI 3''"
                                                "|049Tubus ANSI 3''" },
                           {  11,   "|001Tube RS DN25/ANSI1''"
                                                "|049Rohr-DF DN25/ANSI1''" },
                           {  12,   "|001Tube RS DN40/1.5''"
                                                "|049Rohr-DF DN40/1,5''" },
                           {  13,   "|001Tube RS DN50/2'' "
                                                "|049Rohr-DF DN50/2''" },
                           {  14,   "|001Tube RS DN80/3'' "
                                                "|049Rohr-DF DN80/3''" },
                           {  15,   "|001RS w. cap screw DN50"
                                                "|049DF Nutberwurfm DN50" },
                           {  16,   "|001RS clamp connect.2''"
                                                "|049DF Clamp-Anschl. 2''" },
                           {  17,   "|001Miniature RS G 1 A"
                                                "|049Klein-DF G 1 A" },
                           {  18,   "|001Miniature RS G 1/2 A"
                                                "|049Klein-DF G 1/2 A" },
                           { 251,   [none] },
                           { 253,   [special] }
                   }
                }

                VARIABLE pressure_lower_range_value
                {
                        REDEFINE TYPE  FLOAT
                        {
                                DEFAULT_VALUE  local_pressure_sensor_min;
                                // @@st riskant MIN_VALUE       (local_pressure_sensor_min);
                                // @@st riskant MAX_VALUE       (local_pressure_sensor_max);
                        }
                }

                VARIABLE pressure_upper_range_value
                {
                        REDEFINE TYPE  FLOAT
                        {
                                DEFAULT_VALUE  local_pressure_sensor_max;
                                // @@st riskant MIN_VALUE       (local_pressure_sensor_min);
                                // @@st riskant MAX_VALUE       (local_pressure_sensor_max);
                        }
                }

                VARIABLE pressure_sensor_units
                {
                        REDEFINE TYPE ENUMERATED
                        {
                                DEFAULT_VALUE 8;
                                UNITS_CODE (1),         /* inches H2O @ 68 degrees Fahrenheit */
                                UNITS_CODE (2),         /* inches Hg @ 0 degrees Celsius */
                                UNITS_CODE (3),         /* feet H2O @ 68 degrees Fahrenheit */
                                UNITS_CODE (4),         /* millimeters H2O @ 68 degrees Fahrenheit*/
                                UNITS_CODE (5),         /* millimeters Hg @ 0 degrees Celsius */
                                UNITS_CODE (6),         /* pounds/square inch */
                                UNITS_CODE (7),         /* bars */
                                UNITS_CODE (8),         /* millibars */
                                UNITS_CODE (9),         /* grams/square centimeter */
                                UNITS_CODE (10),        /* kilograms/square centimeter */
                                UNITS_CODE (11),        /* pascals */
                                UNITS_CODE (12),        /* kilopascals */
                                UNITS_CODE (13),        /* torr @ 0 degrees Celsius */
                                UNITS_CODE (14),        /* atmospheres */
                                UNITS_CODE (237),       /* megapascals (ABB-Kent) */
                                UNITS_CODE (238),       /* in H2O @ 4 Degrees Celsius (ABB-Kent) */
                                UNITS_CODE (239),       /* mm H2O @ 4 Degrees Celsius (ABB-Kent) */
                                {251,  [none] },
                                {252,  [unknown] },
                                {253,  [special] }
                        }

                        REDEFINE HANDLING READ & WRITE;
                }

                VARIABLE ptrbLowFlowCutOff
                {
                        REDEFINE LABEL [ptrbLowFlowCutOff];
                }

                VARIABLE ptrbFlowLinSqrtPoint
                {
                        REDEFINE LABEL [ptrbFlowLinSqrtPoint];
                        REDEFINE TYPE FLOAT
                        {
                                DEFAULT_VALUE 5.0;
                                MIN_VALUE 5.0;
                                MAX_VALUE 20.0;
                        }
                }

                VARIABLE ptrbFlowLinSqrtPoint
                {
                        REDEFINE LABEL [ptrbFlowLinSqrtPoint];
                }

                VARIABLE aidp_outscale_units
                {
                        REDEFINE LABEL [units];
                        REDEFINE TYPE ENUMERATED
                        {
                                DEFAULT_VALUE 57;
                                {    1,  "|001inH2O"
                                                 "|049inH2O"},
                                {    2,  "|001inHg"
                                                 "|049inHg"},
                                {    3,  "|001ftH2O"
                                                 "|049ftH2O"},
                                {    4,  "|001mmH2O"
                                                 "|049mmH2O"},
                                {    5,  "|001mmHg"
                                                 "|049mmHg"},
                                {    6,  "|001psi"
                                                 "|049psi"},
                                {    7,  "|001bar"
                                                 "|049bar"},
                                {    8,  "|001mbar"
                                                 "|049mbar"},
                                {    9,  "|001g/cm2"
                                                 "|049g/cm2"},
                                {   10,  "|001kg/cm2"
                                                 "|049kg/cm2"},
                                {   11,  "|001Pa"
                                                 "|049Pa"},
                                {   12,  "|001kPa"
                                                 "|049kPa"},
                                {   13,  "|001torr"
                                                 "|049torr"},
                                {   14,  "|001atm"
                                                 "|049atm"},
                                {   15,  "|001CFM"
                                                 "|049CFM"},
                                {   16,  "|001GPM"
                                                 "|049GPM"},
                                {   17,  "|001L/min"
                                                 "|049L/min"},
                                {   18,  "|001ImpGal/min"
                                                 "|049ImpGal/min"},
                                {   19,  "|001m3/h"
                                                 "|049m3/h"},
                                {   20,  "|001ft/s"
                                                 "|049ft/s"},
                                {   21,  "|001m/s"
                                                 "|049m/s"},
                                {   22,  "|001gal/s"
                                                 "|049gal/s"},
                                {   23,  "|001Mgal/d"
                                                 "|049Mgal/d"},
                                {   24,  "|001L/s"
                                                 "|049L/s"},
                                {   25,  "|001ML/d"
                                                 "|049ML/d"},
                                {   26,  "|001CFS"
                                                 "|049CFS"},
                                {   27,  "|001ft3/d"
                                                 "|049ft3/d"},
                                {   28,  "|001m3/s"
                                                 "|049m3/s"},
                                {   29,  "|001m3/d"
                                                 "|049m3/d"},
                                {   30,  "|001ImpGal/h"
                                                 "|049ImpGal/h"},
                                {   31,  "|001ImpGal/d"
                                                 "|049ImpGal/d"},
                                {   32,  "|001C"
                                                 "|049C"},
                                {   33,  "|001F"
                                                 "|049F"},
                                {   34,  "|001R"
                                                 "|049R"},
                                {   35,  "|001K"
                                                 "|049K"},
                                {   36,  "|001mV"
                                                 "|049mV"},
                                {   37,  "|001Ohm"
                                                 "|049Ohm"},
                                {   38,  "|001Hz"
                                                 "|049Hz"},
                                {   39,  "|001mA"
                                                 "|049mA"},
                                {   40,  "|001gallon"
                                                 "|049gallon"},
                                {   41,  "|001L"
                                                 "|049L"},
                                {   42,  "|001ImpGal"
                                                 "|049ImpGal"},
                                {   43,  "|001m3"
                                                 "|049m3"},
                                {   44,  "|001ft"
                                                 "|049ft"},
                                {   45,  "|001m"
                                                 "|049m"},
                                {   46,  "|001bbl"
                                                 "|049bbl"},
                                {   47,  "|001in"
                                                 "|049in"},
                                {   48,  "|001cm"
                                                 "|049cm"},
                                {   49,  "|001mm"
                                                 "|049mm"},
                                {   50,  "|001min"
                                                 "|049min"},
                                {   51,  "|001s"
                                                 "|049s"},
                                {   52,  "|001h"
                                                 "|049h"},
                                {   53,  "|001d"
                                                 "|049d"},
                                {   54,  "|001cSt"
                                                 "|049cSt"},
                                {   55,  "|001cP"
                                                 "|049cP"},
                                {   56,  "|001uS"
                                                 "|049uS"},
                                {   57,  "|001%"
                                                 "|049%"},
                                {   58,  "|001V"
                                                 "|049V"},
                                {   59,  "|001pH"
                                                 "|049pH"},
                                {   60,  "|001g"
                                                 "|049g"},
                                {   61,  "|001kg"
                                                 "|049kg"},
                                {   62,  "|001t"
                                                 "|049t"},
                                {   63,  "|001lb"
                                                 "|049lb"},
                                {   64,  "|001STon"
                                                 "|049STon"},
                                {   65,  "|001LTon"
                                                 "|049LTon"},
                                {   66,  "|001mS/cm"
                                                 "|049mS/cm"},
                                {   67,  "|001uS/mm"
                                                 "|049uS/mm"},
                                {   70,  "|001g/s"
                                                 "|049g/s"},
                                {   71,  "|001g/min"
                                                 "|049g/min"},
                                {   72,  "|001g/h"
                                                 "|049g/h"},
                                {   73,  "|001kg/s"
                                                 "|049kg/s"},
                                {   74,  "|001kg/min"
                                                 "|049kg/min"},
                                {   75,  "|001kg/h"
                                                 "|049kg/h"},
                                {   76,  "|001kg/d"
                                                 "|049kg/d"},
                                {   77,  "|001t/min"
                                                 "|049t/min"},
                                {   78,  "|001t/h"
                                                 "|049t/h"},
                                {   79,  "|001t/d"
                                                 "|049t/d"},
                                {   80,  "|001lb/s"
                                                 "|049lb/s"},
                                {   81,  "|001lb/min"
                                                 "|049lb/min"},
                                {   82,  "|001lb/h"
                                                 "|049lb/h"},
                                {   83,  "|001lb/d"
                                                 "|049lb/d"},
                                {   84,  "|001STon/min"
                                                 "|049STon/min"},
                                {   85,  "|001STon/h"
                                                 "|049STon/h"},
                                {   86,  "|001STon/d"
                                                 "|049STon/d"},
                                {   87,  "|001LTon/h"
                                                 "|049LTon/h"},
                                {   88,  "|001LTon/d"
                                                 "|049LTon/d"},
                                {   89,  "|001decatherm"
                                                 "|049decatherm"},
                                {   90,  "|001SGU"
                                                 "|049SGU"},
                                {   91,  "|001g/cm3"
                                                 "|049g/cm3"},
                                {   92,  "|001kg/m3"
                                                 "|049kg/m3"},
                                {   93,  "|001lb/gal"
                                                 "|049lb/gal"},
                                {   94,  "|001lb/ft3"
                                                 "|049lb/ft3"},
                                {   95,  "|001g/ml"
                                                 "|049g/ml"},
                                {   96,  "|001kg/L"
                                                 "|049kg/L"},
                                {   97,  "|001g/L"
                                                 "|049g/L"},
                                {   98,  "|001lb/in3"
                                                 "|049lb/in3"},
                                {   99,  "|001STon/yd3"
                                                 "|049STon/yd3"},
                                {  100,  "|001degTwad"
                                                 "|049degTwad"},
                                {  101,  "|001degBrix"
                                                 "|049degBrix"},
                                {  102,  "|001degBaum hv"
                                                 "|049degBaum hv"},
                                {  103,  "|001degBaum lt"
                                                 "|049degBaum lt"},
                                {  104,  "|001degAPI"
                                                 "|049degAPI"},
                                {  105,  "|001% sol/wt"
                                                 "|049% sol/wt"},
                                {  106,  "|001% sol/vol"
                                                 "|049% sol/vol"},
                                {  107,  "|001degBall"
                                                 "|049degBall"},
                                {  108,  "|001proof/vol"
                                                 "|049proof/vol"},
                                {  109,  "|001proof/mass"
                                                 "|049proof/mass"},
                                {  110,  "|001bushel"
                                                 "|049bushel"},
                                {  111,  "|001yd3"
                                                 "|049yd3"},
                                {  112,  "|001ft3"
                                                 "|049ft3"},
                                {  113,  "|001in3"
                                                 "|049in3"},
                                {  120,  "|001m/h"
                                                 "|049m/h"},
                                {  121,  "|001Nm3/h"
                                                 "|049Nm3/h"},
                                {  122,  "|001NL/h"
                                                 "|049NL/h"},
                                {  123,  "|001SCFM"
                                                 "|049SCFM"},
                                {  124,  "|001bbl (liq)"
                                                 "|049bbl (liq)"},
                                {  125,  "|001oz"
                                                 "|049oz"},
                                {  126,  "|001ft-lb"
                                                 "|049ft-lb"},
                                {  127,  "|001KW"
                                                 "|049KW"},
                                {  128,  "|001KWH"
                                                 "|049KWH"},
                                {  129,  "|001hp"
                                                 "|049hp"},
                                {  130,  "|001CFH"
                                                 "|049CFH"},
                                {  131,  "|001m3/min"
                                                 "|049m3/min"},
                                {  132,  "|001bbl/s"
                                                 "|049bbl/s"},
                                {  133,  "|001bbl/min"
                                                 "|049bbl/min"},
                                {  134,  "|001bbl/h"
                                                 "|049bbl/h"},
                                {  135,  "|001bbl/d"
                                                 "|049bbl/d"},
                                {  136,  "|001gal/h"
                                                 "|049gal/h"},
                                {  137,  "|001ImpGal/s"
                                                 "|049ImpGal/s"},
                                {  138,  "|001L/h"
                                                 "|049L/h"},
                                {  139,  "|001ppm"
                                                 "|049ppm"},
                                {  140,  "|001Mcal/h"
                                                 "|049Mcal/h"},
                                {  141,  "|001MJ/h"
                                                 "|049MJ/h"},
                                {  142,  "|001Btu/h"
                                                 "|049Btu/h"},
                                {  150,  "|001% stm qual"
                                                 "|049% stm qual"},
                                {  152,  "|001ft3/lb"
                                                 "|049ft3/lb"},
                                {  153,  "|001pF"
                                                 "|049pF"},
                                {  160,  "|001% plato"
                                                 "|049% plato"},
                                {  162,  "|001Mcal"
                                                 "|049Mcal"},
                                {  163,  "|001kOhm"
                                                 "|049kOhm"},
                                {  164,  "|001MJ"
                                                 "|049MJ"},
                                {  165,  "|001Btu"
                                                 "|049Btu"},
                                {  166,  "|001Nm3"
                                                 "|049Nm3"},
                                {  167,  "|001NL"
                                                 "|049NL"},
                                {  168,  "|001Sft3"
                                                 "|049Sft3"},
                                {  235,  "|001gal/d"
                                                 "|049gal/d"},
                                {  236,  "|001hl"
                                                 "|049hl"},
                                {  237,  "|001MPa"
                                                 "|049MPa"},
                                {  238,  "|001inH2O (4C)"
                                                 "|049inH2O (4C)"},
                                {  239,  "|001mmH2O (4C)"
                                                 "|049mmH2O (4C)"},
                                {  240,  "|001W"
                                                 "|049W"},
                                {  241,  "|001MW"
                                                 "|049MW"},
                                {  245,  "|001WH"
                                                 "|049WH"},
                                {  246,  "|001MWH"
                                                 "|049MWH"},
                                {  247,  "|001J"
                                                 "|049J"},
                                {  248,  "|001kJ"
                                                 "|049kJ"},
                                {  249,  "|001kJ/kg"
                                                 "|049kJ/kg"},
                                {  253,  "|001special"
                                                 "|049Spezial"}
                        }
                }

                VARIABLE diagnosis
                {
                        REDEFINE LABEL [diagnosis];
                        REDEFINE TYPE   BIT_ENUMERATED (4)
                        {
                                DEFAULT_VALUE    0x00000000;
                                {       0,                              [dia_OK],                                       [dia_OK_help]                                   },
                                {       DIA_HW_ELECTR,          [dia_HW_ELECTR],                        [dia_HW_ELECTR_help]                    },
                                {       DIA_HW_MECH,            [dia_HW_MECH],                          [dia_HW_MECH_help]                              },
                                {       DIA_TEMP_MOTOR,         [dia_TEMP_MOTOR],                       [dia_TEMP_MOTOR_help]                   },
                                {       DIA_TEMP_ELECTR,                [dia_TEMP_ELECTR],                      [dia_TEMP_ELECTR_help]                  },
                                {       DIA_MEM_CHKSUM,         [dia_MEM_CHKSUM],                       [dia_MEM_CHKSUM_help]                   },
                                {       DIA_MEASUREMENT,                [dia_MEASUREMENT],                      [dia_MEASUREMENT_help]                  },
                                {       DIA_NOT_INIT,                   [dia_NOT_INIT],                         [dia_NOT_INIT_help]                             },
                                {       DIA_INIT_ERR,                   [dia_INIT_ERR],                         [dia_INIT_ERR_help]                             },
                                {       DIA_ZERO_ERR,                   [dia_ZERO_ERR],                         [dia_ZERO_ERR_help]                             },
                                {       DIA_SUPPLY,                     [dia_SUPPLY],                           [dia_SUPPLY_help]                               },
                                {       DIA_CONF_INVAL,         [dia_CONF_INVAL],                       [dia_CONF_INVAL_help]                   },
                                {       DIA_WARMSTART,          [dia_WARMSTART],                        [dia_WARMSTART_help]                    },
                                {       DIA_COLDSTART,          [dia_COLDSTART],                        [dia_COLDSTART_help]                    },
                                {       DIA_MAINTENANCE,                [dia_MAINTENANCE],                      [dia_MAINTENANCE_help]                  },
                                {       DIA_CHARACT,                    [dia_CHARACT],                          [dia_CHARACT_help]                              },
                                {       DIA_IDENT_VIOL,         [dia_IDENT_VIOL],                       [dia_IDENT_VIOL_help]                   }
                                {       EXTENSION_AVAILABLE,    [dia_EXTENSION_AVAILABLE],      [dia_EXTENSION_AVAILABLE_help]  }
                        }
                            STYLE       "MULTILINE 0 18";

                }
                VARIABLE pressure_damping_value
                {
                        REDEFINE LABEL [pressure_damping_value];
                }

                VARIABLE aidp_outscale_0
                {
                        REDEFINE LABEL [lrv];
                        ADD DEFAULT_VALUE 0.0;
                }

                VARIABLE aidp_outscale_100
                {
                        REDEFINE LABEL [urv];
                        ADD DEFAULT_VALUE 100.0;
                }

                VARIABLE local_keys_mode_control_codes
                {
                        REDEFINE LABEL [local_operation];
                }

                VARIABLE write_protect
                {
                        REDEFINE LABEL [write_protect];
                    REDEFINE  TYPE ENUMERATED
            {
                                {0,  [off]}
                                {1,  [on]}
            }
                }

                VARIABLE meter_installation
                {
                        REDEFINE LABEL [meter_installation];
                        REDEFINE TYPE ENUMERATED
                        {
                                {   1,   "|001Pressure"
                                "|049Druck"},
                                {   2,   "|001Percent"
                                "|049Prozentwert"},
                                {   3,   "|001Current"
                                "|049Strom"},
                                // @@st {   4,   "|001Mass flow/Normalized vol flow"
                                // "|049Massen-Durchflu/NormVolDurchfl"},
                                // {   5,   "|001Volume flow"
                                // "|049Volumen-Durchflu"}
                        }
                }

                VARIABLE o_ring_material
                {
                        REDEFINE LABEL [o_ring_material];
                }

                   VARIABLE o_ring_material
                   {
                                REDEFINE LABEL [o_ring_material];
                                REDEFINE TYPE ENUMERATED
                                {
                                        DEFAULT_VALUE 251;
                                        {   0,   [carbon_steel], [carbon_steel_help] },
                                        {   1,   "|001Stainless Steel 304"
                                                "|049Nichtr. Stahl 304"},
                                        {   2,   "|001Stainless Steel 316"
                                                "|049Nichtr. Stahl 316"},
                                        {   3,   [hastelloy_c], [hastelloy_c_help] },
                                        {   4,   [monel], [monel_help] },
                                        {   5,   [tantalum], [tantalum_help] },
                                        {   6,   "|001Titanium"
                                                "|049Titan"},
                                        {   7,   "|001Platinum-Iridium"
                                                "|049Platin-Iridium"},
                                        {   8,   "|001Alloy 20"
                                                "|049Alloy 20"},
                                        {   9,   "|001Cobalt Chromium Nickel"
                                                "|049Kobalt-Chrom-Nickel"},
                                        {  10,   [ptfe], [ptfe_teflon_help] },
                                        {  11,   [vito], [viton_help] },
                                        {  12,   [buna_n], [buna_n_help] },
                                        {  13,   "|001Ethyl-Prop"
                                                "|049Ethyl-Prop"},
                                        {  14,   "|001Urethane"
                                                "|049Urethan"},
                                        {  15,   "|001Gold Monel Alloy"
                                                "|049Gold Monel Alloy"},
                                        {  16,   "|001Tefzel"
                                                "|049Tefzel"},
                                        {  17,   "|001Ryton"
                                                "|049Ryton"},
                                        {  18,   [ceramic], [ceramic_help] },
                                        {  19,   [stainless_steel_316l], [stainless_steel_316l_help] },
                                        {  20,   "|001PVC"
                                                "|049PVC"},
                                        {  21,   "|001Nitrile Rubber"
                                                "|049Nitrile Gummi"},
                                        {  22,   [kalrez], [kalrez_help] },
                                        {  23,   "|001Inconel"
                                                "|049Inconel"},
                                        {  24,   "|001Kynar"
                                                "|049Kynar"},
                                        {  25,   "|001Aluminium"
                                                "|049Aluminium"},
                                        {  26,   "|001Nickel"
                                                "|049Nickel"},
                                        {  27,   "|001FEP"
                                                "|049FEP"},
                                        {  28,   "|001Stainless Steel 316 Ti"
                                                "|049Nichtr. Stahl 316 Ti"},
                                        {  30,   "|001Hastelloy C276"
                                                "|049Hastelloy C276"},
                                        {  31,   "|001Klinger C4401"
                                                "|049Klinger C4401"},
                                        {  32,   "|001Thermotork"
                                                "|049Thermotork"},
                                        {  33,   "|001Grafoil"
                                                "|049Grafoil"},
                                        {  34,   "|001PTFE coated 316l SST"
                                                "|049316l SST PTFE beschichtet"},
                                        {  35,   "|001Gold plated Hastelloy C276"
                                                "|049Hastelloy C276 goldbeschichtet"},
                                        {  36,   "|001PTFE Glass"
                                                "|049PTFE Glass"},
                                        {  37,   "|001PTFE Graphite"
                                                "|049PTFE Graphite"},
                                        { 129,   "|0011.4571/1.4404"
                                                "|0491.4571/1.4404"},
                                        { 130,   "|001Hastelloy C/1.4571"
                                                "|049Hastelloy C/1.4571"},
                                        { 132,   "|0011.4435/1.4571"
                                                "|0491.4435/1.4571"},
                                        { 133,   "|001Per Fluor Kautschuk"
                                                "|049Per Fluor Kautschuk"},
                                        { 134,   "|00114435"
                                                "|04914435"},
                                        { 135,   "|001AU/1.4404"
                                                "|049AU/1.4404"},
                                        { 136,   "|001Gold plated Monel"
                                                "|049Monel goldbeschichtet"},
                                        { 137,   "|001PVDF"
                                                "|049PVDF"},
                                        { 138,   "|001EPDM"
                                                "|049EPDM"},
                                        { 234,   "|001PTFE Hastelloy"
                                                "|049PTFE Hastelloy"},
                                        { 235,   "|001Stainless Steel CF 8M"
                                                "|049Stainless Steel CF 8M"},
                                        { 236,   "|001Hastelloy SST"
                                                "|049Hastelloy SST"},
                                        { 237,   "|001Gold plated SST"
                                                "|049SST goldbeschichtet"},
                                        { 239,   "|001Monel 400"
                                                "|049Monel 400"},
                                        { 250,   "|001Not used"
                                                "|049Nicht benutzt"},
                                        { 251,   [none] },
                                        { 252,   "|001Unknown"
                                                "|049Unbekannt"},
                                        { 253,   [special] }
                                }
                        }

           VARIABLE remote_seal_isolator_material
                   {
                                REDEFINE LABEL [remote_seal_isolator_material];
                                REDEFINE TYPE ENUMERATED
                           {
                                   DEFAULT_VALUE 251;
                                   {   0,   [carbon_steel], [carbon_steel_help] },
                                   {   1,   "|001Stainless Steel 304"
                                                        "|049Nichtr. Stahl 304"},
                                   {   2,   "|001Stainless Steel 316"
                                                        "|049Nichtr. Stahl 316"},
                                   {   3,   [hastelloy_c], [hastelloy_c_help] },
                                   {   4,   [monel], [monel_help] },
                                   {   5,   [tantalum], [tantalum_help] },
                                   {   6,   "|001Titanium"
                                                        "|049Titan"},
                                   {   7,   "|001Platinum-Iridium"
                                                        "|049Platin-Iridium"},
                                   {   8,   "|001Alloy 20"
                                                        "|049Alloy 20"},
                                   {   9,   "|001Cobalt Chromium Nickel"
                                                        "|049Kobalt-Chrom-Nickel"},
                                   {  10,   [ptfe], [ptfe_teflon_help] },
                                   {  11,   [vito], [viton_help] },
                                   {  12,   [buna_n], [buna_n_help] },
                                   {  13,   "|001Ethyl-Prop"
                                                        "|049Ethyl-Prop"},
                                   {  14,   "|001Urethane"
                                                        "|049Urethan"},
                                   {  15,   "|001Gold Monel Alloy"
                                                        "|049Gold Monel Alloy"},
                                   {  16,   "|001Tefzel"
                                                        "|049Tefzel"},
                                   {  17,   "|001Ryton"
                                                        "|049Ryton"},
                                   {  18,   [ceramic], [ceramic_help] },
                                   {  19,   [stainless_steel_316l], [stainless_steel_316l_help] },
                                   {  20,   "|001PVC"
                                                        "|049PVC"},
                                   {  21,   "|001Nitrile Rubber"
                                                        "|049Nitrile Gummi"},
                                   {  22,   [kalrez], [kalrez_help] },
                                   {  23,   "|001Inconel"
                                                        "|049Inconel"},
                                   {  24,   "|001Kynar"
                                                        "|049Kynar"},
                                   {  25,   "|001Aluminium"
                                                        "|049Aluminium"},
                                   {  26,   "|001Nickel"
                                                        "|049Nickel"},
                                   {  27,   "|001FEP"
                                                        "|049FEP"},
                                   {  28,   "|001Stainless Steel 316 Ti"
                                                        "|049Nichtr. Stahl 316 Ti"},
                                   {  30,   "|001Hastelloy C276"
                                                        "|049Hastelloy C276"},
                                   {  31,   "|001Klinger C4401"
                                                        "|049Klinger C4401"},
                                   {  32,   "|001Thermotork"
                                                        "|049Thermotork"},
                                   {  33,   "|001Grafoil"
                                                        "|049Grafoil"},
                                   {  34,   "|001PTFE coated 316l SST"
                                                        "|049316l SST PTFE beschichtet"},
                                   {  35,   "|001Gold plated Hastelloy C276"
                                                        "|049Hastelloy C276 goldbeschichtet"},
                                   {  36,   "|001PTFE Glass"
                                                        "|049PTFE Glass"},
                                   {  37,   "|001PTFE Graphite"
                                                        "|049PTFE Graphite"},
                                   { 129,   "|0011.4571/1.4404"
                                                        "|0491.4571/1.4404"},
                                   { 130,   "|001Hastelloy C/1.4571"
                                                        "|049Hastelloy C/1.4571"},
                                   { 132,   "|0011.4435/1.4571"
                                                        "|0491.4435/1.4571"},
                                   { 133,   "|001Per Fluor Kautschuk"
                                                        "|049Per Fluor Kautschuk"},
                                   { 134,   "|00114435"
                                                        "|04914435"},
                                   { 135,   "|001AU/1.4404"
                                                        "|049AU/1.4404"},
                                   { 136,   "|001Gold plated Monel"
                                                        "|049Monel goldbeschichtet"},
                                   { 137,   "|001PVDF"
                                                        "|049PVDF"},
                                   { 138,   "|001EPDM"
                                                        "|049EPDM"},
                                   { 234,   "|001PTFE Hastelloy"
                                                        "|049PTFE Hastelloy"},
                                   { 235,   "|001Stainless Steel CF 8M"
                                                        "|049Stainless Steel CF 8M"},
                                   { 236,   "|001Hastelloy SST"
                                                        "|049Hastelloy SST"},
                                   { 237,   "|001Gold plated SST"
                                                        "|049SST goldbeschichtet"},
                                   { 239,   "|001Monel 400"
                                                        "|049Monel 400"},
                                   { 250,   "|001Not used"
                                                        "|049Nicht benutzt"},
                                   { 251,   [none] },
                                   { 252,   "|001Unknown"
                                                        "|049Unbekannt"},
                                   { 253,   [special] }
                           }
                   }

                VARIABLE number_of_remote_seals
        {
                        REDEFINE LABEL "Number of remote seals" "|de|Anzahl Druckmittler";
            REDEFINE TYPE UNSIGNED_INTEGER
            {
                                DISPLAY_FORMAT  "5u";
                                DEFAULT_VALUE   00000;
                                MIN_VALUE       00000;
                                MAX_VALUE       00002;
           }
        }

                VARIABLE  ptrbTemperatureValueUnitV21
                {
                        REDEFINE TYPE ENUMERATED
                        {
                                {32,  "|001C"
                                          "|049C"},
                                {33,  "|001F"
                                          "|049F"},
                                {34,  "|001R"
                                          "|049R"},
                                {35,  "|001K"
                                          "|049K"}
                                {57,  "|001%"
                                          "|049%"}
                        }

                        REDEFINE VALIDITY
                        IF ( software_revision >= 21 )
                                {
                                        TRUE ;
                                }
                                ELSE
                                {
                                        FALSE;
                                }
                }

                VARIABLE temperature_units
                {
                        REDEFINE TYPE ENUMERATED
                        {
                                {32,  "|001C"
                                          "|049C"},
                                {33,  "|001F"
                                          "|049F"},
                                {34,  "|001R"
                                          "|049R"},
                                {35,  "|001K"
                                          "|049K"}
                                {57,  "|001%"
                                          "|049%"}
                        }
                        REDEFINE VALIDITY
                        IF ( software_revision < 21 )
                                {
                                        TRUE ;
                                }
                                ELSE
                                {
                                        FALSE;
                                }

                }

                REDEFINE COLLECTION OF VARIABLE temperature
                {
                        LABEL [sensor_temperature];
                        HELP "|001Sensor Temperature- Temperature of the sensor which measures the proccess."
                                 "|049Sensortemperatur- Temperatur des Sensors der den Proze mit.";
                        MEMBERS
                        {
                        IF ( software_revision < 21 )
                                {
                                DIGITAL_UNITS, temperature_units, [temperature_unit], "|001Field Device Variable Unit- Digital unit that the variable is displayed in. "
                                                                  "Sensor Temperature- Temperature of the sensor which measures the proccess."
                                                                  "|049Feldgerte Variablendimension- Digitale Dimension mit der die Variable "
                                                                  "angezeigt wird. Sensortemperatur- Temperatur des Sensors der den Proze "
                                                                  "mit.";
                                DIGITAL_VALUE, temperature_pressure_value, [blank], "|001Field Device Variable Value- Digital value that changes with respect to "
                                                                  "process or ambient temperature over time with no user intervention. Sensor "
                                                                  "Temperature- Temperature of the sensor wich measures the process."
                                                                  "|049Feldgerte Variablenwert- Digitaler Prozessmewert oder "
                                                                  "Umgebungstemperatur. Sensortemperatur- Temperatur des Sensors der den "
                                                                  "Proze mit.";
                                }
                        ELSE
                                {
                                DIGITAL_UNITS, ptrbTemperatureValueUnitV21, [temperature_unit], "|001Field Device Variable Unit- Digital unit that the variable is displayed in. "
                                                                  "Sensor Temperature- Temperature of the sensor which measures the proccess."
                                                                  "|049Feldgerte Variablendimension- Digitale Dimension mit der die Variable "
                                                                  "angezeigt wird. Sensortemperatur- Temperatur des Sensors der den Proze "
                                                                  "mit.";
                                DIGITAL_VALUE, ptrbTemperatureValueV21, [blank], "|001Field Device Variable Value- Digital value that changes with respect to "
                                                                  "process or ambient temperature over time with no user intervention. Sensor "
                                                                  "Temperature- Temperature of the sensor wich measures the process."
                                                                  "|049Feldgerte Variablenwert- Digitaler Prozessmewert oder "
                                                                  "Umgebungstemperatur. Sensortemperatur- Temperatur des Sensors der den "
                                                                  "Proze mit.";
                                }
                        }
                }

                VARIABLE  ptrbTemperatureValueV21
                {
                        DELETE VALIDITY;
                }

                VARIABLE device_id
                {
                  REDEFINE LABEL [device_id];
                }

                VARIABLE date
                {
                  REDEFINE LABEL [date];
                  REDEFINE TYPE DATE
                  {
                        DELETE DEFAULT_VALUE;
                  }
                }

                VARIABLE flange_type
                {
                   REDEFINE HELP [flange_type];
                }

       VARIABLE flange_type
       {
                   REDEFINE HELP [flange_type];
           REDEFINE TYPE ENUMERATED
           {
               DEFAULT_VALUE 251;
                           {   1,   "|001Flange and 1/4 NPT"
                        "|049Flansch und 1/4 NPT" },
               {   2,   "|001DIN 19213 and 1/4 NPT"
                        "|049DIN 19213 u. 1/4 NPT" },
               {   3,   "|001DIN16288: B-G 1/2A"
                        "|049DIN16288: B-G 1/2A" },
               {   4,   "|001DIN16288: D-G 1/2A"
                        "|049DIN16288: D-G 1/2A" },
               {   5,   "|001NPT1/2 '' male thread"
                        "|049NPT 1/2 '' Auengew." },
               {   6,   "|001NPT1/2 '' fem. thread"
                        "|049NPT 1/2 '' Innengew." },
               {   7,   "|001NPT 1/4 internal thread"
                        "|049NPT 1/4 Innengewinde"},
               {   8,   "|001Pin DIN 16288 Form"
                        "|049Zapfen DIN 16288 Form"},
               {   9,   "|001Alcatel flange DN25"
                        "|049Alcatel Flansch DN25"},
               {  10,   "|001Pressure sensor with flange"
                        "|049Druck-Mewerk m.Flansch"},
               { 251,   [none] },
               { 253,   [special] }
           }
       }

           VARIABLE flange_material
                {
                   REDEFINE HELP [flange_material];
                }

            VARIABLE flange_material
                {
                   REDEFINE HELP [flange_material];
           REDEFINE TYPE ENUMERATED
           {
               DEFAULT_VALUE 251;
                           {   0,   [carbon_steel], [carbon_steel_help] },
               {   1,   "|001Stainless Steel 304"
                        "|049Nichtr. Stahl 304"},
               {   2,   "|001Stainless Steel 316"
                        "|049Nichtr. Stahl 316"},
               {   3,   [hastelloy_c], [hastelloy_c_help] },
               {   4,   [monel], [monel_help] },
               {   5,   [tantalum], [tantalum_help] },
               {   6,   "|001Titanium"
                        "|049Titan"},
               {   7,   "|001Platinum-Iridium"
                        "|049Platin-Iridium"},
               {   8,   "|001Alloy 20"
                        "|049Alloy 20"},
               {   9,   "|001Cobalt Chromium Nickel"
                        "|049Kobalt-Chrom-Nickel"},
               {  10,   [ptfe], [ptfe_teflon_help] },
               {  11,   [vito], [viton_help] },
               {  12,   [buna_n], [buna_n_help] },
               {  13,   "|001Ethyl-Prop"
                        "|049Ethyl-Prop"},
               {  14,   "|001Urethane"
                        "|049Urethan"},
               {  15,   "|001Gold Monel Alloy"
                        "|049Gold Monel Alloy"},
               {  16,   "|001Tefzel"
                        "|049Tefzel"},
               {  17,   "|001Ryton"
                        "|049Ryton"},
               {  18,   [ceramic], [ceramic_help] },
               {  19,   [stainless_steel_316l], [stainless_steel_316l_help] },
               {  20,   "|001PVC"
                        "|049PVC"},
               {  21,   "|001Nitrile Rubber"
                        "|049Nitrile Gummi"},
               {  22,   [kalrez], [kalrez_help] },
               {  23,   "|001Inconel"
                        "|049Inconel"},
               {  24,   "|001Kynar"
                        "|049Kynar"},
               {  25,   "|001Aluminium"
                        "|049Aluminium"},
               {  26,   "|001Nickel"
                        "|049Nickel"},
               {  27,   "|001FEP"
                        "|049FEP"},
               {  28,   "|001Stainless Steel 316 Ti"
                        "|049Nichtr. Stahl 316 Ti"},
               {  30,   "|001Hastelloy C276"
                        "|049Hastelloy C276"},
               {  31,   "|001Klinger C4401"
                        "|049Klinger C4401"},
               {  32,   "|001Thermotork"
                        "|049Thermotork"},
               {  33,   "|001Grafoil"
                        "|049Grafoil"},
               {  34,   "|001PTFE coated 316l SST"
                        "|049316l SST PTFE beschichtet"},
               {  35,   "|001Gold plated Hastelloy C276"
                        "|049Hastelloy C276 goldbeschichtet"},
               {  36,   "|001PTFE Glass"
                        "|049PTFE Glass"},
               {  37,   "|001PTFE Graphite"
                        "|049PTFE Graphite"},
               { 129,   "|0011.4571/1.4404"
                        "|0491.4571/1.4404"},
               { 130,   "|001Hastelloy C/1.4571"
                        "|049Hastelloy C/1.4571"},
               { 132,   "|0011.4435/1.4571"
                        "|0491.4435/1.4571"},
               { 133,   "|001Per Fluor Kautschuk"
                        "|049Per Fluor Kautschuk"},
               { 134,   "|00114435"
                        "|04914435"},
               { 135,   "|001AU/1.4404"
                        "|049AU/1.4404"},
               { 136,   "|001Gold plated Monel"
                        "|049Monel goldbeschichtet"},
               { 137,   "|001PVDF"
                        "|049PVDF"},
               { 138,   "|001EPDM"
                        "|049EPDM"},
               { 234,   "|001PTFE Hastelloy"
                        "|049PTFE Hastelloy"},
               { 235,   "|001Stainless Steel CF 8M"
                        "|049Stainless Steel CF 8M"},
               { 236,   "|001Hastelloy SST"
                        "|049Hastelloy SST"},
               { 237,   "|001Gold plated SST"
                        "|049SST goldbeschichtet"},
               { 239,   "|001Monel 400"
                        "|049Monel 400"},
               { 250,   "|001Not used"
                        "|049Nicht benutzt"},
               { 251,   [none] },
               { 252,   "|001Unknown"
                        "|049Unbekannt"},
               { 253,   [special] }
           }
       }

           VARIABLE pbWriteLock
                {
                        REDEFINE LABEL [pbWriteLock];
                        REDEFINE TYPE ENUMERATED (2)
                        {
                                DEFAULT_VALUE 0x0999;
                                {0x0000,  "Device write locked|de|Gert schreibgeschtzt"},
                                {0x0999,  "User data write enabled|de|Anwenderdaten schreibbar"}
//                              {0x1001,  "User protected data write enabled|de|Anwendergeschtzte Daten schreibbar"},
//                              {0x7381,  "Factory protected data write enabled|de|Werksdaten schreibbar"},
                        }
                }

                VARIABLE module_fill_fluid
                {
                   REDEFINE TYPE ENUMERATED
                   {
                           DEFAULT_VALUE 251;
                           {   1,   [silicone_oil] },
                           {   2,   "|001Fluor carbon"
                                                "|049Fluorkohlenstoff" },
                           {   3,   "|001Destilled water"
                                                "|049Destilliertes Wasser" },
                           {   4,   "|001High temperature oil"
                                                "|049Hochtemperaturl" },
                           {   5,   "|001Vegetable Oil"
                                                "|049Pflanzenl"},
                           {   6,   "|001Mineral oil"
                                                "|049Minerall"},
                           {   7,   "|001White oil"
                                                "|049Weissl"},
                           {   8,   "|001Fill fluid FDA certified"
                                                "|049Fllflssigkeit FDA zugelassen"},
                           {   9,   "|001Fill fluid ABB"
                                                "|049Fllflssigkeit ABB"},
                           { 251,  [none] },
                           { 253,  [special] }
                   }
                   REDEFINE HANDLING READ;// & WRITE;
                }

                VARIABLE module_isolator_material
                {
                   REDEFINE TYPE ENUMERATED
                   {
                           DEFAULT_VALUE 0;
                           {   0,   [carbon_steel], [carbon_steel_help] },
                           {   1,   "|001Stainless Steel 304"
                                                "|049Nichtr. Stahl 304"},
                           {   2,   "|001Stainless Steel 316"
                                                "|049Nichtr. Stahl 316"},
                           {   3,   [hastelloy_c], [hastelloy_c_help] },
                           {   4,   [monel], [monel_help] },
                           {   5,   [tantalum], [tantalum_help] },
                           {   6,   "|001Titanium"
                                                "|049Titan"},
                           {   7,   "|001Platinum-Iridium"
                                                "|049Platin-Iridium"},
                           {   8,   "|001Alloy 20"
                                                "|049Alloy 20"},
                           {   9,   "|001Cobalt Chromium Nickel"
                                                "|049Kobalt-Chrom-Nickel"},
                           {  10,   [ptfe], [ptfe_teflon_help] },
                           {  11,   [vito], [viton_help] },
                           {  12,   [buna_n], [buna_n_help] },
                           {  13,   "|001Ethyl-Prop"
                                                "|049Ethyl-Prop"},
                           {  14,   "|001Urethane"
                                                "|049Urethan"},
                           {  15,   "|001Gold Monel Alloy"
                                                "|049Gold Monel Alloy"},
                           {  16,   "|001Tefzel"
                                                "|049Tefzel"},
                           {  17,   "|001Ryton"
                                                "|049Ryton"},
                           {  18,   [ceramic], [ceramic_help] },
                           {  19,   [stainless_steel_316l], [stainless_steel_316l_help] },
                           {  20,   "|001PVC"
                                                "|049PVC"},
                           {  21,   "|001Nitrile Rubber"
                                                "|049Nitrile Gummi"},
                           {  22,   [kalrez], [kalrez_help] },
                           {  23,   "|001Inconel"
                                                "|049Inconel"},
                           {  24,   "|001Kynar"
                                                "|049Kynar"},
                           {  25,   "|001Aluminium"
                                                "|049Aluminium"},
                           {  26,   "|001Nickel"
                                                "|049Nickel"},
                           {  27,   "|001FEP"
                                                "|049FEP"},
                           {  28,   "|001Stainless Steel 316 Ti"
                                                "|049Nichtr. Stahl 316 Ti"},
                           {  30,   "|001Hastelloy C276"
                                                "|049Hastelloy C276"},
                           {  31,   "|001Klinger C4401"
                                                "|049Klinger C4401"},
                           {  32,   "|001Thermotork"
                                                "|049Thermotork"},
                           {  33,   "|001Grafoil"
                                                "|049Grafoil"},
                           {  34,   "|001PTFE coated 316l SST"
                                                "|049316l SST PTFE beschichtet"},
                           {  35,   "|001Gold plated Hastelloy C276"
                                                "|049Hastelloy C276 goldbeschichtet"},
                           {  36,   "|001PTFE Glass"
                                                "|049PTFE Glass"},
                           {  37,   "|001PTFE Graphite"
                                                "|049PTFE Graphite"},
                           { 129,   "|0011.4571/1.4404"
                                                "|0491.4571/1.4404"},
                           { 130,   "|001Hastelloy C/1.4571"
                                                "|049Hastelloy C/1.4571"},
                           { 132,   "|0011.4435/1.4571"
                                                "|0491.4435/1.4571"},
                           { 133,   "|001Per Fluor Kautschuk"
                                                "|049Per Fluor Kautschuk"},
                           { 134,   "|00114435"
                                                "|04914435"},
                           { 135,   "|001AU/1.4404"
                                                "|049AU/1.4404"},
                           { 136,   "|001Gold plated Monel"
                                                "|049Monel goldbeschichtet"},
                           { 137,   "|001PVDF"
                                                "|049PVDF"},
                           { 138,   "|001EPDM"
                                                "|049EPDM"},
                           { 234,   "|001PTFE Hastelloy"
                                                "|049PTFE Hastelloy"},
                           { 235,   "|001Stainless Steel CF 8M"
                                                "|049Stainless Steel CF 8M"},
                           { 236,   "|001Hastelloy SST"
                                                "|049Hastelloy SST"},
                           { 237,   "|001Gold plated SST"
                                                "|049SST goldbeschichtet"},
                           { 239,   "|001Monel 400"
                                                "|049Monel 400"},
                           { 250,   "|001Not used"
                                                "|049Nicht benutzt"},
                           { 251,   [none] },
                           { 252,   "|001Unknown"
                                                "|049Unbekannt"},
                           { 253,   [special] }
                   }
                   REDEFINE HANDLING READ;// & WRITE;
                }
       VARIABLE drain_vent_material
       {
           REDEFINE TYPE ENUMERATED
           {
               DEFAULT_VALUE 251;
                           {   0,   [carbon_steel], [carbon_steel_help] },
               {   1,   "|001Stainless Steel 304"
                        "|049Nichtr. Stahl 304"},
               {   2,   "|001Stainless Steel 316"
                        "|049Nichtr. Stahl 316"},
               {   3,   [hastelloy_c], [hastelloy_c_help] },
               {   4,   [monel], [monel_help] },
               {   5,   [tantalum], [tantalum_help] },
               {   6,   "|001Titanium"
                        "|049Titan"},
               {   7,   "|001Platinum-Iridium"
                        "|049Platin-Iridium"},
               {   8,   "|001Alloy 20"
                        "|049Alloy 20"},
               {   9,   "|001Cobalt Chromium Nickel"
                        "|049Kobalt-Chrom-Nickel"},
               {  10,   [ptfe], [ptfe_teflon_help] },
               {  11,   [vito], [viton_help] },
               {  12,   [buna_n], [buna_n_help] },
               {  13,   "|001Ethyl-Prop"
                        "|049Ethyl-Prop"},
               {  14,   "|001Urethane"
                        "|049Urethan"},
               {  15,   "|001Gold Monel Alloy"
                        "|049Gold Monel Alloy"},
               {  16,   "|001Tefzel"
                        "|049Tefzel"},
               {  17,   "|001Ryton"
                        "|049Ryton"},
               {  18,   [ceramic], [ceramic_help] },
               {  19,   [stainless_steel_316l], [stainless_steel_316l_help] },
               {  20,   "|001PVC"
                        "|049PVC"},
               {  21,   "|001Nitrile Rubber"
                        "|049Nitrile Gummi"},
               {  22,   [kalrez], [kalrez_help] },
               {  23,   "|001Inconel"
                        "|049Inconel"},
               {  24,   "|001Kynar"
                        "|049Kynar"},
               {  25,   "|001Aluminium"
                        "|049Aluminium"},
               {  26,   "|001Nickel"
                        "|049Nickel"},
               {  27,   "|001FEP"
                        "|049FEP"},
               {  28,   "|001Stainless Steel 316 Ti"
                        "|049Nichtr. Stahl 316 Ti"},
               {  30,   "|001Hastelloy C276"
                        "|049Hastelloy C276"},
               {  31,   "|001Klinger C4401"
                        "|049Klinger C4401"},
               {  32,   "|001Thermotork"
                        "|049Thermotork"},
               {  33,   "|001Grafoil"
                        "|049Grafoil"},
               {  34,   "|001PTFE coated 316l SST"
                        "|049316l SST PTFE beschichtet"},
               {  35,   "|001Gold plated Hastelloy C276"
                        "|049Hastelloy C276 goldbeschichtet"},
               {  36,   "|001PTFE Glass"
                        "|049PTFE Glass"},
               {  37,   "|001PTFE Graphite"
                        "|049PTFE Graphite"},
               { 129,   "|0011.4571/1.4404"
                        "|0491.4571/1.4404"},
               { 130,   "|001Hastelloy C/1.4571"
                        "|049Hastelloy C/1.4571"},
               { 132,   "|0011.4435/1.4571"
                        "|0491.4435/1.4571"},
               { 133,   "|001Per Fluor Kautschuk"
                        "|049Per Fluor Kautschuk"},
               { 134,   "|00114435"
                        "|04914435"},
               { 135,   "|001AU/1.4404"
                        "|049AU/1.4404"},
               { 136,   "|001Gold plated Monel"
                        "|049Monel goldbeschichtet"},
               { 137,   "|001PVDF"
                        "|049PVDF"},
               { 138,   "|001EPDM"
                        "|049EPDM"},
               { 234,   "|001PTFE Hastelloy"
                        "|049PTFE Hastelloy"},
               { 235,   "|001Stainless Steel CF 8M"
                        "|049Stainless Steel CF 8M"},
               { 236,   "|001Hastelloy SST"
                        "|049Hastelloy SST"},
               { 237,   "|001Gold plated SST"
                        "|049SST goldbeschichtet"},
               { 239,   "|001Monel 400"
                        "|049Monel 400"},
               { 250,   "|001Not used"
                        "|049Nicht benutzt"},
               { 251,   [none] },
               { 252,   "|001Unknown"
                        "|049Unbekannt"},
               { 253,   [special] }
           }
       }


           REDEFINE COMMAND write_pv_range_values
                {
                        NUMBER 35;

                        OPERATION WRITE;

                        TRANSACTION
                        {
                                REQUEST
                                {
                                        pressure_units, TV.UPPER_RANGE_VALUE, TV.LOWER_RANGE_VALUE
                                }

                                REPLY
                                {
                                        response_code, device_status,
                                        pressure_units, TV.UPPER_RANGE_VALUE, TV.LOWER_RANGE_VALUE
                                }
                        }

                        RESPONSE_CODES
                        {
                                0,      SUCCESS,                        [no_command_specific_errors];
                                2,      DATA_ENTRY_ERROR,       [invalid_selection];
                                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                                7,      MODE_ERROR,                     [in_write_protect_mode];
                                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                                14,     DATA_ENTRY_WARNING,     [span_too_small];
                                16,     MODE_ERROR,                     [access_restricted];
                        }
                }

                REDEFINE VARIABLE ptrbPrimaryValue
                {
                        LABEL           [measuring_value];
                        CLASS           OUTPUT & DYNAMIC;
                        TYPE        FLOAT
                        {
                                DEFAULT_VALUE   0.0;
                        }
                        HANDLING READ;
                }

                VARIABLE free_proc_var_stat_press
                {
                        REDEFINE LABEL    [trans_value];
                        REDEFINE VALIDITY TRUE;
                }

        }
}

/******************************************************************************/
/*    Trending                                                                                                                            */
/******************************************************************************/

#define YT1_LABEL       [measuring_value]
#define YT1_VALUE       ptrbPrimaryValue
#define YT1_LRV         ptrbScaleOut0
#define YT1_URV         ptrbScaleOut100

#define YT2_LABEL       "Output Value|de|Ausgangswert"
#define YT2_VALUE       aiDPOutValue//pressure.DIGITAL_VALUE
#define YT2_LRV         aidp_outscale_0//pressure.UPPER_RANGE_VALUE
#define YT2_URV         aidp_outscale_100//pressure.LOWER_RANGE_VALUE


/*******************************************************************************/
/*    PDM-Menus                                                                                                                            */
/********************************************************************************/

#define EXTRA_ITEMS_DEVICE_MENU_SPECIALIST  \
                OnlineDialog_hart_comm,                         \
                configuration_flag_reset,                       \
                SEPARATOR,                                                      \
                loop_test,                                                      \
                MENU_Simulation                                         \
                MENU_sensor_trim,                                       \
                OnlineDialog_position_corr,                     \
                OnlineDialog_set_lower_upper_value,     \
                SEPARATOR,                                                      \
                OnlineDialog_reset,                                     \
                OnlineDialog_security_locking           \


#define EXTRA_ITEMS_VIEW_MENU_SPECIALIST        OnlineWindow_diagnosis,                         \
                                                OnlineWindow_pressure_pointer,                  \
                                                OnlineWindow_about


#define EXTRA_ITEMS_VIEW_MENU_MAINTENANCE       OnlineWindow_diagnosis, \
                                                OnlineWindow_about


/*******************************************************************************/
/* Includes                                                                                                                                        */
/*******************************************************************************/
#include "SI_MainMenu.inc"
#include "SI_FileM.inc"
#include "SI_OptM.inc"
#include "SI_HlpM.inc"
#include "SIHA.inc"
#include "SI_DevM.inc"
#include "SI_ViewM.inc"
#include "SI_YT.inc"

/*******************************************************************************/
/*****  Online-Windows  ********************************************************/
/*******************************************************************************/

MENU OnlineWindow_about
{
        LABEL           [onlinewindow_about_label];
        ITEMS
        {
                Page_about,
        }
}

MENU Page_about
{
        LABEL   [page_about_label];
        ITEMS
        {
                device_type(READ_ONLY),
                module_type_code(READ_ONLY),
                device_id(READ_ONLY),
                universal_revision(READ_ONLY),
                transmitter_revision(READ_ONLY),
                software_revision(READ_ONLY),
                pbsoftwarespecifics(READ_ONLY),
                hardware_revision(READ_ONLY),
                pdm_revision(READ_ONLY)
        }
}

MENU OnlineWindow_display
{
        LABEL           [menu_dialog_display];
        ITEMS
        {
                                Page_display_func1,
                                Page_display_diff_pressure_value,
                                IF (DIFFERENTIAL_SENSOR)
                                {
                                        Page_display_static_pressure_value,
                                }
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Page_display_func1
{
        LABEL       IF (STATIC_SENSOR)
                                {
                                        [menu_static_pressure] ;
                                }
                                ELSE
                                {
                                        [menu_differentialpressure] ;
                                }
        ITEMS
        {
                BarVal_out_display_func1,
                Group_display_func1_out,
                Group_display_func1_in
        }
}

MENU Page_display_static_pressure_value
{
        LABEL     [display_static_pressure_value] ;
        ITEMS
        {
                BarVal_pv_display_2,
                Group_display_primary_2,
                Group_display_temperatur
        }

}

MENU Page_display_diff_pressure_value
{
        LABEL                   IF (STATIC_SENSOR)
                                {
                                        [display_static_pressure_value] ;
                                }
                                ELSE
                                {
                                        [display_diff_pressure_value] ;
                                }
        ITEMS
        {
                BarVal_pv_display,
                Group_display_primary,
                Val_sensor_display,
                Group_display_secundary,
                Group_display_temperatur
        }
}

MENU Val_sensor_display
{
        LABEL           [trans_pres_sensor_value];
        ITEMS
        {
                ptrbSensorValue //trans1_sensor_value (Rohwert)
        }
}

MENU BarVal_pv_display
{
        LABEL           [trans_value];
        ITEMS
        {
                ptrbPrimaryValue,//trans1_primary_value,(Mewert: Der gemessene, korrigierte und abgeglichene Druck am Ausgang)
                ptrbScaleOut0(READ_ONLY),//trans1_scale_out_lower_value(READ_ONLY),
                ptrbScaleOut100(READ_ONLY)//trans1_scale_out_upper_value(READ_ONLY)
        }
}

MENU BarVal_pv_display_2
{
        LABEL           [trans_value];
        ITEMS
        {
                free_proc_var_stat_press,
                static_pressure_lower_range_value(READ_ONLY),
                static_pressure_upper_range_value(READ_ONLY)
        }
}

MENU Group_display_primary
{
        LABEL           [trans_value];
        ITEMS
        {
                ptrbPrimaryValue,//trans1_primary_value,(Mewert: Der gemessene, korrigierte und abgeglichene Druck am Ausgang)
                SEPARATOR,
                ptrbPrimaryValueStatus_quality,//trans1_primary_value_status_quality
                ptrbPrimaryValueStatus_limit//trans1_primary_value_status_limit
        }
}

MENU Group_display_primary_2
{
        LABEL           [trans_value];
        ITEMS
        {
                free_proc_var_stat_press,
                SEPARATOR,
                ptrbStaticPressureValueStatus_quality,
                ptrbStaticPressureValueStatus_limit
        }
}

MENU Group_display_secundary
{
        LABEL           [trans_secondary_value_1_value];
        ITEMS
        {
                temperature_pressure_value.DIGITAL_VALUE,
                SEPARATOR,
                ptrbSecondaryValue1Status_quality//trans1_secondary_value_1_status_quality, ptrbSecondaryValue1Status
                ptrbSecondaryValue1Status_limit//trans1_secondary_value_1_status_limit ptrbSecondaryValue1Status
        }
}



MENU BarVal_out_display_func1
{
        LABEL           [func_out_value];
        HELP            [func_ai_out_value_help];
        ITEMS
        {
                aiDPOutValue(READ_ONLY),//func1_AI_out_value
                aidp_outscale_0 (READ_ONLY),//aiDPOutScale0 func1_AI_out_lower_range_value
                aidp_outscale_100(READ_ONLY)//aiDPOutScale100 func1_AI_out_upper_range_value
        }
}

MENU Group_display_func1_out
{
        LABEL           [menu_dialog_display_output] ;
        ITEMS
        {
                aiDPModeBlkActual,//func1_AI_actual_mode,
                SEPARATOR,
                aiDPOutStatus_quality(READ_ONLY)//func1_AI_out_status_quality
                aiDPOutStatus_limit(READ_ONLY)//func1_AI_out_status_limit
                xmtr_specific_status_0//func1_AI_current_state_alarm_sum//aiDPAlarmSumCurrent
        }
}


MENU Group_display_func1_in
{
        LABEL           [menu_dialog_display_input] ;
        ITEMS
        {
#ifdef FUNC1_PV
                FUNC1_PV,
#endif

#ifdef FUNC1_CHANNEL_LIST
                func1_AI_channel                                (READ_ONLY),
#endif

        SEPARATOR,

#ifdef FUNC1_PV_STATUS
                FUNC1_PV_STATUS,
#endif
                aiDPSimulateEnabled(READ_ONLY)//func1_AI_simulation_enabled (READ_ONLY)//aiDPSimulateEnabled
        }
}

MENU Group_display_temperatur
{
        LABEL           [trans_pres_sensor_temp_value];
        ITEMS
        {
                ptrbTemperatureValueV21 //trans1_temperature_value,//ptrbTemperatureValue
        }
}

MENU BarVal_out_display_func2
{
        LABEL           [func_out_value];
        HELP            [func_ai_out_value_help];
        ITEMS
        {
                aiPOutValue(READ_ONLY),//func2_AI_out_value
                aiPOutScale0(READ_ONLY),//func2_AI_out_lower_range_value(READ_ONLY)
                aiPOutScale100(READ_ONLY)//func2_AI_out_upper_range_value(READ_ONLY)
        }
}



MENU Group_display_func2_out
{
        LABEL           [menu_dialog_display_output] ;
        ITEMS
        {
                aiPModeBlkActual//func2_AI_actual_mode,
                SEPARATOR,
                aiPOutStatus_quality(READ_ONLY),//func2_AI_out_status_quality
                aiPOutStatus_limit(READ_ONLY),//func2_AI_out_status_limit
                xmtr_specific_status_1//func2_AI_current_state_alarm_sum//aiPAlarmSumCurrent
        }
}

MENU Group_display_func2_in
{
        LABEL           [menu_dialog_display_input] ;
        ITEMS
        {
#ifdef FUNC2_PV
                FUNC2_PV,
#endif

#ifdef FUNC2_CHANNEL_LIST
                func2_AI_channel                                (READ_ONLY),
#endif

        SEPARATOR,

#ifdef FUNC2_PV_STATUS
                FUNC2_PV_STATUS,
#endif
                aiPSimulateEnabled(READ_ONLY),//func2_AI_simulation_enabled (READ_ONLY)
        }
}


MENU OnlineWindow_diagnosis
{
        LABEL           [menu_dialog_diagnosis];
        ITEMS
        {
                Page_diagnosis_device,
                Page_diagnosis_status
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Page_diagnosis_status
{
        LABEL   [menu_status];
        ITEMS
        {
                device_status(READ_ONLY),
                diagnosis,
                // diagnosis1,
                diagnosisExtension,
                diagnosisExtension1,
                diagnosisExtension2,
                self_test
        }
}

MENU Page_diagnosis_device
{
        LABEL           [menu_ident_device];
        ITEMS
        {
                tag(READ_ONLY),
                manufacturer_id(READ_ONLY),
                device_type(READ_ONLY),
                device_id(READ_ONLY),
                date(READ_ONLY),
                universal_revision(READ_ONLY),
                transmitter_revision(READ_ONLY),
                hardware_revision(READ_ONLY),
                software_revision(READ_ONLY),
                final_assembly_number(READ_ONLY),
                write_protect(READ_ONLY)
        }
}

/*******************************************************************************/
/*****  Online-Dialogs  ********************************************************/
/*******************************************************************************/

MENU OnlineDialog_security_locking
{
        LABEL           [security_locking];
        ITEMS
        {
                write_protect,
                pbWriteLock
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU OnlineDialog_set_lower_upper_value
{
        LABEL   [set_lower_upper_value];
        ITEMS
        {
                Page_set_lower_value
                Page_set_upper_value
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Page_set_lower_value
{
        LABEL   [lower_value];
        ITEMS
        {
                temperature_pressure_value.DIGITAL_VALUE,
                pressure_lower_range_value(READ_ONLY),
                method_set_pv_lower_range_value
        }
}

MENU Page_set_upper_value
{
        LABEL   [upper_value];
        ITEMS
        {
                temperature_pressure_value.DIGITAL_VALUE,
                pressure_upper_range_value(READ_ONLY),
                method_set_pv_upper_range_value
        }
}

MENU OnlineDialog_position_corr
{
        LABEL   [position_corr];
        HELP    [position_corr_help];
        ITEMS
        {
                Page_position_corr
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Page_position_corr
{
        LABEL   [position_corr];
        HELP    [position_corr_help];
        ITEMS
        {
                temperature_pressure_value.DIGITAL_VALUE,
                // pressure.DIGITAL_VALUE,
                method_position_corr
        }
}

METHOD method_position_corr
{
        LABEL   "start";
        CLASS INPUT;
        DEFINITION
        {
                int status;
                add_abort_method(abort_load_to_device);

                ReadCommand (read_static_data_material);
                if ( pbWriteLock == 0 )
                {
                        ACKNOWLEDGE([DeviceWriteProtected]);
                        process_abort();
                }

                status = send_command(43);

                if ( status >= ID_FC_ERROR )
                {
                         ACKNOWLEDGE([acknowledge_process_aborted]);
                         process_abort();
                }
                else
                {
                         ACKNOWLEDGE([pos_correction_succeeded]);
                }
        }
}

MENU MENU_sensor_trim
{
        LABEL           [menu_dialog_sensor_trim];
        ITEMS
        {
                IF(STATIC_SENSOR)
                {
                        OnlineDialog_sensor_trim_diff,
                }
                ELSE
                {
                        OnlineDialog_sensor_trim_diff,
                        OnlineDialog_sensor_trim_stat
                }
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU OnlineDialog_sensor_trim_diff
{
        LABEL       IF (STATIC_SENSOR)
                                {
                                        [menu_dialog_sensor_trim_stat_change];//[menu_dialog_sensor_trim_stat] ;
                                }
                                ELSE
                                {
                                        [menu_dialog_sensor_trim_diff] ;
                                }
        ITEMS
        {
                Page_cal_point_lo,
                Page_cal_point_hi,
                Page_date_person
        }
}

MENU Page_cal_point_lo
{
        LABEL           [menu_dialog_sensor_trim_cal_point_lo];
        ITEMS
        {
                sensor_a_lower_sensor_trim_point,//ptrbCalPointLo
                PV.MINIMUM_SPAN(READ_ONLY),//ptrbMinSpan
                ptrbSensorValue,
        }
}

MENU Page_cal_point_hi
{
        LABEL           [menu_dialog_sensor_trim_cal_point_hi];
        ITEMS
        {
                sensor_a_upper_sensor_trim_point,//ptrbCalPointHi
                PV.MINIMUM_SPAN(READ_ONLY),//ptrbMinSpan
                ptrbSensorValue,
        }
}

MENU OnlineDialog_sensor_trim_stat
{
        LABEL           [menu_dialog_sensor_trim_stat];
        ITEMS
        {
                Page_cal_point_lo_static,
                Page_cal_point_hi_static,
                Page_date_person
        }
}

MENU Page_cal_point_lo_static
{
        LABEL           [menu_dialog_sensor_trim_cal_point_lo];
        ITEMS
        {
                stat_press_sensor_lower_sensor_trim_point,//ptrbStaticPressureCalPointLo
                ptrbStaticPressureMinSpan,
                free_proc_var_stat_press,
        }
}

MENU Page_cal_point_hi_static
{
        LABEL           [menu_dialog_sensor_trim_cal_point_hi];
        ITEMS
        {
                stat_press_sensor_upper_sensor_trim_point,//ptrbStaticPressureCalPointHi
                ptrbStaticPressureMinSpan,
                free_proc_var_stat_press
        }
}

MENU Page_date_person
{
        LABEL           [menu_dialog_date_person];
        ITEMS
        {
                ptrbSensorCalDate,
                ptrbSensorCalWho,
        }
}

MENU MENU_Simulation
{
        LABEL           [func_simulation_enabled];
        ITEMS
        {
                OnlineDialog_simulation_func1,
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU OnlineDialog_simulation_func1
{
        LABEL       IF (DIFFERENTIAL_SENSOR)
                                {
                                        [Simulation_diff_absolute] ;
                                }
                                ELSE
                                {
                                        [Simulation_diff] ;
                                }
        ITEMS
        {
                Page_simulation_input_func1,
                Page_simulation_output_func1
        }
}

MENU Page_simulation_input_func1
{
        LABEL           [menu_dialog_simulation_input];
        ITEMS
        {
                aiDPSimulateEnabled,//func1_AI_simulation_enabled
                Group_simulate_input_func1,
        }
}

MENU Group_simulate_input_func1
{
        LABEL           [func_simulate_value];
        ITEMS
        {
                aiDPSimulateValue,//func1_AI_simulate_value
                SEPARATOR,
                aiDPSimulateStatus_quality,//func1_AI_simulate_status_quality
                aiDPSimulateStatus_limit//func1_AI_simulate_status_limit
        }
}

MENU Page_simulation_output_func1
{
        LABEL           [menu_dialog_simulation_output];
        ITEMS
        {
                aiDPModeBlkTarget,//func1_AI_target_mode
                aiDPModeBlkActual,//func1_AI_actual_mode
                Group_simulate_output_func1,
        }
}

MENU Group_simulate_output_func1
{
        LABEL           [func_out_value];
        ITEMS
        {
                aiDPOutValue,//func1_AI_out_value
                SEPARATOR,
                aiDPOutStatus_quality,//func1_AI_out_status_quality,
                aiDPOutStatus_limit/*func1_AI_out_status_limit*/
        }
}

MENU OnlineDialog_simulation_func2
{
        LABEL           [Simulation_diff] ;
        ITEMS
        {
                        Page_simulation_input_func2,
                        Page_simulation_output_func2
        }
}

MENU Page_simulation_input_func2
{
        LABEL           [menu_dialog_simulation_input];
        ITEMS
        {
                aiPSimulateEnabled,//func2_AI_simulation_enabled
                Group_simulate_input_func2,
        }
}

MENU Group_simulate_input_func2
{
        LABEL           [func_simulate_value];
        ITEMS
        {
                aiPSimulateValue,//func2_AI_simulate_value
                SEPARATOR,
                aiPSimulateStatus_quality,//func2_AI_simulate_status_quality
                aiPSimulateStatus_limit//func2_AI_simulate_status_limit
        }
}

MENU Page_simulation_output_func2
{
        LABEL           [menu_dialog_simulation_output];
        ITEMS
        {
                aiPModeBlkTarget,//func2_AI_target_mode
                aiPModeBlkActual,//func2_AI_actual_mode
                Group_simulate_output_func2,
        }
}

MENU OnlineDialog_reset
{
        LABEL           [master_reset];
        HELP            [master_reset_help];
        ITEMS
        {
                Page_reset
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}



MENU Page_reset
{
        LABEL           [master_reset];
        HELP            [master_reset_help];
        ITEMS
        {
                diagnosis,//phys_diagnosis,
                SEPARATOR,
                method_phys_factory_reset_params,
                master_reset,

        }
}

MENU Group_simulate_output_func2
{
        LABEL           [func_out_value];
        ITEMS
        {
                aiPOutValue,//func2_AI_out_value
                SEPARATOR,
                aiPOutStatus_quality,//func2_AI_out_status_quality,
                aiPOutStatus_limit/*func2_AI_out_status_limit*/
        }
}

/*******************************************************************************/
/*****  Online-Dialogs  ********************************************************/
/*******************************************************************************/
MENU OnlineWindow_pressure_pointer
{
        LABEL           [menu_indicator];
        ITEMS
        {
                IF (DIFFERENTIAL_SENSOR)
                {
                        Page_pressure_pointer_diff,
                        Page_pressure_pointer_static,
                        Page_sens_temp_pointer,
                }
                ELSE
                {
                        Page_pressure_pointer_diff,
                        Page_sens_temp_pointer
                }
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Page_pressure_pointer_diff
{
        LABEL       IF (STATIC_SENSOR)
                                {
                                        [menu_pres_indicator_static] ;
                                }
                                ELSE
                                {
                                        [menu_pres_indicator_diff] ;
                                }
        ITEMS
        {
                ptrbMinSensorValue(READ_ONLY),//trans1_min_sensor_value
                ptrbMaxSensorValue(READ_ONLY),//trans1_max_sensor_value
                reset_pressure_pointer
        }
}

MENU Page_sens_temp_pointer
{
        LABEL           [menu_sens_temp_indicator];
        ITEMS
        {
                ptrbMinTemperature(READ_ONLY),//trans1_min_temperature(READ_ONLY),
                ptrbMaxTemperature(READ_ONLY),//trans1_max_temperature(READ_ONLY),
                reset_temperatur_pointer,
        }
}
MENU Page_pressure_pointer_static
{
        LABEL           [menu_pres_indicator_static];
        ITEMS
        {
                ptrbMaxStaticPressure(READ_ONLY),
                ptrbMinStaticPressure(READ_ONLY),
                reset_pressure_pointer_static
        }
}
/*******************************************************************************/
/*****  Table: Specialist  *****************************************************/
/*******************************************************************************/

MENU Table_Main_Specialist
{
        LABEL            "2600T-263/265" ;
        ITEMS
        {
                Tab_s_ident,
                Tab_s_input,
                Tab_s_output,
                Tab_s_const,
                Tab_s_sensorcalibration,
                Tab_s_certificatesandapprovals

        }
}

MENU Tab_s_ident
{
        LABEL           [menu_ident];
        ITEMS
        {
                Tab_s_ident_opunit,
                Tab_s_ident_device

        }
}

MENU Tab_s_ident_device
{
        LABEL           [menu_ident_device];
        ITEMS
        {
                manufacturer_id,
                device_id,
                software_revision,
                hardware_revision,
                date,
                module_type_code,
                PV.SENSOR_SERIAL_NUMBER(READ_ONLY),
                pbsoftwarespecifics(READ_ONLY),
                write_protect,
                pbWriteLock(READ_ONLY)
        }

}

MENU Tab_s_input
{
        LABEL           [menu_input];
        ITEMS
        {
                Tab_s_input_range_limit,
                Tab_s_input_measwindow,
                Tab_s_input_workingrange,
                Tab_s_input_characterization,
                Tab_s_input_coordinates,
                Tab_s_input_sensortemperatur

        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Tab_s_input_range_limit
{
        LABEL           [menu_input_measrange];
        ITEMS
        {
                pressure_sensor_units,
                pressure_lower_range_limit,
                pressure_upper_range_limit,
                IF (DIFFERENTIAL_SENSOR)
                {
                        static_pressure_lo_lim,
                        static_pressure_hi_lim
                }
        }
}

MENU   Tab_s_input_measwindow
{
        LABEL           [menu_input_meassurerange];
        ITEMS
        {
                static_pressure_lo_lim(HIDDEN),
                static_pressure_hi_lim(HIDDEN),
                pressure_lower_range_limit(HIDDEN),
                pressure_upper_range_limit(HIDDEN),
                pressure_units,
                pressure_lower_range_value,
                pressure_upper_range_value,
                IF (DIFFERENTIAL_SENSOR)
                {
                        static_pressure_units,
                        static_pressure_lower_range_value,
                        static_pressure_upper_range_value
                }

        }
}

MENU Tab_s_input_workingrange
{
        LABEL           [menu_input_workrange];
        ITEMS
        {
                ptrbScaleOutUnit,
                ptrbScaleOut0,
                ptrbScaleOut100
        }
}

MENU Tab_s_input_characterization
{
        LABEL           [menu_input_table];
        ITEMS
        {
                pressure_output_transfer_function,
                ptrbLowFlowCutOff,
                ptrbFlowLinSqrtPoint
        }
}

MENU Tab_s_input_coordinates
{
        LABEL           [menu_coordinate];
        ITEMS
        {
                ptrbTabActualNumber,
                ptrbTabXValue2,
                ptrbTabYValue2,
                ptrbTabXValue3,
                ptrbTabYValue3,
                ptrbTabXValue4,
                ptrbTabYValue4,
                ptrbTabXValue5,
                ptrbTabYValue5,
                ptrbTabXValue6,
                ptrbTabYValue6,
                ptrbTabXValue7,
                ptrbTabYValue7,
                ptrbTabXValue8,
                ptrbTabYValue8,
                ptrbTabXValue9,
                ptrbTabYValue9,
                ptrbTabXValue10,
                ptrbTabYValue10,
                ptrbTabXValue11,
                ptrbTabYValue11,
                ptrbTabXValue12,
                ptrbTabYValue12,
                ptrbTabXValue13,
                ptrbTabYValue13,
                ptrbTabXValue14,
                ptrbTabYValue14,
                ptrbTabXValue15,
                ptrbTabYValue15,
                ptrbTabXValue16,
                ptrbTabYValue16,
                ptrbTabXValue17,
                ptrbTabYValue17,
                ptrbTabXValue18,
                ptrbTabYValue18,
                ptrbTabXValue19,
                ptrbTabYValue19,
                ptrbTabXValue20,
                ptrbTabYValue20
                ptrbTabXValue21,
                ptrbTabYValue21
        }
        VALIDITY IF(pressure_output_transfer_function == 4)
        {
                TRUE;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Tab_s_input_sensortemperatur
{
        LABEL           [sensor_temperature];
        ITEMS
        {
                temperature.DIGITAL_UNITS
        }
}

MENU Tab_s_output
{
        LABEL           [menu_output];
        ITEMS
        {
                Tab_s_differentialpressure,
                Tab_s_localhumaninterface
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Tab_s_differentialpressure
{
        LABEL   IF (DIFFERENTIAL_SENSOR)
        {
                [menu_differentialpressure];
        }
        ELSE
        {
                [menu_static_pressure];
        }
        ITEMS
        {
                aidp_outscale_units,
                pressure_damping_value,
                Tab_s_outputscale,
                Tab_s_outputlimits
        }
}

MENU Tab_s_outputscale
{
        LABEL           [menu_output_scalewindow];
        ITEMS
        {
                aidp_outscale_0,
                aidp_outscale_100
        }
}

MENU Tab_s_localhumaninterface
{
        LABEL           [menu_interface_local];
        ITEMS
        {
                local_keys_mode_control_codes,
                write_protect,
                meter_installation
        }
}

MENU Tab_s_outputlimits
{
        LABEL           [menu_output_limits];
        ITEMS
        {
                aiDPLoLoLim,
                aiDPLoLim,
            aiDPHiLim,
            aiDPHiHiLim,
                aiDPAlarmHys
        }
}

MENU Tab_s_const
{
        LABEL           [menu_construct];
        ITEMS
        {
                Tab_s_const_design,
                Tab_s_const_proc
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Tab_s_const_design
{
        LABEL           [menu_const_design];
        ITEMS
        {
                Tab_s_const_design_sensor,
                Tab_s_const_design_remseal
        }
}

MENU Tab_s_const_design_sensor
{
        LABEL           [menu_const_design_sensor];
        ITEMS
        {
                module_fill_fluid,
                module_isolator_material,
                o_ring_material
        }
}

MENU Tab_s_const_design_remseal
{
        LABEL           [menu_remote_seal];
        ITEMS
        {
                number_of_remote_seals,
                remote_seal_type,
                remote_seal_fill_fluid,
                remote_seal_isolator_material
        }
}

MENU Tab_s_const_proc
{
        LABEL           [menu_const_proc];
        ITEMS
        {
                flange_type,
                flange_material,
                drain_vent_material
        }
}

MENU Tab_s_sensorcalibration
{
        LABEL           [menu_interface_set];
        ITEMS
        {
                ptrbSensorCalDate,
                ptrbSensorCalWho,
                ptrbTemperatureTrimValue
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Tab_s_certificatesandapprovals
{
        LABEL           [menu_certificates];
        ITEMS
        {
                pbDeviceCertification(READ_ONLY),
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

/*******************************************************************************/
/*****  Table: Maintenance  ****************************************************/
/*******************************************************************************/
MENU Table_Main_Maintenance
{
        LABEL            "2600T-263/265" ;
        ITEMS
        {
                Tab_m_ident,
                Tab_m_input,
                Tab_m_output,
                Tab_m_const,
                Tab_m_sensorcalibration,
                Tab_m_certificatesandapprovals

        }
}

MENU Tab_m_ident
{
        LABEL           [menu_ident];
        ITEMS
        {
                Tab_m_ident_opunit,
                Tab_m_ident_device

        }
}

MENU Tab_m_ident_device
{
        LABEL           [menu_ident_device];
        ITEMS
        {
                manufacturer_id,
                device_id,
                software_revision,
                hardware_revision,
                date,
                module_type_code,
                PV.SENSOR_SERIAL_NUMBER(READ_ONLY),
                pbsoftwarespecifics(READ_ONLY),
                write_protect,
                pbWriteLock(READ_ONLY)
        }

}

MENU Tab_m_input
{
        LABEL           [menu_input];
        ITEMS
        {
                Tab_m_input_range_limit,
                Tab_m_input_measwindow,
                Tab_m_input_workingrange,
                Tab_m_input_characterization,
                Tab_m_input_coordinates,
                Tab_m_input_sensortemperatur

        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Tab_m_input_range_limit
{
        LABEL           [menu_input_measrange];
        ITEMS
        {
                pressure_sensor_units(READ_ONLY),
                pressure_lower_range_limit(READ_ONLY),
                pressure_upper_range_limit(READ_ONLY),
                static_pressure_hi_lim(READ_ONLY),
                static_pressure_lo_lim(READ_ONLY)
        }
}

MENU   Tab_m_input_measwindow
{
        LABEL           [menu_input_meassurerange];
        ITEMS
        {
                static_pressure_lo_lim(HIDDEN),
                static_pressure_hi_lim(HIDDEN),
                pressure_lower_range_limit(HIDDEN),
                pressure_upper_range_limit(HIDDEN),
                pressure_units(READ_ONLY),
                pressure_lower_range_value(READ_ONLY),
                pressure_upper_range_value(READ_ONLY),
                IF (DIFFERENTIAL_SENSOR)
                {
                        static_pressure_units(READ_ONLY),
                        static_pressure_lower_range_value(READ_ONLY),
                        static_pressure_upper_range_value(READ_ONLY),
                }

        }
}

MENU Tab_m_input_workingrange
{
        LABEL           [menu_input_workrange];
        ITEMS
        {
                ptrbScaleOutUnit(READ_ONLY),
                ptrbScaleOut0(READ_ONLY),
                ptrbScaleOut100(READ_ONLY)
        }
}

MENU Tab_m_input_characterization
{
        LABEL           [menu_input_table];
        ITEMS
        {
                pressure_output_transfer_function(READ_ONLY),
                ptrbLowFlowCutOff(READ_ONLY),
                ptrbFlowLinSqrtPoint(READ_ONLY)
        }
}

MENU Tab_m_input_coordinates
{
        LABEL           [menu_coordinate];
        ITEMS
        {
                ptrbTabActualNumber,
                ptrbTabXValue2,
                ptrbTabYValue2,
                ptrbTabXValue3,
                ptrbTabYValue3,
                ptrbTabXValue4,
                ptrbTabYValue4,
                ptrbTabXValue5,
                ptrbTabYValue5,
                ptrbTabXValue6,
                ptrbTabYValue6,
                ptrbTabXValue7,
                ptrbTabYValue7,
                ptrbTabXValue8,
                ptrbTabYValue8,
                ptrbTabXValue9,
                ptrbTabYValue9,
                ptrbTabXValue10,
                ptrbTabYValue10,
                ptrbTabXValue11,
                ptrbTabYValue11,
                ptrbTabXValue12,
                ptrbTabYValue12,
                ptrbTabXValue13,
                ptrbTabYValue13,
                ptrbTabXValue14,
                ptrbTabYValue14,
                ptrbTabXValue15,
                ptrbTabYValue15,
                ptrbTabXValue16,
                ptrbTabYValue16,
                ptrbTabXValue17,
                ptrbTabYValue17,
                ptrbTabXValue18,
                ptrbTabYValue18,
                ptrbTabXValue19,
                ptrbTabYValue19,
                ptrbTabXValue20,
                ptrbTabYValue20
                ptrbTabXValue21,
                ptrbTabYValue21

        }
        VALIDITY IF(pressure_output_transfer_function == 4)
        {
                TRUE;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Tab_m_input_sensortemperatur
{
        LABEL           [sensor_temperature];
        ITEMS
        {
                temperature.DIGITAL_UNITS(READ_ONLY)
        }
}

MENU Tab_m_output
{
        LABEL           [menu_output];
        ITEMS
        {
                Tab_m_differentialpressure,
                Tab_m_localhumaninterface
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Tab_m_differentialpressure
{
        LABEL           [menu_differentialpressure];
        ITEMS
        {
                aidp_outscale_units(READ_ONLY),
                pressure_damping_value(READ_ONLY),
                Tab_m_outputscale(READ_ONLY),
                Tab_m_outputlimits(READ_ONLY)
        }
}

MENU Tab_m_outputscale
{
        LABEL           [menu_output_scalewindow];
        ITEMS
        {
                aidp_outscale_0(READ_ONLY),
                aidp_outscale_100(READ_ONLY)
        }
}

MENU Tab_m_localhumaninterface
{
        LABEL           [menu_interface_local];
        ITEMS
        {
                local_keys_mode_control_codes(READ_ONLY),
                write_protect,
                meter_installation(READ_ONLY)
        }
}

MENU Tab_m_outputlimits
{
        LABEL           [menu_output_limits];
        ITEMS
        {
                aiDPLoLoLim(READ_ONLY),
                aiDPLoLim(READ_ONLY),
            aiDPHiLim(READ_ONLY),
            aiDPHiHiLim(READ_ONLY),
                aiDPAlarmHys(READ_ONLY)
        }
}

MENU Tab_m_const
{
        LABEL           [menu_construct];
        ITEMS
        {
                Tab_m_const_design,
                Tab_m_const_proc
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Tab_m_const_design
{
        LABEL           [menu_const_design];
        ITEMS
        {
                Tab_m_const_design_sensor,
                Tab_m_const_design_remseal
        }
}

MENU Tab_m_const_design_sensor
{
        LABEL           [menu_const_design_sensor];
        ITEMS
        {
                module_fill_fluid,
                module_isolator_material,
                o_ring_material(READ_ONLY)
        }
}

MENU Tab_m_const_design_remseal
{
        LABEL           [menu_remote_seal];
        ITEMS
        {
                number_of_remote_seals(READ_ONLY),
                remote_seal_type(READ_ONLY),
                remote_seal_fill_fluid(READ_ONLY),
                remote_seal_isolator_material(READ_ONLY)
        }
}

MENU Tab_m_const_proc
{
        LABEL           [menu_const_proc];
        ITEMS
        {
                flange_type(READ_ONLY),
                flange_material(READ_ONLY),
                drain_vent_material(READ_ONLY)
        }
}

MENU Tab_m_sensorcalibration
{
        LABEL           [menu_interface_set];
        ITEMS
        {
                ptrbSensorCalDate(READ_ONLY),
                ptrbSensorCalWho(READ_ONLY),
                ptrbTemperatureTrimValue(READ_ONLY)
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Tab_m_certificatesandapprovals
{
        LABEL           [menu_certificates];
        ITEMS
        {
                pbDeviceCertification(READ_ONLY)
        }
        VALIDITY IF ( software_revision >= 21 )
        {
                TRUE ;
        }
        ELSE
        {
                FALSE;
        }
}
/*******************************************************************************/
/*****  Transmitter Specific COMMAND            ************************************/
/*******************************************************************************/

/*  Kommando #158  */

COMMAND read_sensor_cal_who
{
    NUMBER 158;
    OPERATION READ;
    TRANSACTION 0
    {
        REQUEST
        {
                        9
        }
        REPLY
        {
                response_code, device_status,
                9,ptrbSensorCalWho
        }
    }

        TRANSACTION 1
    {
        REQUEST
        {
                        13
        }
        REPLY
        {
                response_code, device_status,
                13,pbDeviceCertification
        }
    }
        RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #159  */

COMMAND write_sensor_cal_who
{
    NUMBER 159;
    OPERATION WRITE;
    TRANSACTION 0
    {
        REQUEST
        {
                9,ptrbSensorCalWho
        }
        REPLY
        {
                response_code, device_status,
                9,ptrbSensorCalWho
        }
    }

        TRANSACTION 1
    {
        REQUEST
        {
                13,pbDeviceCertification
        }
        REPLY
        {
                response_code, device_status,
                13,pbDeviceCertification
        }
    }
        RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}


/*  Kommando #166  */

COMMAND read_sensor_cal
{
    NUMBER 166;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
                response_code, device_status,
                ptrbSensorCalMethod, ptrbSensorCalDate
        }
    }
    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #167  */

COMMAND write_sensor_cal
{
    NUMBER 167;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
                ptrbSensorCalMethod, ptrbSensorCalDate
        }
        REPLY
        {
                response_code, device_status,
                ptrbSensorCalMethod, ptrbSensorCalDate
        }
    }
    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #170  */

COMMAND read_aidplim
{
    NUMBER 170;
    OPERATION READ;
    TRANSACTION 0
    {
        REQUEST
        {
            1
        }
        REPLY
        {
                response_code, device_status,
                1, aiDPHiHiLim, aiDPLoLoLim
        }
    }

    TRANSACTION 1
    {
        REQUEST
        {
            2
        }
        REPLY
        {
                response_code, device_status,
                2, aiDPHiLim, aiDPLoLim
        }
    }

    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #171  */

COMMAND write_aidplim
{
    NUMBER 171;
    OPERATION WRITE;
    TRANSACTION 0
    {
        REQUEST
        {
                1, aiDPHiHiLim, aiDPLoLoLim
        }
        REPLY
        {
                response_code, device_status,
                1, aiDPHiHiLim, aiDPLoLoLim
        }
    }

        TRANSACTION 1
    {
        REQUEST
        {
                2, aiDPHiLim, aiDPLoLim
        }
        REPLY
        {
                response_code, device_status,
                2, aiDPHiLim, aiDPLoLim
        }
    }
    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR,    [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR,    [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR,                 "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR,                 "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #172  */

COMMAND read_aidpoutunittext
{
    NUMBER 172;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
            2
        }
        REPLY
        {
                response_code, device_status,
                2,aiDPIoOpts,aiDPStatusOptsFF,aiDPChannel,aiDPLType,aiDPLowCut,aiDPAlarmHys,aidpoutunittext
        }
    }

     RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #173  */

COMMAND write_aidpoutunittext
{
    NUMBER 173;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
                2,aiDPIoOpts,aiDPStatusOptsFF,aiDPChannel,aiDPLType,aiDPLowCut,aiDPAlarmHys,aidpoutunittext
        }
        REPLY
        {
                response_code, device_status,
                2,aiDPIoOpts,aiDPStatusOptsFF,aiDPChannel,aiDPLType,aiDPLowCut,aiDPAlarmHys,aidpoutunittext
        }
    }

    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #224  */

COMMAND read_ptrbtabxyvalue
{
    NUMBER 224;
    OPERATION READ;

/*      TRANSACTION 0
    {
        REQUEST
        {
            21
        }
        REPLY
        {
                response_code, device_status,
                21, ptrbTabXValue1, ptrbTabYValue1
        }
    }
*/      TRANSACTION 1
    {
        REQUEST
        {
            1
        }
        REPLY
        {
                response_code, device_status,
                1, ptrbTabXValue2, ptrbTabYValue2
        }
    }

        TRANSACTION 2
    {
        REQUEST
        {
            2
        }
        REPLY
        {
                response_code, device_status,
                2, ptrbTabXValue3, ptrbTabYValue3
        }
    }

        TRANSACTION 3
    {
        REQUEST
        {
            3
        }
        REPLY
        {
                response_code, device_status,
                3, ptrbTabXValue4, ptrbTabYValue4
        }
    }

        TRANSACTION 4
    {
        REQUEST
        {
            4
        }
        REPLY
        {
                response_code, device_status,
                4, ptrbTabXValue5, ptrbTabYValue5
        }
    }

        TRANSACTION 5
    {
        REQUEST
        {
            5
        }
        REPLY
        {
                response_code, device_status,
                5, ptrbTabXValue6, ptrbTabYValue6
        }
    }

        TRANSACTION 6
    {
        REQUEST
        {
            6
        }
        REPLY
        {
                response_code, device_status,
                6, ptrbTabXValue7, ptrbTabYValue7
        }
    }

        TRANSACTION 7
    {
        REQUEST
        {
            7
        }
        REPLY
        {
                response_code, device_status,
                7, ptrbTabXValue8, ptrbTabYValue8
        }
    }

        TRANSACTION 8
    {
        REQUEST
        {
            8
        }
        REPLY
        {
                response_code, device_status,
                8, ptrbTabXValue9, ptrbTabYValue9
        }
    }

        TRANSACTION 9
    {
        REQUEST
        {
            9
        }
        REPLY
        {
                response_code, device_status,
                9, ptrbTabXValue10, ptrbTabYValue10
        }
    }

        TRANSACTION 10
    {
        REQUEST
        {
            10
        }
        REPLY
        {
                response_code, device_status,
                10, ptrbTabXValue11, ptrbTabYValue11
        }
    }

        TRANSACTION 11
    {
        REQUEST
        {
            11
        }
        REPLY
        {
                response_code, device_status,
                11, ptrbTabXValue12, ptrbTabYValue12
        }
    }

        TRANSACTION 12
    {
        REQUEST
        {
            12
        }
        REPLY
        {
                response_code, device_status,
                12, ptrbTabXValue13, ptrbTabYValue13
        }
    }

        TRANSACTION 13
    {
        REQUEST
        {
            13
        }
        REPLY
        {
                response_code, device_status,
                13, ptrbTabXValue14, ptrbTabYValue14
        }
    }

        TRANSACTION 14
    {
        REQUEST
        {
            14
        }
        REPLY
        {
                response_code, device_status,
                14, ptrbTabXValue15, ptrbTabYValue15
        }
    }

        TRANSACTION 15
    {
        REQUEST
        {
            15
        }
        REPLY
        {
                response_code, device_status,
                15, ptrbTabXValue16, ptrbTabYValue16
        }
    }

        TRANSACTION 16
    {
        REQUEST
        {
            16
        }
        REPLY
        {
                response_code, device_status,
                16, ptrbTabXValue17, ptrbTabYValue17
        }
    }

        TRANSACTION 17
    {
        REQUEST
        {
            17
        }
        REPLY
        {
                response_code, device_status,
                17, ptrbTabXValue18, ptrbTabYValue18
        }
    }

        TRANSACTION 18
    {
        REQUEST
        {
            18
        }
        REPLY
        {
                response_code, device_status,
                18, ptrbTabXValue19, ptrbTabYValue19
        }
    }

        TRANSACTION 19
    {
        REQUEST
        {
            19
        }
        REPLY
        {
                response_code, device_status,
                19, ptrbTabXValue20, ptrbTabYValue20
        }
    }

        TRANSACTION 20
    {
        REQUEST
        {
            20
        }
        REPLY
        {
                response_code, device_status,
                20, ptrbTabXValue21, ptrbTabYValue21
        }
    }
        RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #225  */

COMMAND write_ptrbtabxyvalue
{
    NUMBER 225;
    OPERATION WRITE;

        TRANSACTION 1
    {
        REQUEST
        {
                1, ptrbTabXValue2, ptrbTabYValue2
        }
        REPLY
        {
                response_code, device_status,
                1, ptrbTabXValue2, ptrbTabYValue2
        }
    }

        TRANSACTION 2
    {
        REQUEST
        {
                2, ptrbTabXValue3, ptrbTabYValue3
        }
        REPLY
        {
                response_code, device_status,
                2, ptrbTabXValue3, ptrbTabYValue3
        }
    }

        TRANSACTION 3
    {
        REQUEST
        {
                3, ptrbTabXValue4, ptrbTabYValue4
        }
        REPLY
        {
                response_code, device_status,
                3, ptrbTabXValue4, ptrbTabYValue4
        }
    }

        TRANSACTION 4
    {
        REQUEST
        {
                4, ptrbTabXValue5, ptrbTabYValue5
        }
        REPLY
        {
                response_code, device_status,
                4, ptrbTabXValue5, ptrbTabYValue5
        }
    }

        TRANSACTION 5
    {
        REQUEST
        {
                5, ptrbTabXValue6, ptrbTabYValue6
        }
        REPLY
        {
                response_code, device_status,
                5, ptrbTabXValue6, ptrbTabYValue6
        }
    }

        TRANSACTION 6
    {
        REQUEST
        {
                6, ptrbTabXValue7, ptrbTabYValue7
        }
        REPLY
        {
                response_code, device_status,
                6, ptrbTabXValue7, ptrbTabYValue7
        }
    }

        TRANSACTION 7
    {
        REQUEST
        {
                7, ptrbTabXValue8, ptrbTabYValue8
        }
        REPLY
        {
                response_code, device_status,
                7, ptrbTabXValue8, ptrbTabYValue8
        }
    }

        TRANSACTION 8
    {
        REQUEST
        {
                8, ptrbTabXValue9, ptrbTabYValue9
        }
        REPLY
        {
                response_code, device_status,
                8, ptrbTabXValue9, ptrbTabYValue9
        }
    }

        TRANSACTION 9
    {
        REQUEST
        {
                9, ptrbTabXValue10, ptrbTabYValue10
        }
        REPLY
        {
                response_code, device_status,
                9, ptrbTabXValue10, ptrbTabYValue10
        }
    }

        TRANSACTION 10
    {
        REQUEST
        {
                10, ptrbTabXValue11, ptrbTabYValue11
        }
        REPLY
        {
                response_code, device_status,
                10, ptrbTabXValue11, ptrbTabYValue11
        }
    }

        TRANSACTION 11
    {
        REQUEST
        {
                11, ptrbTabXValue12, ptrbTabYValue12
        }
        REPLY
        {
                response_code, device_status,
                11, ptrbTabXValue12, ptrbTabYValue12
        }
    }

        TRANSACTION 12
    {
        REQUEST
        {
                12, ptrbTabXValue13, ptrbTabYValue13
        }
        REPLY
        {
                response_code, device_status,
                12, ptrbTabXValue13, ptrbTabYValue13
        }
    }

        TRANSACTION 13
    {
        REQUEST
        {
                13, ptrbTabXValue14, ptrbTabYValue14
        }
        REPLY
        {
                response_code, device_status,
                13, ptrbTabXValue14, ptrbTabYValue14
        }
    }

        TRANSACTION 14
    {
        REQUEST
        {
                14, ptrbTabXValue15, ptrbTabYValue15
        }
        REPLY
        {
                response_code, device_status,
                14, ptrbTabXValue15, ptrbTabYValue15
        }
    }

        TRANSACTION 15
    {
        REQUEST
        {
                15, ptrbTabXValue16, ptrbTabYValue16
        }
        REPLY
        {
                response_code, device_status,
                15, ptrbTabXValue16, ptrbTabYValue16
        }
    }

        TRANSACTION 16
    {
        REQUEST
        {
                16, ptrbTabXValue17, ptrbTabYValue17
        }
        REPLY
        {
                response_code, device_status,
                16, ptrbTabXValue17, ptrbTabYValue17
        }
    }

        TRANSACTION 17
    {
        REQUEST
        {
                17, ptrbTabXValue18, ptrbTabYValue18
        }
        REPLY
        {
                response_code, device_status,
                17, ptrbTabXValue18, ptrbTabYValue18
        }
    }

        TRANSACTION 18
    {
        REQUEST
        {
                18, ptrbTabXValue19, ptrbTabYValue19
        }
        REPLY
        {
                response_code, device_status,
                18, ptrbTabXValue19, ptrbTabYValue19
        }
    }

        TRANSACTION 19
    {
        REQUEST
        {
                19, ptrbTabXValue20, ptrbTabYValue20
        }
        REPLY
        {
                response_code, device_status,
                19, ptrbTabXValue20, ptrbTabYValue20
        }
    }

        TRANSACTION 20
    {
        REQUEST
        {
                20, ptrbTabXValue21, ptrbTabYValue21
        }
        REPLY
        {
                response_code, device_status,
                20, ptrbTabXValue21, ptrbTabYValue21
        }
    }
        RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #226  */

COMMAND read_pbsoftwarespecifics
{
    NUMBER 226;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
                response_code, device_status,
                pbsoftwarespecifics
        }
    }
    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #239  */

COMMAND write_sensor_temperature
{
    NUMBER 239;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
                ptrbTemperatureValueUnit,ptrbTemperatureTrimValue
        }
        REPLY
        {
                response_code, device_status,
                ptrbTemperatureValueUnit,ptrbTemperatureTrimValue
        }
    }
    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #242  */

COMMAND read_ptrbMaxSensorValue
{
    NUMBER 242;
    OPERATION READ;
    TRANSACTION 0
    {
        REQUEST
        {
                        1
        }
        REPLY
        {
                        response_code, device_status,
                        1,ptrbMaxSensorValue
        }
    }

        TRANSACTION 1
    {
        REQUEST
        {
                        2
        }
        REPLY
        {
                        response_code, device_status,
                        2,ptrbMinSensorValue
        }
    }

        TRANSACTION 2
    {
        REQUEST
        {
                        3
        }
        REPLY
        {
                        response_code, device_status,
                        3,ptrbMaxTemperature
        }
    }

        TRANSACTION 3
    {
        REQUEST
        {
                        4
        }
        REPLY
        {
                        response_code, device_status,
                        4,ptrbMinTemperature
        }
    }

        TRANSACTION 4
    {
        REQUEST
        {
                        5
        }
        REPLY
        {
                        response_code, device_status,
                        5,ptrbMaxStaticPressure
        }
    }

        TRANSACTION 5
    {
        REQUEST
        {
                        6
        }
        REPLY
        {
                        response_code, device_status,
                        6,ptrbMinStaticPressure
        }
    }
        RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3,  DATA_ENTRY_ERROR,   [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR,   [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #243  */

COMMAND write_ptrbMaxSensorValue
{
    NUMBER 243;
    OPERATION WRITE;
    TRANSACTION 0
    {
        REQUEST
        {
                        1,ptrbMaxSensorValue
        }
        REPLY
        {
                        response_code, device_status,
                        1,ptrbMaxSensorValue
        }
    }

        TRANSACTION 1
    {
        REQUEST
        {
                        2,ptrbMinSensorValue
        }
        REPLY
        {
                        response_code, device_status,
                        2,ptrbMinSensorValue
        }
    }

        TRANSACTION 2
    {
        REQUEST
        {
                        3,ptrbMaxTemperature
        }
        REPLY
        {
                        response_code, device_status,
                        3,ptrbMaxTemperature
        }
    }
        TRANSACTION 3
    {
        REQUEST
        {
                        4,ptrbMinTemperature
        }
        REPLY
        {
                        response_code, device_status,
                        4,ptrbMinTemperature
        }
    }
        TRANSACTION 4
    {
        REQUEST
        {
                        5,ptrbMaxStaticPressure
        }
        REPLY
        {
                        response_code, device_status,
                        5,ptrbMaxStaticPressure
        }
    }

        TRANSACTION 5
    {
        REQUEST
        {
                        6,ptrbMinStaticPressure
        }
        REPLY
        {
                        response_code, device_status,
                        6,ptrbMinStaticPressure
        }
    }
        RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,               [invalid_selection];
                3,      DATA_ENTRY_ERROR,               [passed_parameter_too_large];
                4,      DATA_ENTRY_ERROR,               [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,               [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,               [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,               [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,               [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,               [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,             [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17,     MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29,     MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #162  */

COMMAND read_aiPModeBlkTarget
{
    NUMBER 162;
    OPERATION READ;
    TRANSACTION 0
    {
        REQUEST
        {
                        2
        }
        REPLY
        {
                response_code, device_status,
                        2, aiDPModeBlkTarget, aiDPModeBlkPermitted, aiDPModeBlkNormal
        }
    }

    TRANSACTION 1
    {
        REQUEST
        {
                        8
        }
        REPLY
        {
                response_code, device_status,
                        8, aiPModeBlkTarget, aiPModeBlkPermitted, aiPModeBlkNormal
        }
    }

    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3,  DATA_ENTRY_ERROR,   [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR,   [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #163  */

COMMAND write_aiPModeBlkTarget
{
    NUMBER 163;
    OPERATION WRITE;
    TRANSACTION 0
    {
        REQUEST
        {
                        2,aiDPModeBlkTarget, aiDPModeBlkPermitted, aiDPModeBlkNormal
        }
        REPLY
        {
                response_code, device_status,
                        2,aiDPModeBlkTarget, aiDPModeBlkPermitted, aiDPModeBlkNormal
        }
    }

        TRANSACTION 1
    {
        REQUEST
        {
                        8,aiPModeBlkTarget, aiPModeBlkPermitted, aiPModeBlkNormal
        }
        REPLY
        {
                response_code, device_status,
                        8,aiPModeBlkTarget, aiPModeBlkPermitted, aiPModeBlkNormal
        }
    }

    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3,  DATA_ENTRY_ERROR,   [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR,   [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #174  */

COMMAND read_aiPOutValue
{
    NUMBER 174;
    OPERATION READ;
    TRANSACTION 0
    {
        REQUEST
        {
                        2
        }
        REPLY
        {
                        response_code, device_status,
                        2,aiPPvFtime,aiPOutValue,
                        aiPOutStatus_quality<0xFC>,
                        aiPOutStatus_limit<0x03>,
                        aiPFieldValue,aiPFieldStatus,aiPPvValue,aiPPvStatus,aiPModeBlkActual
        }
    }
    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3,  DATA_ENTRY_ERROR,   [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR,   [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #175  */

COMMAND write_aiPOutValue
{
    NUMBER 175;
    OPERATION WRITE;
    TRANSACTION 0
    {
        REQUEST
        {
                        2,aiPPvFtime,aiPOutValue,
                        aiPOutStatus_quality<0xFC>,
                        aiPOutStatus_limit<0x03>,
                        aiPFieldValue,aiPFieldStatus,aiPPvValue,aiPPvStatus,aiPModeBlkActual
        }
        REPLY
        {
                        response_code, device_status,
                        2,aiPPvFtime,aiPOutValue,
                        aiPOutStatus_quality<0xFC>,
                        aiPOutStatus_limit<0x03>,
                        aiPFieldValue,aiPFieldStatus,aiPPvValue,aiPPvStatus,aiPModeBlkActual
        }
    }
    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3,  DATA_ENTRY_ERROR,   [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR,   [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #178  */

COMMAND read_aiDPOutValue
{
    NUMBER 178;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {

        }
        REPLY
        {
                        response_code, device_status,
                        aiDPOutValue,
                        aiDPOutStatus_quality<0xFC>,
                        aiDPOutStatus_limit<0x03>,
                        aiDPFieldValue,aiDPFieldStatus,aiDPPvValue,aiDPPvStatus,aiDPModeBlkActual
        }
    }
    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3,  DATA_ENTRY_ERROR,   [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR,   [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #179  */

COMMAND write_aiDPOutValue
{
    NUMBER 179;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
                        aiDPOutValue,
                        aiDPOutStatus_quality<0xFC>,
                        aiDPOutStatus_limit<0x03>

        }
        REPLY
        {
                        response_code, device_status,
                        aiDPOutValue,
                        aiDPOutStatus_quality<0xFC>,
                        aiDPOutStatus_limit<0x03>
        }
    }
    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3,  DATA_ENTRY_ERROR,   [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR,   [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #188  */

COMMAND read_aiPSimulateEnabled
{
    NUMBER 188;
    OPERATION READ;
    TRANSACTION 0
    {
        REQUEST
        {
                        9
        }
        REPLY
        {
                response_code, device_status
                9,aiDPSimulateEnabled, aiDPSimulateValue,
                        aiDPSimulateStatus_quality<0xFC>,
                        aiDPSimulateStatus_limit<0x03>
        }
    }

        TRANSACTION 1
    {
        REQUEST
        {
                        11
        }
        REPLY
        {
                response_code, device_status,
                11,aiPSimulateEnabled, aiPSimulateValue,
                        aiPSimulateStatus_quality<0xFC>,
                        aiPSimulateStatus_limit<0x03>
        }
    }

    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/*  Kommando #189  */

COMMAND write_aiPSimulateEnabled
{
    NUMBER 189;
    OPERATION WRITE;
    TRANSACTION 0
    {
        REQUEST
        {
                9,aiDPSimulateEnabled, aiDPSimulateValue,
                        aiDPSimulateStatus_quality<0xFC>,
                        aiDPSimulateStatus_limit<0x03>
        }
        REPLY
        {
                response_code, device_status,
                9,aiDPSimulateEnabled, aiDPSimulateValue,
                        aiDPSimulateStatus_quality<0xFC>,
                        aiDPSimulateStatus_limit<0x03>
        }
    }

    TRANSACTION 1
    {
        REQUEST
        {
                11,aiPSimulateEnabled, aiPSimulateValue,
                        aiPSimulateStatus_quality<0xFC>,
                        aiPSimulateStatus_limit<0x03>
        }
        REPLY
        {
                response_code, device_status,
                11,aiPSimulateEnabled, aiPSimulateValue,
                        aiPSimulateStatus_quality<0xFC>,
                        aiPSimulateStatus_limit<0x03>
        }
    }

    RESPONSE_CODES
    {
                0,      SUCCESS,                        [no_command_specific_errors];
                2,      DATA_ENTRY_ERROR,       [invalid_selection];
        3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5,      MISC_ERROR,                     [too_few_data_bytes_recieved];
                6,      MISC_ERROR,                     [xmtr_specific_command_error];
                7,      MODE_ERROR,                     [in_write_protect_mode];
                9,      DATA_ENTRY_ERROR,       [lower_range_value_too_high];
                10,     DATA_ENTRY_ERROR,       [lower_range_value_too_low];
                11,     DATA_ENTRY_ERROR,       [upper_range_value_too_high];
                12,     DATA_ENTRY_ERROR,       [upper_range_value_too_low];
                13,     DATA_ENTRY_ERROR,       [URV_and_LRV_out_of_limits];
                14,     DATA_ENTRY_WARNING,     [span_too_small];
                16,     MODE_ERROR,                     [access_restricted];
                17, MISC_ERROR, "|001Invalid float format|049ungltige Gleitkommazahl";
                29, MISC_ERROR, "|001Setting not accepted|049Kalibrierung fehlgeschlagen";
    }
}

/****************************************************************************** */
/*      Transmitter Specific Variables                                              */
/****************************************************************************** */
/*
VARIABLE ptrbTabXValue1
{
        LABEL "X 1";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ ;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 2)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue1
{
        LABEL "Y 1";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 2)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}
*/
VARIABLE ptrbTabXValue2
{
        LABEL "X[0]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 1)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue2
{
        LABEL "Y[0]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 1)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue3
{
        LABEL "X[1]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 2)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue3
{
        LABEL "Y[1]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 2)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue4
{
        LABEL "X[2]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 3)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue4
{
        LABEL "Y[2]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 3)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue5
{
        LABEL "X[3]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 4)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue5
{
        LABEL "Y[3]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 4)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue6
{
        LABEL "X[4]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 5)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue6
{
        LABEL "Y[4]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 5)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue7
{
        LABEL "X[5]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 6)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue7
{
        LABEL "Y[5]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 6)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue8
{
        LABEL "X[6]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 7)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue8
{
        LABEL "Y[6]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 7)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue9
{
        LABEL "X[7]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 8)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue9
{
        LABEL "Y[7]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 8)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue10
{
        LABEL "X[8]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 9)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue10
{
        LABEL "Y[8]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 9)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue11
{
        LABEL "X[9]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 10)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue11
{
        LABEL "Y[9]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 10)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue12
{
        LABEL "X[10]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 11)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue12
{
        LABEL "Y[10]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 11)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue13
{
        LABEL "X[11]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 12)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue13
{
        LABEL "Y[11]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 12)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue14
{
        LABEL "X[12]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 13)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue14
{
        LABEL "Y[12]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 13)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue15
{
        LABEL "X[13]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 14)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue15
{
        LABEL "Y[13]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 14)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue16
{
        LABEL "X[14]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 15)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue16
{
        LABEL "Y[14]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 15)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue17
{
        LABEL "X[15]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 16)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue17
{
        LABEL "Y[15]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 16)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue18
{
        LABEL "X[16]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 17)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue18
{
        LABEL "Y[16]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 17)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue19
{
        LABEL "X[17]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 18)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue19
{
        LABEL "Y[17]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 18)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue20
{
        LABEL "X[18]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 19)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue20
{
        LABEL "Y[18]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 19)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabXValue21
{
        LABEL "X[19]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 20)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue21
{
        LABEL "Y[19]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 20)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}
/*
VARIABLE ptrbTabXValue22
{
        LABEL "X[21]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 22)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}

VARIABLE ptrbTabYValue22
{
        LABEL "Y[21]";
        CLASS ANALOG_OUTPUT;
        TYPE FLOAT
          {
                DISPLAY_FORMAT    "5.2f";
                DEFAULT_VALUE       0.0;
                MIN_VALUE           0.0;
                MAX_VALUE         100.0;
          }
        HANDLING READ;
        CONSTANT_UNIT "%";
        VALIDITY IF (ptrbTabActualNumber < 22)
          {
                  FALSE;
          }
          ELSE
          {
                  TRUE;
          }
}
*/
VARIABLE aidpoutunittext
{
        LABEL           [aidpoutunittext];
        HELP            [aidpoutunittext_help];
        CLASS           DEVICE;
        TYPE            ASCII(5)
        {
                DEFAULT_VALUE   "mbar";
        }
        HANDLING READ & WRITE;
}

VARIABLE aiDPLoLoLim
{
        LABEL           [aiDPLoLoLim];
        HELP        [aiDPLoLoLim_help];
        CLASS           DEVICE;
        TYPE FLOAT
          {
                DEFAULT_VALUE   aidp_outscale_0;
          }
        HANDLING READ & WRITE;
}

VARIABLE aiDPLoLim
{
        LABEL           [aiDPLoLim];
        HELP        [aiDPLoLim_help];
        CLASS           DEVICE;
        TYPE FLOAT
          {
                DEFAULT_VALUE   aidp_outscale_0;
          }
        HANDLING READ & WRITE;
}

VARIABLE aiDPHiLim
{
        LABEL           [aiDPHiLim];
        HELP        [aiDPHiLim_help];
        CLASS           DEVICE;
        TYPE FLOAT
          {
                DEFAULT_VALUE   aidp_outscale_100;
          }
        HANDLING READ & WRITE;
}

VARIABLE aiDPHiHiLim
{
        LABEL           [aiDPHiHiLim];
        HELP        [aiDPHiHiLim_help];
        CLASS           DEVICE;
        TYPE FLOAT
          {
                DEFAULT_VALUE   aidp_outscale_100;
          }
        HANDLING READ & WRITE;
}

VARIABLE aiDPIoOpts
{
        LABEL           "";
        HELP            "";
        CLASS           DEVICE;
        TYPE            UNSIGNED_INTEGER (2);
        DEFAULT_VALUE   0;
        HANDLING        READ & WRITE;
}

VARIABLE aiDPStatusOptsFF
{
        LABEL           "";
        HELP            "";
        CLASS           DEVICE;
        TYPE            UNSIGNED_INTEGER (2);
        DEFAULT_VALUE   0;
        HANDLING        READ & WRITE;
}

VARIABLE aiDPChannel
{
        LABEL           "";
        HELP            "";
        CLASS           DEVICE;
        TYPE            UNSIGNED_INTEGER (2);
        DEFAULT_VALUE   1;
        HANDLING        READ & WRITE;
}

VARIABLE aiDPLType
{
        LABEL           "";
        HELP            "";
        CLASS           DEVICE;
        TYPE            UNSIGNED_INTEGER (1);
        DEFAULT_VALUE   0;
        HANDLING        READ & WRITE;
}

VARIABLE aiDPLowCut
{
        LABEL           "";
        HELP        "";
        CLASS           DEVICE;
        TYPE FLOAT
          {
                DEFAULT_VALUE   0.0;
                MIN_VALUE       0.0;
                MAX_VALUE       50.0;
          }
        HANDLING READ & WRITE;
}

VARIABLE aiDPAlarmHys
{
        LABEL           [limit_hysteresis];
        HELP        [limit_hysteresis_help];
        CLASS           DEVICE;
        TYPE FLOAT
          {
                DEFAULT_VALUE   0.5;
                MIN_VALUE       0.0;
                MAX_VALUE       50.0;
          }
        HANDLING READ & WRITE;
        CONSTANT_UNIT "%";
}

VARIABLE ptrbSensorCalDate
{
        LABEL   [ptrbSensorCalDate];
        HELP    [ptrbSensorCalDate_help];
        CLASS DEVICE;
        TYPE DATE
        {
                // @@st DEFAULT_VALUE   "0000308AE30A63";
                DEFAULT_VALUE   "01.01.03";
        }
        HANDLING READ & WRITE;
}

VARIABLE ptrbSensorCalMethod
{
        LABEL           "";
        HELP            "";
        CLASS           DEVICE;
        TYPE        ENUMERATED
        {
                DEFAULT_VALUE   0x67;
                SENSOR_CAL_METHOD_TABEL
        }
        HANDLING        READ & WRITE ;
}

VARIABLE ptrbSensorCalWho
{
        LABEL           [ptrbSensorCalWho];
        HELP            [ptrbSensorCalWho_help];
        CLASS           DEVICE;
        TYPE            ASCII(32)
        {
                DEFAULT_VALUE   "Seele";
        }
        HANDLING READ & WRITE;
}

VARIABLE ptrbTemperatureTrimValue
{
        LABEL           [sensor_temperature_trim];
        HELP        [sensor_temperature_trim_help];
        CLASS           DEVICE;
        TYPE FLOAT
          {
                DEFAULT_VALUE   0.0;
          }
        HANDLING WRITE;
}

VARIABLE ptrbTemperatureValueUnit
{
        LABEL           [ptrbTemperatureValueUnit];
        HELP        [ptrbTemperatureValueUnit_help];
        CLASS           DEVICE;
        TYPE UNSIGNED_INTEGER;
        HANDLING WRITE;
}

VARIABLE pbDeviceCertification
{
        LABEL           [pbDeviceCertification];
        HELP            [pbDeviceCertification_help];
        CLASS           DEVICE;
        TYPE            ASCII(32)
        {
                DEFAULT_VALUE   "";
        }
        HANDLING READ;// & WRITE;
}

VARIABLE pbsoftwarespecifics
{
        LABEL           [pbsoftwarespecifics];
        HELP            [pbsoftwarespecifics_help];
        CLASS           DEVICE;
        TYPE            ASCII(18)
        {
                DEFAULT_VALUE   "";
        }
        HANDLING READ & WRITE;
}

ptrbScaleOutUnit        LIKE VARIABLE   aidp_outscale_units
{
        REDEFINE        LABEL [units];
        REDEFINE DEFAULT_VALUE 57;
}

VARIABLE ptrbScaleOut0
{
    LABEL [lrv];
    HELP "|001Process value, lower range value"
             "|049Prozesswert, Messbereichsanfang";
    CLASS ANALOG_OUTPUT;
    TYPE FLOAT
    {
                DEFAULT_VALUE   0.0;
    }
    HANDLING READ & WRITE;
}

VARIABLE ptrbScaleOut100
{
    LABEL [urv];
    HELP "|001Process value, upper range value"
             "|049Prozesswert, Messbereichsende";
    CLASS ANALOG_OUTPUT;
    TYPE FLOAT
    {
                DEFAULT_VALUE   100.0;
    }
    HANDLING READ & WRITE;
}

ptrbScaleOutDecimal     LIKE VARIABLE   aidp_outscale_decimal
{
        REDEFINE        LABEL "";
}

VARIABLE ptrbSensorValue
{
        LABEL           [trans_pres_sensor_value];
        HELP            [trans_pres_sensor_value_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING        READ;
}

VARIABLE ptrbTrimmedValueStatus_quality
{
        LABEL           [status_quality];
        HELP            [value_status_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                STATUS_OUTPUT_NO_RCAS
        }
        HANDLING        READ;
}

ptrbTrimmedValueStatus_limit                    LIKE VARIABLE   ptrbTrimmedValueStatus_quality
{
        REDEFINE LABEL          [status_limit];
        REDEFINE TYPE           ENUMERATED (1)
        {
                STATUS_OUTPUT_LIMIT
        }
}

VARIABLE aiDPSimulateValue//func1_AI_simulate_value
{
        LABEL           [func_simulate_value];
        HELP            [func_ai_simulate_value_help];
        CLASS           CONTAINED & SERVICE;
        TYPE        FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aiDPSimulateStatus_quality//func1_AI_simulate_status_quality
{
        LABEL           [status_quality];
        HELP            [func_simulate_status_help];
        CLASS           CONTAINED & SERVICE;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                STATUS_INPUT_NO_RCAS
        }
        POST_EDIT_ACTIONS
        {
                method_set_status_limit_1
        }
        HANDLING        READ & WRITE;
}

aiDPSimulateStatus_limit /*func1_AI_simulate_status_limit*/ LIKE VARIABLE aiDPSimulateStatus_quality
{
        REDEFINE LABEL          [status_limit];
        REDEFINE TYPE           ENUMERATED (1)
        {
                STATUS_INPUT_LIMIT (aiDPSimulateStatus_quality)
        }
}

VARIABLE aiDPSimulateEnabled//func1_AI_simulation_enabled
{
        LABEL           [func_simulation_enabled];
        HELP            [func_simulation_enabled_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                {       0,      [disabled]              },
                {       1,      [enabled]               }
        }
        HANDLING        READ & WRITE;
}

VARIABLE aiDPPvValue
{
        LABEL           "";
        HELP            "";
        CLASS           OUTPUT & DYNAMIC;
        TYPE        FLOAT;

}

VARIABLE aiDPFieldValue
{
        LABEL           "";
        HELP            "";
        CLASS           OUTPUT & DYNAMIC;
        TYPE        FLOAT;

}

VARIABLE aiDPOutValue//func1_AI_out_value
{
        LABEL           [func_out_value];
        HELP            [func_ai_out_value_help];
        CLASS           OUTPUT & DYNAMIC;
        TYPE        FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING
                IF (aiDPModeBlkTarget/*func1_AI_target_mode*/ == BLOCK_MODE_MAN)
                {
                        READ & WRITE;
                }
                ELSE
                {
                        READ;
                }
}

VARIABLE aiDPModeBlkActual//func1_AI_actual_mode
{
        LABEL           [actual_mode];
        HELP            [actual_mode_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]                             },
                {       0x10,   [mode_MAN]                              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ;
}


VARIABLE aiDPModeBlkTarget//func1_AI_target_mode
{
        LABEL           [target_mode];
        HELP            [target_mode_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]                             },
                {       0x10,   [mode_MAN]                              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ & WRITE;
}

VARIABLE aiDPFieldStatus
{
        LABEL           "";
        HELP            "";
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER (1);
        HANDLING        READ & WRITE;
}

VARIABLE aiDPPvStatus
{
        LABEL           "";
        HELP            "";
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER (1);
        HANDLING        READ & WRITE;
}

VARIABLE aiDPOutStatus_quality//func1_AI_out_status_quality
{
        LABEL           [status_quality];
        HELP            [func_out_status_help];
        CLASS           OUTPUT & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                IF (aiDPModeBlkTarget/*func1_AI_target_mode*/ == BLOCK_MODE_MAN)
                {
                        STATUS_INPUT_NO_RCAS
                }
                ELSE
                {
                        STATUS_OUTPUT_NO_RCAS
                }
        }
        POST_EDIT_ACTIONS
        {
                IF (aiDPModeBlkTarget/*func1_AI_target_mode*/ == BLOCK_MODE_MAN)
                {
                        method_set_status_limit_1
                }
        }
        HANDLING
                IF (aiDPModeBlkTarget/*func1_AI_target_mode*/ == BLOCK_MODE_MAN)
                {
                        READ & WRITE;
                }
                ELSE
                {
                        READ;
                }
}

aiDPOutStatus_limit /*func1_AI_out_status_limit*/ LIKE VARIABLE    aiDPOutStatus_quality//func1_AI_out_status_quality
{
        REDEFINE LABEL          [status_limit];
        REDEFINE TYPE           ENUMERATED (1)
        {
                STATUS_INPUT_LIMIT (aiDPOutStatus_quality)/*func1_AI_out_status_quality*/
        }
}


VARIABLE aiDPModeBlkPermitted
{
        LABEL           [permitted_mode];
        HELP            [permitted_mode_help];
        CLASS           CONTAINED;
        TYPE            BIT_ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]                             },
                {       0x10,   [mode_MAN]                              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ & WRITE;
}

VARIABLE aiDPModeBlkNormal
{
        LABEL           [normal_mode];
        HELP            [normal_mode_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]                             },
                {       0x10,   [mode_MAN]                              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ & WRITE;
}

VARIABLE aiPSimulateValue//func2_AI_simulate_value
{
        LABEL           [func_simulate_value];
        HELP            [func_ai_simulate_value_help];
        CLASS           CONTAINED & SERVICE;
        TYPE        FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aiPSimulateStatus_quality//func2_AI_simulate_status_quality
{
        LABEL           [status_quality];
        HELP            [func_simulate_status_help];
        CLASS           CONTAINED & SERVICE;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                STATUS_INPUT_NO_RCAS
        }
        POST_EDIT_ACTIONS
        {
                method_set_status_limit_2
        }
        HANDLING        READ & WRITE;
}

aiPSimulateStatus_limit /*func2_AI_simulate_status_limit*/ LIKE VARIABLE  aiPSimulateStatus_quality
{
        REDEFINE LABEL          [status_limit];
        REDEFINE TYPE           ENUMERATED (1)
        {
                STATUS_INPUT_LIMIT (aiPSimulateStatus_quality)
        }
}

VARIABLE aiPSimulateEnabled//func2_AI_simulation_enabled
{
        LABEL           [func_simulation_enabled];
        HELP            [func_simulation_enabled_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                {       0,      [disabled]              },
                {       1,      [enabled]               }
        }
        HANDLING        READ & WRITE;
}

VARIABLE aiPPvValue
{
        LABEL           "";
        HELP            "";
        CLASS           OUTPUT & DYNAMIC;
        TYPE        FLOAT;

}

VARIABLE aiPFieldValue
{
        LABEL           "";
        HELP            "";
        CLASS           OUTPUT & DYNAMIC;
        TYPE        FLOAT;

}

VARIABLE aiPOutValue//func2_AI_out_value
{
        LABEL           [func_out_value];
        HELP            [func_ai_out_value_help];
        CLASS           OUTPUT & DYNAMIC;
        TYPE        FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING
                IF (aiPModeBlkTarget/*func2_AI_target_mode*/ == BLOCK_MODE_MAN)
                {
                        READ & WRITE;
                }
                ELSE
                {
                        READ;
                }
}

VARIABLE aiPModeBlkActual//func2_AI_actual_mode
{
        LABEL           [actual_mode];
        HELP            [actual_mode_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]                             },
                {       0x10,   [mode_MAN]                              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ;
}


VARIABLE aiPModeBlkTarget//func2_AI_target_mode
{
        LABEL           [target_mode];
        HELP            [target_mode_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]                             },
                {       0x10,   [mode_MAN]                              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ & WRITE;
}

VARIABLE aiPFieldStatus
{
        LABEL           "";
        HELP            "";
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER (1);
        HANDLING        READ & WRITE;
}

VARIABLE aiPPvStatus
{
        LABEL           "";
        HELP            "";
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER (1);
        HANDLING        READ & WRITE;
}


VARIABLE aiPOutStatus_quality//func2_AI_out_status_quality
{
        LABEL           [status_quality];
        HELP            [func_out_status_help];
        CLASS           OUTPUT & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                IF (aiPModeBlkTarget/*func2_AI_target_mode*/ == BLOCK_MODE_MAN)
                {
                        STATUS_INPUT_NO_RCAS
                }
                ELSE
                {
                        STATUS_OUTPUT_NO_RCAS
                }
        }
        POST_EDIT_ACTIONS
        {
                IF (aiPModeBlkTarget == BLOCK_MODE_MAN)//func2_AI_target_mode
                {
                        method_set_status_limit_2
                }
        }
        HANDLING
                IF (aiPModeBlkTarget/*func2_AI_target_mode*/ == BLOCK_MODE_MAN)
                {
                        READ & WRITE;
                }
                ELSE
                {
                        READ;
                }
}

aiPOutStatus_limit /*func2_AI_out_status_limit*/ LIKE VARIABLE     aiPOutStatus_quality//func2_AI_out_status_quality
{
        REDEFINE LABEL          [status_limit];
        REDEFINE TYPE           ENUMERATED (1)
        {
                STATUS_INPUT_LIMIT (aiPOutStatus_quality)/*func2_AI_out_status_quality*/
        }
}

VARIABLE aiPModeBlkPermitted
{
        LABEL           [permitted_mode];
        HELP            [permitted_mode_help];
        CLASS           CONTAINED;
        TYPE            BIT_ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]                             },
                {       0x10,   [mode_MAN]                              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ & WRITE;
}

VARIABLE aiPModeBlkNormal
{
        LABEL           [normal_mode];
        HELP            [normal_mode_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]                             },
                {       0x10,   [mode_MAN]                              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ & WRITE;
}

aiPOutStatus_limit /*func2_AI_out_status_limit*/ LIKE VARIABLE     aiPOutStatus_quality//func2_AI_out_status_quality
{
        REDEFINE LABEL          [status_limit];
        REDEFINE TYPE           ENUMERATED (1)
        {
                STATUS_INPUT_LIMIT (aiPOutStatus_quality)/*func2_AI_out_status_quality*/
        }
}

VARIABLE aiPOutValue//func2_AI_out_value
{
        LABEL           [func_out_value];
        HELP            [func_ai_out_value_help];
        CLASS           OUTPUT & DYNAMIC;
        TYPE        FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING
                IF (aiPModeBlkTarget/*func2_AI_target_mode*/ == BLOCK_MODE_MAN)
                {
                        READ & WRITE;
                }
                ELSE
                {
                        READ;
                }
}

VARIABLE aiPPvFtime//func2_AI_pv_ftime
{
        LABEL           [func_pv_ftime];
        HELP            [func_pv_ftime_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   1.0 ;
                MIN_VALUE               0.0;
                MAX_VALUE               300.0 ;
        }
        CONSTANT_UNIT   [sec];
        HANDLING        READ & WRITE;
}

VARIABLE aiDPPvFtime//func1_AI_pv_ftime
{
        LABEL           [func_pv_ftime];
        HELP            [func_pv_ftime_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   1.0 ;
                MIN_VALUE               0.0;
                MAX_VALUE               300.0 ;
        }
        CONSTANT_UNIT   [sec];
        HANDLING        READ & WRITE;
}

VARIABLE ptrbMinSensorValue
{
        LABEL         [trans_pres_min_sensor_value];
        HELP          [trans_pres_min_sensor_value_help];
        CLASS         CONTAINED & DYNAMIC;
        TYPE          FLOAT;
        HANDLING      READ & WRITE;
}

VARIABLE ptrbMaxSensorValue
{
        LABEL         [trans_pres_max_sensor_value];
        HELP          [trans_pres_max_sensor_value_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ & WRITE;
}

VARIABLE ptrbMaxStaticPressure
{
        LABEL           [static_pressure_hi_lim];
        HELP            [static_pressure_hi_lim_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ & WRITE;
}

VARIABLE ptrbMinStaticPressure
{
        LABEL           [static_pressure_lo_lim];
        HELP            [static_pressure_lo_lim_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ & WRITE;
}

VARIABLE ptrbMaxTemperature
{
        LABEL           [trans_pres_max_temperature];
        HELP            [trans_pres_max_temperature_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ & WRITE;
}

VARIABLE ptrbMinTemperature
{
        LABEL           [trans_pres_min_temperature];
        HELP            [trans_pres_min_temperature_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ & WRITE;
}

VARIABLE ptrbPrimaryValueStatus_quality
{
        LABEL           [status_quality];
        HELP            [value_status_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                STATUS_OUTPUT_NO_RCAS
        }
        HANDLING        READ;
}

ptrbPrimaryValueStatus_limit                    LIKE VARIABLE   ptrbPrimaryValueStatus_quality
{
        REDEFINE LABEL          [status_limit];
        REDEFINE TYPE           ENUMERATED (1)
        {
                STATUS_OUTPUT_LIMIT
        }
}

VARIABLE aiDPXdScaleUnitFF
{
        LABEL           "";
        HELP            "";
        CLASS           DEVICE;
        TYPE            UNSIGNED_INTEGER (1);
        DEFAULT_VALUE   0;
        HANDLING        READ & WRITE;
}

VARIABLE aiDPXdScale100
{
        LABEL           "";
        HELP            "";
        CLASS           DEVICE;
        TYPE            FLOAT;
        DEFAULT_VALUE   100.0;
        HANDLING        READ & WRITE;
}

VARIABLE aiDPXdScale0
{
        LABEL           "";
        HELP            "";
        CLASS           DEVICE;
        TYPE            FLOAT;
        DEFAULT_VALUE   0.0;
        HANDLING        READ & WRITE;
}

VARIABLE aiDPXdScaleDecimalFF
{
        LABEL           "";
        HELP            "";
        CLASS           DEVICE;
        TYPE            UNSIGNED_INTEGER (1);
        DEFAULT_VALUE   0;
        HANDLING        READ & WRITE;
}

VARIABLE aiPOutScaleUnit
{
        LABEL           "";
        HELP            "";
        CLASS           DEVICE;
        TYPE            UNSIGNED_INTEGER (1);
        DEFAULT_VALUE   0;
        HANDLING        READ & WRITE;
}

VARIABLE aiPOutScaleDecimal
{
        LABEL           "";
        HELP            "";
        CLASS           DEVICE;
        TYPE            UNSIGNED_INTEGER (1);
        DEFAULT_VALUE   0;
        HANDLING        READ & WRITE;
}

/*******************************************************************************/
/***** Hilfsvariable ***********************************************************/
/*******************************************************************************/

VARIABLE pdm_revision
{
      CLASS LOCAL;
      LABEL [pdm_revision_label];
      TYPE ASCII(16)
      {
              DEFAULT_VALUE [edd_revision_label];
      }
}

/*******************************************************************************/
/*****  UNIT Relation***********************************************************/
/*******************************************************************************/

UNIT LOCAL_PRESSURE_SENSOR_UNITS
{
        local_pressure_sensor_units:

        local_pressure_sensor_min,
        local_pressure_sensor_max,
}

UNIT LOCAL_STATIC_PRESSURE_UNITS
{
        local_static_pressure_units:

        local_static_pressure_lower_range_value,
        local_static_pressure_upper_range_value
}

UNIT PRESSURE_SENSOR_UNITS
{
    pressure_sensor_units:

        pressure_lower_range_limit,
        pressure_upper_range_limit,
        static_pressure_hi_lim,
        static_pressure_lo_lim
}

UNIT PRESSURE_UNITS
{
    pressure_units:

        pressure_lower_range_value,
        pressure_upper_range_value,
        ptrbMinSensorValue,
        ptrbMaxSensorValue,
        ptrbSensorValue,
        temperature_pressure_value
}

UNIT STATIC_PRESSURE_UNITS
{
    static_pressure_units:

        static_pressure_upper_range_value,
        static_pressure_lower_range_value,
        free_proc_var_stat_press
}

UNIT PTRB_SCALE_OUT_UNIT
{
    ptrbScaleOutUnit:

        ptrbScaleOut100,
        ptrbScaleOut0,
        ptrbPrimaryValue
}

UNIT AIDP_OUTSCALE_UNITS
{
    aidp_outscale_units:

        aidp_outscale_0,
        aidp_outscale_100,
        Tab_s_outputlimits,
        aiDPLoLoLim,
        aiDPLoLim,
        aiDPHiLim,
        aiDPHiHiLim,
        ptrbMaxStaticPressure,
        ptrbMinStaticPressure,
        aiDPOutValue,
        aiPOutValue,//func2_AI_out_value
        aiPOutScale0,//func2_AI_out_lower_range_value(READ_ONLY)
        aiPOutScale100//func2_AI_out_upper_range_value(READ_ONLY)

}

UNIT TB_SENSOR_PTRBTEMPERATURETRIMVALUE
{
        temperature.DIGITAL_UNITS:

        ptrbTemperatureTrimValue,
//        temperature_pressure_value,
        ptrbMinTemperature,
        ptrbMaxTemperature
}

UNIT PTRBTEMPERATUREVALUE1
{
                temperature_units:

                temperature_pressure_value
}
UNIT PTRBTEMPERATUREVALUE2
{
        ptrbTemperatureValueUnitV21:

        ptrbTemperatureValueV21
}

/*
UNIT TB_SENSOR_PTRBTEMPERATUREVALUEUNITV21
{
        ptrbTemperatureValueUnitV21:

                ptrbMinTemperature,
                ptrbMaxTemperature
}
*/
/********************************************************************************/
/*      METHOD                                                                                                                                          */
/********************************************************************************/

METHOD pre_download_dependencies
{
        DEFINITION
        {
                int status;
                status = ReadCommand (read_sv_units);
        }
}

METHOD post_download_dependencies
{
        DEFINITION
        {
                if (software_revision < 21)
                {
                        ACKNOWLEDGE([WrongSwRevision]);
                        process_abort();
                }

        }
}

METHOD  method_assignment1
{
    DEFINITION
    {
                local_pressure_sensor_units = pressure_sensor_units;
                local_pressure_sensor_min = pressure_lower_range_limit;
                local_pressure_sensor_units = pressure_units;
        }
}

METHOD  method_assignment2
{
    DEFINITION
    {
                local_pressure_sensor_units = pressure_sensor_units;
                local_pressure_sensor_max = pressure_upper_range_limit;
                local_pressure_sensor_units = pressure_units;
        }
}

METHOD  method_assignment_unit
{
    DEFINITION
    {
                local_pressure_sensor_units = pressure_units;
        }
}

METHOD  method_static_pressure_units
{
    DEFINITION
    {
                local_static_pressure_units = static_pressure_units;
        }
}

METHOD  method_edit_local_static_pressure_lower_range_value
{
    DEFINITION
    {
                local_static_pressure_units = pressure_sensor_units;
                local_static_pressure_lower_range_value = static_pressure_lo_lim;
                old_local_static_pressure_lower_range_value = static_pressure_lo_lim;
                local_static_pressure_units = static_pressure_units;
        }
}

METHOD  method_edit_local_static_pressure_upper_range_value
{
    DEFINITION
    {
                local_static_pressure_units = pressure_sensor_units;
                local_static_pressure_upper_range_value = static_pressure_hi_lim;
                old_local_static_pressure_upper_range_value = static_pressure_hi_lim;
                local_static_pressure_units = static_pressure_units;
        }
}

METHOD  method_read_local_static_pressure_lower_range_value
{
    DEFINITION
    {
                local_static_pressure_units = pressure_sensor_units;
                local_static_pressure_lower_range_value = static_pressure_lo_lim;
                local_static_pressure_units = static_pressure_units;
        }
}

METHOD  method_read_local_static_pressure_upper_range_value
{
    DEFINITION
    {
                local_static_pressure_units = pressure_sensor_units;
                local_static_pressure_upper_range_value = static_pressure_hi_lim;
                local_static_pressure_units = static_pressure_units;
        }
}

METHOD  method_pre_write_pbWriteLock
{
    LABEL   [method_pre_write_pbWriteLock];
    DEFINITION
    {
                send_command(0);
                if (software_revision < 21)
                {
                        ACKNOWLEDGE([WrongSwRevision]);
                        process_abort();
                }
                WriteCommand (write_sv_units);
        }
}

METHOD abort_load_to_device
{
        LABEL "aborting_return_to_normal";
        DEFINITION
        {
                local_abort=1;
                PUT_MESSAGE([Procedure_aborted]);
        }
}

METHOD  method_set_pv_lower_range_value
{
        LABEL   [set_pv_lower_range_value];
    DEFINITION
    {
                        int status;

                        ReadCommand (read_static_data_material);
                        if ( pbWriteLock == 0 )
                        {
                                ACKNOWLEDGE([DeviceWriteProtected]);
                                process_abort();
                        }

                        status = send_command(37);
                        if ( status >= ID_FC_ERROR )
                        {
                                ACKNOWLEDGE([Procedure_aborted]);
                        }
                        else
                        {
                                ACKNOWLEDGE([set_lower_range_value_successful]);
                        }
        }
}

METHOD  method_set_pv_upper_range_value
{
        LABEL   [set_pv_upper_range_value];
    DEFINITION
    {
                        int status;

                        ReadCommand (read_static_data_material);
                        if ( pbWriteLock == 0 )
                        {
                                ACKNOWLEDGE([DeviceWriteProtected]);
                                process_abort();
                        }
                        status = send_command(36);

                        if ( status >= ID_FC_ERROR )
                        {
                                ACKNOWLEDGE([Procedure_aborted]);
                        }
                        else
                        {
                                ACKNOWLEDGE([set_upper_range_value_successful]);
                        }
        }
}


METHOD method_set_status_limit_1
{
        CLASS           INPUT;
        DEFINITION
        {
                int     quality;
                int block_mode;                 /* !!! temp.: bis Methoden mit Aufrufparametern funktionieren !!! */

                quality = ivar_value(aiDPSimulateStatus_quality)/*func1_AI_simulate_status_quality)*/;
                if ((quality == 0x20) || (quality == 0x30))
                        iassign(aiDPSimulateStatus_limit/*func1_AI_simulate_status_limit*/, 0);

                block_mode      = ivar_value(aiDPModeBlkTarget/*func1_AI_target_mode*/);
                quality         = ivar_value(aiDPOutStatus_quality/*func1_AI_out_status_quality*/);
                if ((block_mode == BLOCK_MODE_MAN) && ((quality == 0x20) || (quality == 0x30)))
                        iassign(aiDPOutStatus_limit/*func1_AI_out_status_limit*/, 0);
        }
}

METHOD method_set_status_limit_2
{
        CLASS           INPUT;
        DEFINITION
        {
                int     quality;
                int block_mode;

                quality = ivar_value(aiPSimulateStatus_quality);//func2_AI_simulate_status_quality)
                if ((quality == 0x20) || (quality == 0x30))
                        iassign(aiPSimulateStatus_limit, 0);//func2_AI_simulate_status_limit

                block_mode      = ivar_value(aiPModeBlkTarget);//func2_AI_target_mode
                quality         = ivar_value(aiPOutStatus_quality);//func2_AI_out_status_quality
                if ((block_mode == BLOCK_MODE_MAN) && ((quality == 0x20) || (quality == 0x30)))
                        iassign(aiPOutStatus_limit, 0);//func2_AI_out_status_limit
        }
}

METHOD method_phys_factory_reset_params
{
        LABEL   [factory_reset_PARAMS];
        DEFINITION
        {
                char status[3];
                add_abort_method(abort_load_to_device);
                IGNORE_ALL_DEVICE_STATUS();
                XMTR_IGNORE_ALL_DEVICE_STATUS();
                assign_int(eeprom_select,1);
                send(39, status);
                if ( status[STATUS_RESPONSE_CODE] ) {
                           display_response_status(39,status[STATUS_RESPONSE_CODE]);
                           ACKNOWLEDGE("Factory Reset Error");
                           process_abort();
                }
                else
                {
                       DELAY(40,"Restoring initial values..." "|de|Initialwerte werden geladen...");
                       ACKNOWLEDGE("Ready" "|de|Beendet");
                }
        }
}

METHOD reset_temperatur_pointer
{
        LABEL   [reset];
        HELP    [reset_temp_sens_pointer_Help];
        DEFINITION
        {
                int status;
                int choice_mode, choise_reset;

                ReadCommand (read_static_data_material);
                if ( pbWriteLock == 0 )
                {
                        ACKNOWLEDGE([DeviceWriteProtected]);
                        process_abort();
                }

#ifdef NO_trans1_max_temperature
                choice_mode=1; //nur trans1_min_temperature
#else
#ifdef NO_trans1_min_temperature
                choice_mode=0; //nur trans1_max_temperature
#else
                choice_mode= SELECT_FROM_LIST([select_to_reset], [maxmin_R]);
#endif
#endif

                choise_reset = SELECT_FROM_LIST ([ack_reset], [no_yes]);
                switch (choise_reset)
                {
                        case 0:
                                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        break;
                        case 1:
                        switch (choice_mode)
                        {
                                case 0:
                                        status = send_command_trans(243,2);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                                ACKNOWLEDGE([acknowledge_pointer_max_reset]);

                                break;
                                case 1:
                                        status = send_command_trans(243,3);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                                ACKNOWLEDGE([acknowledge_pointer_min_reset]);
                                break;
                                case 2:
                                        status = send_command_trans(243,2);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                        {
                                        status = send_command_trans(243,3);
                                                if ( status >= ID_FC_ERROR )
                                                {
                                                        ACKNOWLEDGE([acknowledge_process_aborted]);
                                                        process_abort();
                                                }
                                                else
                                                        ACKNOWLEDGE([acknowledge_pointer_max_min_reset]);
                                        }
                                break;
                        }//switch (choice_mode)
                        break;
                }
        }
}

METHOD reset_pressure_pointer
{
        LABEL   [reset];
        HELP    [reset_pres_pointer_Help];
        DEFINITION
        {
                int status;
                int choice_mode, choise_reset;

                ReadCommand (read_static_data_material);
                if ( pbWriteLock == 0 )
                {
                        ACKNOWLEDGE([DeviceWriteProtected]);
                        process_abort();
                }

#ifdef NO_trans1_max_sensor_value
                choice_mode=1; //nur trans1_min_sensor_value
#else
#ifdef NO_trans1_min_sensor_value
                choice_mode=0; //nur trans1_max_sensor_value
#else
                choice_mode= SELECT_FROM_LIST([select_to_reset], [maxmin_R]);
#endif
#endif
                choise_reset = SELECT_FROM_LIST ([ack_reset], [no_yes]);
                switch (choise_reset)
                {
                        case 0:
                                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        break;
                        case 1:
                        switch (choice_mode)
                        {
                                case 0:
                                        status = send_command_trans(243,0);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                                ACKNOWLEDGE([acknowledge_pointer_max_reset]);

                                break;
                                case 1:
                                        status = send_command_trans(243,1);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                                ACKNOWLEDGE([acknowledge_pointer_min_reset]);
                                break;
                                case 2:
                                        status = send_command_trans(243,0);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                        {
                                        status = send_command_trans(243,1);
                                                if ( status >= ID_FC_ERROR )
                                                {
                                                        ACKNOWLEDGE([acknowledge_process_aborted]);
                                                        process_abort();
                                                }
                                                else
                                                        ACKNOWLEDGE([acknowledge_pointer_max_min_reset]);
                                        }
                                break;
                        }//switch (choice_mode)
                        break;
                }
        }
}

METHOD reset_pressure_pointer_static
{
        LABEL   [reset];
        HELP    [reset_pres_pointer_Help];
        DEFINITION
        {
                int status;
                int choice_mode, choise_reset;

                ReadCommand (read_static_data_material);
                if ( pbWriteLock == 0 )
                {
                        ACKNOWLEDGE([DeviceWriteProtected]);
                        process_abort();
                }

#ifdef NO_trans1_max_sensor_value
                choice_mode=1; //nur trans1_min_sensor_value
#else
#ifdef NO_trans1_min_sensor_value
                choice_mode=0; //nur trans1_max_sensor_value
#else
                choice_mode= SELECT_FROM_LIST([select_to_reset], [maxmin_R]);
#endif
#endif
                choise_reset = SELECT_FROM_LIST ([ack_reset], [no_yes]);
                switch (choise_reset)
                {
                        case 0:
                                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        break;
                        case 1:
                        switch (choice_mode)
                        {
                                case 0:
                                        status = send_command_trans(243,4);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                                ACKNOWLEDGE([acknowledge_pointer_max_reset]);

                                break;
                                case 1:
                                        status = send_command_trans(243,5);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                                ACKNOWLEDGE([acknowledge_pointer_min_reset]);
                                break;
                                case 2:
                                        status = send_command_trans(243,4);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                        {
                                        status = send_command_trans(243,5);
                                                if ( status >= ID_FC_ERROR )
                                                {
                                                        ACKNOWLEDGE([acknowledge_process_aborted]);
                                                        process_abort();
                                                }
                                                else
                                                        ACKNOWLEDGE([acknowledge_pointer_max_min_reset]);
                                        }
                                break;
                        }//switch (choice_mode)
                        break;
                }
        }
}

/********************************************************************************/
/*      LOCAL VARIABLE                                                                                                                          */
/********************************************************************************/
VARIABLE local_abort
{
        LABEL   "local_abort";
        CLASS   LOCAL;
        TYPE    INTEGER
        {
                DEFAULT_VALUE   0;
        }
}

VARIABLE local_static_pressure_units
{
        LABEL "local_static_pressure_units";
        CLASS   LOCAL;
        TYPE ENUMERATED
        {
                DEFAULT_VALUE  7;
                {    1,   "|001inH2O"
                                  "|049inH2O"},
                {    2,   "|001inHg"
                                  "|049inHg"},
                {    3,   "|001ftH2O"
                                  "|049ftH2O"},
                {    4,   "|001mmH2O"
                                  "|049mmH2O"},
                {    5,   "|001mmHg"
                                  "|049mmHg"},
                {    6,   "|001psi"
                                  "|049psi"},
                {    7,   "|001bar"
                                  "|049bar"},
                {    8,   "|001mbar"
                                  "|049mbar"},
                {    9,   "|001g/cm2"
                                  "|049g/cm2"},
                {   10,   "|001kg/cm2"
                                  "|049kg/cm2"},
                {   11,   "|001Pa"
                                  "|049Pa"},
                {   12,   "|001kPa"
                                  "|049kPa"},
                {   13,   "|001torr"
                                  "|049torr"},
                {   14,   "|001atm"
                                  "|049atm"},
                {  237,   "|001MPa"
                                  "|049MPa"},
                /*UNITS_CODE (238),     /* in H2O @ 4 Degrees Celsius (ABB-Kent) */
                /*UNITS_CODE (239),     /* mm H2O @ 4 Degrees Celsius (ABB-Kent) */
                {  251,  [none] },
                {  252,  [unknown] },
                {  253,   "|001special"
                                  "|049Spezial"}
        }
}

VARIABLE local_pressure_sensor_units
{
        CLASS   LOCAL;
        TYPE    ENUMERATED
        {
                DEFAULT_VALUE 8;
                UNITS_CODE (1),         /* inches H2O @ 68 degrees Fahrenheit */
                UNITS_CODE (2),         /* inches Hg @ 0 degrees Celsius */
                UNITS_CODE (3),         /* feet H2O @ 68 degrees Fahrenheit */
                UNITS_CODE (4),         /* millimeters H2O @ 68 degrees Fahrenheit*/
                UNITS_CODE (5),         /* millimeters Hg @ 0 degrees Celsius */
                UNITS_CODE (6),         /* pounds/square inch */
                UNITS_CODE (7),         /* bars */
                UNITS_CODE (8),         /* millibars */
                UNITS_CODE (9),         /* grams/square centimeter */
                UNITS_CODE (10),        /* kilograms/square centimeter */
                UNITS_CODE (11),        /* pascals */
                UNITS_CODE (12),        /* kilopascals */
                UNITS_CODE (13),        /* torr @ 0 degrees Celsius */
                UNITS_CODE (14),        /* atmospheres */
                UNITS_CODE (237),       /* megapascals (ABB-Kent) */
                UNITS_CODE (238),       /* in H2O @ 4 Degrees Celsius (ABB-Kent) */
                UNITS_CODE (239),       /* mm H2O @ 4 Degrees Celsius (ABB-Kent) */
                {251,  [none] },
                {252,  [unknown] },
                {253,  [special] }
        }

        HANDLING READ & WRITE;
}

VARIABLE local_pressure_sensor_min
{
        LABEL   "local_pressure_sensor_min";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   0;
        }

        HANDLING READ & WRITE;
}

VARIABLE local_pressure_sensor_max
{
        LABEL   "local_pressure_sensor_max";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   100;
        }

        HANDLING READ & WRITE;
}

VARIABLE local_static_pressure_lower_range_value
{
        LABEL   "local_static_pressure_lower_range_value";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   0;
        }

        HANDLING READ & WRITE;
}

VARIABLE local_static_pressure_upper_range_value
{
        LABEL   "local_static_pressure_upper_range_value";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   100;
        }

        HANDLING READ & WRITE;
}

VARIABLE old_local_static_pressure_lower_range_value
{
        LABEL   "local_static_pressure_lower_range_value";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   0;
        }

        HANDLING READ & WRITE;
}

VARIABLE old_local_static_pressure_upper_range_value
{
        LABEL   "local_static_pressure_upper_range_value";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   100;
        }

        HANDLING READ & WRITE;
}

VARIABLE aiPOutScale100
{
        LABEL           [func_upper_value];
        HELP            [func_out_scale_upper_value_help];
        CLASS           CONTAINED;
        TYPE            FLOAT;
        HANDLING        READ & WRITE;
}

VARIABLE aiPOutScale0
{
        LABEL           [func_lower_value];
        HELP            [func_out_scale_lower_value_help];
        CLASS           CONTAINED;
        TYPE            FLOAT;
        HANDLING        READ & WRITE;
}

VARIABLE ptrbTemperatureValueStatus_quality
{
        LABEL           [status_quality];
        HELP            [value_status_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                STATUS_OUTPUT_NO_RCAS
        }
        HANDLING        READ;
}

ptrbTemperatureValueStatus_limit                        LIKE VARIABLE   ptrbTemperatureValueStatus_quality
{
        REDEFINE LABEL          [status_limit];
        REDEFINE TYPE           ENUMERATED (1)
        {
                STATUS_OUTPUT_LIMIT
        }
}

VARIABLE xmtr_specific_status_0
{
        LABEL           [current_state_alarm_sum];
        HELP            [current_state_alarm_sum_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            BIT_ENUMERATED (1)
        {
                DEFAULT_VALUE    0x00;
                {       0x00,   [limit_state_NO_ALARM]  },
                {       0x02,   [limit_state_HI_HI]             },
                {       0x04,   [limit_state_HI]                },
                {       0x08,   [limit_state_LO_LO]             },
                {       0x10,   [limit_state_LO]                },
                {       0x80,   [limit_state_ST_REV]    }
        }
        STYLE       "MULTILINE 0 7";
        HANDLING        READ;
}

VARIABLE xmtr_specific_status_1
{
        LABEL           [current_state_alarm_sum];
        HELP            [current_state_alarm_sum_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            BIT_ENUMERATED (1)
        {
                DEFAULT_VALUE    0x00;
                {       0x00,   [limit_state_NO_ALARM]  },
                {       0x02,   [limit_state_HI_HI]             },
                {       0x04,   [limit_state_HI]                },
                {       0x08,   [limit_state_LO_LO]             },
                {       0x10,   [limit_state_LO]                },
                {       0x80,   [limit_state_ST_REV]    }
        }
        STYLE       "MULTILINE 0 7";
        HANDLING        READ;
}

VARIABLE ptrbSecondaryValue1Status_quality
{
        LABEL           [status_quality];
        HELP            [value_status_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                STATUS_OUTPUT_NO_RCAS
        }
        HANDLING        READ;
}

ptrbSecondaryValue1Status_limit  LIKE VARIABLE  ptrbSecondaryValue1Status_quality
{
        REDEFINE LABEL          [status_limit];
        REDEFINE TYPE           ENUMERATED (1)
        {
                STATUS_OUTPUT_LIMIT
        }
}

VARIABLE ptrbStaticPressureValueStatus_quality
{
        LABEL           [status_quality];
        HELP            [value_status_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                STATUS_OUTPUT_NO_RCAS
        }
        HANDLING        READ;
}

ptrbStaticPressureValueStatus_limit  LIKE VARIABLE  ptrbStaticPressureValueStatus_quality
{
        REDEFINE LABEL          [status_limit];
        REDEFINE TYPE           ENUMERATED (1)
        {
                STATUS_OUTPUT_LIMIT
        }
}
/********************************************************************************/
/*      Download        LOAD TO PC                                                                                                              */
/********************************************************************************/

MENU download_variables
{
        LABEL           [menu_load_to_PC];
        PRE_READ_ACTIONS
        {
                pre_download_dependencies,
        }
        POST_READ_ACTIONS
        {
                post_download_dependencies,
        }
        ITEMS
        {
                tag,
                descriptor,
                message,
                manufacturer_id,
                device_id,
                software_revision,
                hardware_revision,
                date,
                module_type_code,
                pressure_sensor_serial_number,
                pbsoftwarespecifics,
                write_protect,
                pbWriteLock,
             IF (software_revision >= 21)
             {
                pressure_sensor_units,
                pressure_lower_range_limit,
                pressure_upper_range_limit,
                pressure_units,
                pressure_lower_range_value,
                pressure_upper_range_value,
                IF (DIFFERENTIAL_SENSOR)
                {
                        static_pressure_hi_lim,
                        static_pressure_lo_lim,
                        static_pressure_units,
                        static_pressure_lower_range_value,
                        static_pressure_upper_range_value
                }
                ptrbScaleOutUnit,
                ptrbScaleOut100,
                ptrbScaleOut0,
                ptrbLowFlowCutOff,
                ptrbFlowLinSqrtPoint,
                aidp_outscale_units,
                pressure_damping_value,
                aidp_outscale_0,
                aidp_outscale_100,
                aiDPLoLoLim,
                aiDPLoLim,
                aiDPHiLim,
                aiDPHiHiLim,
                aiDPAlarmHys,
                local_keys_mode_control_codes,
                write_protect,
                meter_installation,
                module_fill_fluid,
                module_isolator_material,
                o_ring_material,
                number_of_remote_seals,
                remote_seal_type,
                remote_seal_fill_fluid,
                remote_seal_isolator_material,
                flange_type,
                flange_material,
                drain_vent_material,
                ptrbSensorCalDate,
                ptrbSensorCalWho,
                pbDeviceCertification,
                IF ( software_revision >= 21 )
                {
                ptrbTemperatureValueUnitV21,
                }
                ELSE
                {
                temperature_units,
                }
                pressure_output_transfer_function,
                IF (pressure_output_transfer_function == 4)
                {
/*                      IF (ptrbTabActualNumber > 1)
                        {
                                ptrbTabXValue1,
                                ptrbTabYValue1,
                        }
*/                      IF (ptrbTabActualNumber >= 1)
                        {
                                ptrbTabXValue2,
                                ptrbTabYValue2,
                        }
                        IF (ptrbTabActualNumber >= 2)
                        {
                                ptrbTabXValue3,
                                ptrbTabYValue3,
                        }
                        IF (ptrbTabActualNumber >= 3)
                        {
                                ptrbTabXValue4,
                                ptrbTabYValue4,
                        }
                        IF (ptrbTabActualNumber >= 4)
                        {
                                ptrbTabXValue5,
                                ptrbTabYValue5,
                        }
                        IF (ptrbTabActualNumber >= 5)
                        {
                                ptrbTabXValue6,
                                ptrbTabYValue6,
                        }
                        IF (ptrbTabActualNumber >= 6)
                        {
                                ptrbTabXValue7,
                                ptrbTabYValue7,
                        }
                        IF (ptrbTabActualNumber >= 7)
                        {
                                ptrbTabXValue8,
                                ptrbTabYValue8,
                        }
                        IF (ptrbTabActualNumber >= 8)
                        {
                                ptrbTabXValue9,
                                ptrbTabYValue9,
                        }
                        IF (ptrbTabActualNumber >= 9)
                        {
                                ptrbTabXValue10,
                                ptrbTabYValue10,
                        }
                        IF (ptrbTabActualNumber >= 10)
                        {
                                ptrbTabXValue11,
                                ptrbTabYValue11,
                        }
                        IF (ptrbTabActualNumber >= 11)
                        {
                                ptrbTabXValue12,
                                ptrbTabYValue12,
                        }
                        IF (ptrbTabActualNumber >= 12)
                        {
                                ptrbTabXValue13,
                                ptrbTabYValue13,
                        }
                        IF (ptrbTabActualNumber >= 13)
                        {
                                ptrbTabXValue14,
                                ptrbTabYValue14,
                        }
                        IF (ptrbTabActualNumber >= 14)
                        {
                                ptrbTabXValue15,
                                ptrbTabYValue15,
                        }
                        IF (ptrbTabActualNumber >= 15)
                        {
                                ptrbTabXValue16,
                                ptrbTabYValue16,
                        }
                        IF (ptrbTabActualNumber >= 16)
                        {
                                ptrbTabXValue17,
                                ptrbTabYValue17,
                        }
                        IF (ptrbTabActualNumber >= 17)
                        {
                                ptrbTabXValue18,
                                ptrbTabYValue18,
                        }
                        IF (ptrbTabActualNumber >= 18)
                        {
                                ptrbTabXValue19,
                                ptrbTabYValue19,
                        }
                        IF (ptrbTabActualNumber >= 19)
                        {
                                ptrbTabXValue20,
                                ptrbTabYValue20,
                        }
                        IF (ptrbTabActualNumber >= 20)
                        {
                                ptrbTabXValue21,
                                ptrbTabYValue21,
                        }
                }
            }
        }
}

/********************************************************************************/
/*      Upload  LOAD TO DEVICE                                                                                                          */
/********************************************************************************/

MENU upload_variables
{
        LABEL           [menu_load_to_device];
        PRE_WRITE_ACTIONS
        {
                method_pre_write_pbWriteLock,
        }
        ITEMS
        {
            IF (software_revision >= 21)
            {
                tag,
                descriptor,
                message,
                phys_install_date,  // @@st
                date,
                local_keys_mode_control_codes,
                meter_installation,
                IF (DIFFERENTIAL_SENSOR)
                {
                        static_pressure_units,
                        static_pressure_upper_range_value,
                        static_pressure_lower_range_value,
                }
                o_ring_material,
                number_of_remote_seals,
                remote_seal_type,
                remote_seal_fill_fluid,
                remote_seal_isolator_material,
                flange_type,
                flange_material,
                drain_vent_material,
                ptrbSensorCalDate,
                ptrbSensorCalWho,
                pressure_units,
                pressure_lower_range_value,
                pressure_upper_range_value,
                ptrbScaleOutUnit,
                ptrbScaleOut100,
                ptrbScaleOut0,
                ptrbLowFlowCutOff,
                ptrbFlowLinSqrtPoint,
                pressure_damping_value,
                aidp_outscale_units,
                aidp_outscale_0,
                aidp_outscale_100,
                aiDPLoLoLim,
                aiDPLoLim,
                aiDPHiLim,
                aiDPHiHiLim,
                aiDPAlarmHys,
                IF ( software_revision >= 21 )
                {
                ptrbTemperatureValueUnitV21,
                }
                ELSE
                {
                temperature_units,
                }
                ptrbTabActualNumber,
                pressure_output_transfer_function,
                IF (pressure_output_transfer_function == 4)
                {
/*                      IF (ptrbTabActualNumber > 1)
                        {
                                ptrbTabXValue1,
                                ptrbTabYValue1,
                        }     */
                        IF (ptrbTabActualNumber >= 1)
                        {
                                ptrbTabXValue2,
                                ptrbTabYValue2,
                        }
                        IF (ptrbTabActualNumber >= 2)
                        {
                                ptrbTabXValue3,
                                ptrbTabYValue3,
                        }
                        IF (ptrbTabActualNumber >= 3)
                        {
                                ptrbTabXValue4,
                                ptrbTabYValue4,
                        }
                        IF (ptrbTabActualNumber >= 4)
                        {
                                ptrbTabXValue5,
                                ptrbTabYValue5,
                        }
                        IF (ptrbTabActualNumber >= 5)
                        {
                                ptrbTabXValue6,
                                ptrbTabYValue6,
                        }
                        IF (ptrbTabActualNumber >= 6)
                        {
                                ptrbTabXValue7,
                                ptrbTabYValue7,
                        }
                        IF (ptrbTabActualNumber >= 7)
                        {
                                ptrbTabXValue8,
                                ptrbTabYValue8,
                        }
                        IF (ptrbTabActualNumber >= 8)
                        {
                                ptrbTabXValue9,
                                ptrbTabYValue9,
                        }
                        IF (ptrbTabActualNumber >= 9)
                        {
                                ptrbTabXValue10,
                                ptrbTabYValue10,
                        }
                        IF (ptrbTabActualNumber >= 10)
                        {
                                ptrbTabXValue11,
                                ptrbTabYValue11,
                        }
                        IF (ptrbTabActualNumber >= 11)
                        {
                                ptrbTabXValue12,
                                ptrbTabYValue12,
                        }
                        IF (ptrbTabActualNumber >= 12)
                        {
                                ptrbTabXValue13,
                                ptrbTabYValue13,
                        }
                        IF (ptrbTabActualNumber >= 13)
                        {
                                ptrbTabXValue14,
                                ptrbTabYValue14,
                        }
                        IF (ptrbTabActualNumber >= 14)
                        {
                                ptrbTabXValue15,
                                ptrbTabYValue15,
                        }
                        IF (ptrbTabActualNumber >= 15)
                        {
                                ptrbTabXValue16,
                                ptrbTabYValue16,
                        }
                        IF (ptrbTabActualNumber >= 16)
                        {
                                ptrbTabXValue17,
                                ptrbTabYValue17,
                        }
                        IF (ptrbTabActualNumber >= 17)
                        {
                                ptrbTabXValue18,
                                ptrbTabYValue18,
                        }
                        IF (ptrbTabActualNumber >= 18)
                        {
                                ptrbTabXValue19,
                                ptrbTabYValue19,
                        }
                        IF (ptrbTabActualNumber >= 19)
                        {
                                ptrbTabXValue20,
                                ptrbTabYValue20,
                        }
                        IF (ptrbTabActualNumber >= 20)
                        {
                                ptrbTabXValue21,
                                ptrbTabYValue21,
                        }
                }
            }
        }
}

